@charset "UTF-8";
.c3 svg {
    font: 10px sans-serif;
    -webkit-tap-highlight-color: transparent
}

.c3 line, .c3 path {
    fill: none;
    stroke: #000
}

.c3 text {
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none
}

.c3-bars path, .c3-event-rect, .c3-legend-item-tile, .c3-xgrid-focus, .c3-ygrid {
    shape-rendering: crispEdges
}

.c3-chart-arc path {
    stroke: #fff
}

.c3-chart-arc rect {
    stroke: #fff;
    stroke-width: 1
}

.c3-chart-arc text {
    fill: #fff;
    font-size: 13px
}

.c3-grid line {
    stroke: #aaa
}

.c3-grid text {
    fill: #aaa
}

.c3-xgrid, .c3-ygrid {
    stroke-dasharray: 3 3
}

.c3-text.c3-empty {
    fill: grey;
    font-size: 2em
}

.c3-line {
    stroke-width: 1px
}

.c3-circle._expanded_ {
    stroke-width: 1px;
    stroke: #fff
}

.c3-selected-circle {
    fill: #fff;
    stroke-width: 2px
}

.c3-bar {
    stroke-width: 0
}

.c3-bar._expanded_ {
    fill-opacity: 1;
    fill-opacity: .75
}

.c3-target.c3-focused {
    opacity: 1
}

.c3-target.c3-focused path.c3-line, .c3-target.c3-focused path.c3-step {
    stroke-width: 2px
}

.c3-target.c3-defocused {
    opacity: .3 !important
}

.c3-region {
    fill: #4682b4;
    fill-opacity: .1
}

.c3-brush .extent {
    fill-opacity: .1
}

.c3-legend-item {
    font-size: 12px
}

.c3-legend-item-hidden {
    opacity: .15
}

.c3-legend-background {
    opacity: .75;
    fill: #fff;
    stroke: #d3d3d3;
    stroke-width: 1
}

.c3-title {
    font: 14px sans-serif
}

.c3-tooltip-container {
    z-index: 10
}

.c3-tooltip {
    border-collapse: collapse;
    border-spacing: 0;
    background-color: #fff;
    empty-cells: show;
    box-shadow: 7px 7px 12px -9px #777;
    opacity: .9
}

.c3-tooltip tr {
    border: 1px solid #ccc
}

.c3-tooltip th {
    background-color: #aaa;
    font-size: 14px;
    padding: 2px 5px;
    text-align: left;
    color: #fff
}

.c3-tooltip td {
    font-size: 13px;
    padding: 3px 6px;
    background-color: #fff;
    border-left: 1px dotted #999
}

.c3-tooltip td > span {
    display: inline-block;
    width: 10px;
    height: 10px;
    margin-right: 6px
}

.c3-tooltip td.value {
    text-align: right
}

.c3-area {
    stroke-width: 0;
    opacity: .2
}

.c3-chart-arcs-title {
    dominant-baseline: middle;
    font-size: 1.3em
}

.c3-chart-arcs .c3-chart-arcs-background {
    fill: #e0e0e0;
    stroke: #fff
}

.c3-chart-arcs .c3-chart-arcs-gauge-unit {
    fill: #000;
    font-size: 16px
}

.c3-chart-arcs .c3-chart-arcs-gauge-max {
    fill: #777
}

.c3-chart-arcs .c3-chart-arcs-gauge-min {
    fill: #777
}

.c3-chart-arc .c3-gauge-value {
    fill: #000
}

.c3-chart-arc.c3-target g path {
    opacity: 1
}

.c3-chart-arc.c3-target.c3-focused g path {
    opacity: 1
}

/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */
html {
    font-family: sans-serif;
    -ms-text-size-adjust: 100%;
    -webkit-text-size-adjust: 100%
}

body {
    margin: 0
}

article, aside, details, figcaption, figure, footer, header, hgroup, main, menu, nav, section, summary {
    display: block
}

audio, canvas, progress, video {
    display: inline-block;
    vertical-align: baseline
}

audio:not([controls]) {
    display: none;
    height: 0
}

[hidden], template {
    display: none
}

a {
    background-color: transparent
}

a:active, a:hover {
    outline: 0
}

abbr[title] {
    border-bottom: 1px dotted
}

b, strong {
    font-weight: 700
}

dfn {
    font-style: italic
}

h1 {
    font-size: 2em;
    margin: .67em 0
}

mark {
    background: #ff0;
    color: #000
}

small {
    font-size: 80%
}

sub, sup {
    font-size: 75%;
    line-height: 0;
    position: relative;
    vertical-align: baseline
}

sup {
    top: -.5em
}

sub {
    bottom: -.25em
}

img {
    border: 0
}

svg:not(:root) {
    overflow: hidden
}

figure {
    margin: 1em 40px
}

hr {
    box-sizing: content-box;
    height: 0
}

pre {
    overflow: auto
}

code, kbd, pre, samp {
    font-family: monospace, monospace;
    font-size: 1em
}

button, input, optgroup, select, textarea {
    color: inherit;
    font: inherit;
    margin: 0
}

button {
    overflow: visible
}

button, select {
    text-transform: none
}

button, html input[type=button], input[type=reset], input[type=submit] {
    -webkit-appearance: button;
    cursor: pointer
}

button[disabled], html input[disabled] {
    cursor: default
}

button::-moz-focus-inner, input::-moz-focus-inner {
    border: 0;
    padding: 0
}

input {
    line-height: normal
}

input[type=checkbox], input[type=radio] {
    box-sizing: border-box;
    padding: 0
}

input[type=number]::-webkit-inner-spin-button, input[type=number]::-webkit-outer-spin-button {
    height: auto
}

input[type=search] {
    -webkit-appearance: textfield;
    box-sizing: content-box
}

input[type=search]::-webkit-search-cancel-button, input[type=search]::-webkit-search-decoration {
    -webkit-appearance: none
}

fieldset {
    border: 1px solid silver;
    margin: 0 2px;
    padding: .35em .625em .75em
}

legend {
    border: 0;
    padding: 0
}

textarea {
    overflow: auto
}

optgroup {
    font-weight: 700
}

table {
    border-collapse: collapse;
    border-spacing: 0
}

td, th {
    padding: 0
}

/*! Source: https://github.com/h5bp/html5-boilerplate/blob/master/src/css/main.css */
@media print {
    *, :after, :before {
        background: 0 0 !important;
        color: #000 !important;
        box-shadow: none !important;
        text-shadow: none !important
    }

    a, a:visited {
        text-decoration: underline
    }

    a[href]:after {
        content: " (" attr(href) ")"
    }

    abbr[title]:after {
        content: " (" attr(title) ")"
    }

    a[href^="#"]:after, a[href^="javascript:"]:after {
        content: ""
    }

    blockquote, pre {
        border: 1px solid #999;
        page-break-inside: avoid
    }

    thead {
        display: table-header-group
    }

    img, tr {
        page-break-inside: avoid
    }

    img {
        max-width: 100% !important
    }

    h2, h3, p {
        orphans: 3;
        widows: 3
    }

    h2, h3 {
        page-break-after: avoid
    }

    .navbar {
        display: none
    }

    .btn > .caret, .dropup > .btn > .caret {
        border-top-color: #000 !important
    }

    .label {
        border: 1px solid #000
    }

    .table {
        border-collapse: collapse !important
    }

    .table td, .table th {
        background-color: #fff !important
    }

    .table-bordered td, .table-bordered th {
        border: 1px solid #ddd !important
    }
}

* {
    box-sizing: border-box
}

:after, :before {
    box-sizing: border-box
}

html {
    font-size: 10px;
    -webkit-tap-highlight-color: transparent
}

body {
    font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-size: 14px;
    line-height: 1.42857;
    color: #333;
    background-color: #fff
}

button, input, select, textarea {
    font-family: inherit;
    font-size: inherit;
    line-height: inherit
}

a {
    color: #337ab7;
    text-decoration: none
}

a:focus, a:hover {
    color: #23527c;
    text-decoration: underline
}

a:focus {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px
}

figure {
    margin: 0
}

img {
    vertical-align: middle
}

.img-responsive {
    display: block;
    max-width: 100%;
    height: auto
}

.img-rounded {
    border-radius: 6px
}

.img-thumbnail {
    padding: 4px;
    line-height: 1.42857;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 4px;
    transition: all .2s ease-in-out;
    display: inline-block;
    max-width: 100%;
    height: auto
}

.img-circle {
    border-radius: 50%
}

hr {
    margin-top: 20px;
    margin-bottom: 20px;
    border: 0;
    border-top: 1px solid #eee
}

.sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    margin: -1px;
    padding: 0;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    border: 0
}

.sr-only-focusable:active, .sr-only-focusable:focus {
    position: static;
    width: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    clip: auto
}

[role=button] {
    cursor: pointer
}

.h1, .h2, .h3, .h4, .h5, .h6, h1, h2, h3, h4, h5, h6 {
    font-family: inherit;
    font-weight: 500;
    line-height: 1.1;
    color: inherit
}

.h1 .small, .h1 small, .h2 .small, .h2 small, .h3 .small, .h3 small, .h4 .small, .h4 small, .h5 .small, .h5 small, .h6 .small, .h6 small, h1 .small, h1 small, h2 .small, h2 small, h3 .small, h3 small, h4 .small, h4 small, h5 .small, h5 small, h6 .small, h6 small {
    font-weight: 400;
    line-height: 1;
    color: #777
}

.h1, .h2, .h3, h1, h2, h3 {
    margin-top: 20px;
    margin-bottom: 10px
}

.h1 .small, .h1 small, .h2 .small, .h2 small, .h3 .small, .h3 small, h1 .small, h1 small, h2 .small, h2 small, h3 .small, h3 small {
    font-size: 65%
}

.h4, .h5, .h6, h4, h5, h6 {
    margin-top: 10px;
    margin-bottom: 10px
}

.h4 .small, .h4 small, .h5 .small, .h5 small, .h6 .small, .h6 small, h4 .small, h4 small, h5 .small, h5 small, h6 .small, h6 small {
    font-size: 75%
}

.h1, h1 {
    font-size: 36px
}

.h2, h2 {
    font-size: 30px
}

.h3, h3 {
    font-size: 24px
}

.h4, h4 {
    font-size: 18px
}

.h5, h5 {
    font-size: 14px
}

.h6, h6 {
    font-size: 12px
}

p {
    margin: 0 0 10px
}

.lead {
    margin-bottom: 20px;
    font-size: 16px;
    font-weight: 300;
    line-height: 1.4
}

@media (min-width: 768px) {
    .lead {
        font-size: 21px
    }
}

.small, small {
    font-size: 85%
}

.mark, mark {
    background-color: #fcf8e3;
    padding: .2em
}

.text-left {
    text-align: left
}

.text-right {
    text-align: right
}

.text-center {
    text-align: center
}

.text-justify {
    text-align: justify
}

.text-nowrap {
    white-space: nowrap
}

.text-lowercase {
    text-transform: lowercase
}

.initialism, .text-uppercase {
    text-transform: uppercase
}

.text-capitalize {
    text-transform: capitalize
}

.text-muted {
    color: #777
}

.text-primary {
    color: #337ab7
}

a.text-primary:focus, a.text-primary:hover {
    color: #286090
}

.text-success {
    color: #3c763d
}

a.text-success:focus, a.text-success:hover {
    color: #2b542c
}

.text-info {
    color: #31708f
}

a.text-info:focus, a.text-info:hover {
    color: #245269
}

.text-warning {
    color: #8a6d3b
}

a.text-warning:focus, a.text-warning:hover {
    color: #66512c
}

.text-danger {
    color: #a94442
}

a.text-danger:focus, a.text-danger:hover {
    color: #843534
}

.bg-primary {
    color: #fff
}

.bg-primary {
    background-color: #337ab7
}

a.bg-primary:focus, a.bg-primary:hover {
    background-color: #286090
}

.bg-success {
    background-color: #dff0d8
}

a.bg-success:focus, a.bg-success:hover {
    background-color: #c1e2b3
}

.bg-info {
    background-color: #d9edf7
}

a.bg-info:focus, a.bg-info:hover {
    background-color: #afd9ee
}

.bg-warning {
    background-color: #fcf8e3
}

a.bg-warning:focus, a.bg-warning:hover {
    background-color: #f7ecb5
}

.bg-danger {
    background-color: #f2dede
}

a.bg-danger:focus, a.bg-danger:hover {
    background-color: #e4b9b9
}

.page-header {
    padding-bottom: 9px;
    margin: 40px 0 20px;
    border-bottom: 1px solid #eee
}

ol, ul {
    margin-top: 0;
    margin-bottom: 10px
}

ol ol, ol ul, ul ol, ul ul {
    margin-bottom: 0
}

.list-unstyled {
    padding-left: 0;
    list-style: none
}

.list-inline {
    padding-left: 0;
    list-style: none;
    margin-left: -5px
}

.list-inline > li {
    display: inline-block;
    padding-left: 5px;
    padding-right: 5px
}

dl {
    margin-top: 0;
    margin-bottom: 20px
}

dd, dt {
    line-height: 1.42857
}

dt {
    font-weight: 700
}

dd {
    margin-left: 0
}

.dl-horizontal dd:after, .dl-horizontal dd:before {
    content: " ";
    display: table
}

.dl-horizontal dd:after {
    clear: both
}

@media (min-width: 768px) {
    .dl-horizontal dt {
        float: left;
        width: 160px;
        clear: left;
        text-align: right;
        overflow: hidden;
        text-overflow: ellipsis;
        white-space: nowrap
    }

    .dl-horizontal dd {
        margin-left: 180px
    }
}

abbr[data-original-title], abbr[title] {
    cursor: help;
    border-bottom: 1px dotted #777
}

.initialism {
    font-size: 90%
}

blockquote {
    padding: 10px 20px;
    margin: 0 0 20px;
    font-size: 17.5px;
    border-left: 5px solid #eee
}

blockquote ol:last-child, blockquote p:last-child, blockquote ul:last-child {
    margin-bottom: 0
}

blockquote .small, blockquote footer, blockquote small {
    display: block;
    font-size: 80%;
    line-height: 1.42857;
    color: #777
}

blockquote .small:before, blockquote footer:before, blockquote small:before {
    content: '\2014 \00A0'
}

.blockquote-reverse, blockquote.pull-right {
    padding-right: 15px;
    padding-left: 0;
    border-right: 5px solid #eee;
    border-left: 0;
    text-align: right
}

.blockquote-reverse .small:before, .blockquote-reverse footer:before, .blockquote-reverse small:before, blockquote.pull-right .small:before, blockquote.pull-right footer:before, blockquote.pull-right small:before {
    content: ''
}

.blockquote-reverse .small:after, .blockquote-reverse footer:after, .blockquote-reverse small:after, blockquote.pull-right .small:after, blockquote.pull-right footer:after, blockquote.pull-right small:after {
    content: '\00A0 \2014'
}

address {
    margin-bottom: 20px;
    font-style: normal;
    line-height: 1.42857
}

code, kbd, pre, samp {
    font-family: Menlo, Monaco, Consolas, "Courier New", monospace
}

code {
    padding: 2px 4px;
    font-size: 90%;
    color: #c7254e;
    background-color: #f9f2f4;
    border-radius: 4px
}

kbd {
    padding: 2px 4px;
    font-size: 90%;
    color: #fff;
    background-color: #333;
    border-radius: 3px;
    box-shadow: inset 0 -1px 0 rgba(0, 0, 0, .25)
}

kbd kbd {
    padding: 0;
    font-size: 100%;
    font-weight: 700;
    box-shadow: none
}

pre {
    display: block;
    padding: 9.5px;
    margin: 0 0 10px;
    font-size: 13px;
    line-height: 1.42857;
    word-break: break-all;
    word-wrap: break-word;
    color: #333;
    background-color: #f5f5f5;
    border: 1px solid #ccc;
    border-radius: 4px
}

pre code {
    padding: 0;
    font-size: inherit;
    color: inherit;
    white-space: pre-wrap;
    background-color: transparent;
    border-radius: 0
}

.pre-scrollable {
    max-height: 340px;
    overflow-y: scroll
}

.container {
    margin-right: auto;
    margin-left: auto;
    padding-left: 15px;
    padding-right: 15px
}

.container:after, .container:before {
    content: " ";
    display: table
}

.container:after {
    clear: both
}

@media (min-width: 768px) {
    .container {
        width: 750px
    }
}

@media (min-width: 992px) {
    .container {
        width: 970px
    }
}

@media (min-width: 1200px) {
    .container {
        width: 1170px
    }
}

.container-fluid {
    margin-right: auto;
    margin-left: auto;
    padding-left: 15px;
    padding-right: 15px
}

.container-fluid:after, .container-fluid:before {
    content: " ";
    display: table
}

.container-fluid:after {
    clear: both
}

.row {
    margin-left: -15px;
    margin-right: -15px
}

.row:after, .row:before {
    content: " ";
    display: table
}

.row:after {
    clear: both
}

.col-lg-1, .col-lg-10, .col-lg-11, .col-lg-12, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-md-1, .col-md-10, .col-md-11, .col-md-12, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-sm-1, .col-sm-10, .col-sm-11, .col-sm-12, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-xs-1, .col-xs-10, .col-xs-11, .col-xs-12, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9 {
    position: relative;
    min-height: 1px;
    padding-left: 15px;
    padding-right: 15px
}

.col-xs-1, .col-xs-10, .col-xs-11, .col-xs-12, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9 {
    float: left
}

.col-xs-1 {
    width: 8.33333%
}

.col-xs-2 {
    width: 16.66667%
}

.col-xs-3 {
    width: 25%
}

.col-xs-4 {
    width: 33.33333%
}

.col-xs-5 {
    width: 41.66667%
}

.col-xs-6 {
    width: 50%
}

.col-xs-7 {
    width: 58.33333%
}

.col-xs-8 {
    width: 66.66667%
}

.col-xs-9 {
    width: 75%
}

.col-xs-10 {
    width: 83.33333%
}

.col-xs-11 {
    width: 91.66667%
}

.col-xs-12 {
    width: 100%
}

.col-xs-pull-0 {
    right: auto
}

.col-xs-pull-1 {
    right: 8.33333%
}

.col-xs-pull-2 {
    right: 16.66667%
}

.col-xs-pull-3 {
    right: 25%
}

.col-xs-pull-4 {
    right: 33.33333%
}

.col-xs-pull-5 {
    right: 41.66667%
}

.col-xs-pull-6 {
    right: 50%
}

.col-xs-pull-7 {
    right: 58.33333%
}

.col-xs-pull-8 {
    right: 66.66667%
}

.col-xs-pull-9 {
    right: 75%
}

.col-xs-pull-10 {
    right: 83.33333%
}

.col-xs-pull-11 {
    right: 91.66667%
}

.col-xs-pull-12 {
    right: 100%
}

.col-xs-push-0 {
    left: auto
}

.col-xs-push-1 {
    left: 8.33333%
}

.col-xs-push-2 {
    left: 16.66667%
}

.col-xs-push-3 {
    left: 25%
}

.col-xs-push-4 {
    left: 33.33333%
}

.col-xs-push-5 {
    left: 41.66667%
}

.col-xs-push-6 {
    left: 50%
}

.col-xs-push-7 {
    left: 58.33333%
}

.col-xs-push-8 {
    left: 66.66667%
}

.col-xs-push-9 {
    left: 75%
}

.col-xs-push-10 {
    left: 83.33333%
}

.col-xs-push-11 {
    left: 91.66667%
}

.col-xs-push-12 {
    left: 100%
}

.col-xs-offset-0 {
    margin-left: 0
}

.col-xs-offset-1 {
    margin-left: 8.33333%
}

.col-xs-offset-2 {
    margin-left: 16.66667%
}

.col-xs-offset-3 {
    margin-left: 25%
}

.col-xs-offset-4 {
    margin-left: 33.33333%
}

.col-xs-offset-5 {
    margin-left: 41.66667%
}

.col-xs-offset-6 {
    margin-left: 50%
}

.col-xs-offset-7 {
    margin-left: 58.33333%
}

.col-xs-offset-8 {
    margin-left: 66.66667%
}

.col-xs-offset-9 {
    margin-left: 75%
}

.col-xs-offset-10 {
    margin-left: 83.33333%
}

.col-xs-offset-11 {
    margin-left: 91.66667%
}

.col-xs-offset-12 {
    margin-left: 100%
}

@media (min-width: 768px) {
    .col-sm-1, .col-sm-10, .col-sm-11, .col-sm-12, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9 {
        float: left
    }

    .col-sm-1 {
        width: 8.33333%
    }

    .col-sm-2 {
        width: 16.66667%
    }

    .col-sm-3 {
        width: 25%
    }

    .col-sm-4 {
        width: 33.33333%
    }

    .col-sm-5 {
        width: 41.66667%
    }

    .col-sm-6 {
        width: 50%
    }

    .col-sm-7 {
        width: 58.33333%
    }

    .col-sm-8 {
        width: 66.66667%
    }

    .col-sm-9 {
        width: 75%
    }

    .col-sm-10 {
        width: 83.33333%
    }

    .col-sm-11 {
        width: 91.66667%
    }

    .col-sm-12 {
        width: 100%
    }

    .col-sm-pull-0 {
        right: auto
    }

    .col-sm-pull-1 {
        right: 8.33333%
    }

    .col-sm-pull-2 {
        right: 16.66667%
    }

    .col-sm-pull-3 {
        right: 25%
    }

    .col-sm-pull-4 {
        right: 33.33333%
    }

    .col-sm-pull-5 {
        right: 41.66667%
    }

    .col-sm-pull-6 {
        right: 50%
    }

    .col-sm-pull-7 {
        right: 58.33333%
    }

    .col-sm-pull-8 {
        right: 66.66667%
    }

    .col-sm-pull-9 {
        right: 75%
    }

    .col-sm-pull-10 {
        right: 83.33333%
    }

    .col-sm-pull-11 {
        right: 91.66667%
    }

    .col-sm-pull-12 {
        right: 100%
    }

    .col-sm-push-0 {
        left: auto
    }

    .col-sm-push-1 {
        left: 8.33333%
    }

    .col-sm-push-2 {
        left: 16.66667%
    }

    .col-sm-push-3 {
        left: 25%
    }

    .col-sm-push-4 {
        left: 33.33333%
    }

    .col-sm-push-5 {
        left: 41.66667%
    }

    .col-sm-push-6 {
        left: 50%
    }

    .col-sm-push-7 {
        left: 58.33333%
    }

    .col-sm-push-8 {
        left: 66.66667%
    }

    .col-sm-push-9 {
        left: 75%
    }

    .col-sm-push-10 {
        left: 83.33333%
    }

    .col-sm-push-11 {
        left: 91.66667%
    }

    .col-sm-push-12 {
        left: 100%
    }

    .col-sm-offset-0 {
        margin-left: 0
    }

    .col-sm-offset-1 {
        margin-left: 8.33333%
    }

    .col-sm-offset-2 {
        margin-left: 16.66667%
    }

    .col-sm-offset-3 {
        margin-left: 25%
    }

    .col-sm-offset-4 {
        margin-left: 33.33333%
    }

    .col-sm-offset-5 {
        margin-left: 41.66667%
    }

    .col-sm-offset-6 {
        margin-left: 50%
    }

    .col-sm-offset-7 {
        margin-left: 58.33333%
    }

    .col-sm-offset-8 {
        margin-left: 66.66667%
    }

    .col-sm-offset-9 {
        margin-left: 75%
    }

    .col-sm-offset-10 {
        margin-left: 83.33333%
    }

    .col-sm-offset-11 {
        margin-left: 91.66667%
    }

    .col-sm-offset-12 {
        margin-left: 100%
    }
}

@media (min-width: 992px) {
    .col-md-1, .col-md-10, .col-md-11, .col-md-12, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9 {
        float: left
    }

    .col-md-1 {
        width: 8.33333%
    }

    .col-md-2 {
        width: 16.66667%
    }

    .col-md-3 {
        width: 25%
    }

    .col-md-4 {
        width: 33.33333%
    }

    .col-md-5 {
        width: 41.66667%
    }

    .col-md-6 {
        width: 50%
    }

    .col-md-7 {
        width: 58.33333%
    }

    .col-md-8 {
        width: 66.66667%
    }

    .col-md-9 {
        width: 75%
    }

    .col-md-10 {
        width: 83.33333%
    }

    .col-md-11 {
        width: 91.66667%
    }

    .col-md-12 {
        width: 100%
    }

    .col-md-pull-0 {
        right: auto
    }

    .col-md-pull-1 {
        right: 8.33333%
    }

    .col-md-pull-2 {
        right: 16.66667%
    }

    .col-md-pull-3 {
        right: 25%
    }

    .col-md-pull-4 {
        right: 33.33333%
    }

    .col-md-pull-5 {
        right: 41.66667%
    }

    .col-md-pull-6 {
        right: 50%
    }

    .col-md-pull-7 {
        right: 58.33333%
    }

    .col-md-pull-8 {
        right: 66.66667%
    }

    .col-md-pull-9 {
        right: 75%
    }

    .col-md-pull-10 {
        right: 83.33333%
    }

    .col-md-pull-11 {
        right: 91.66667%
    }

    .col-md-pull-12 {
        right: 100%
    }

    .col-md-push-0 {
        left: auto
    }

    .col-md-push-1 {
        left: 8.33333%
    }

    .col-md-push-2 {
        left: 16.66667%
    }

    .col-md-push-3 {
        left: 25%
    }

    .col-md-push-4 {
        left: 33.33333%
    }

    .col-md-push-5 {
        left: 41.66667%
    }

    .col-md-push-6 {
        left: 50%
    }

    .col-md-push-7 {
        left: 58.33333%
    }

    .col-md-push-8 {
        left: 66.66667%
    }

    .col-md-push-9 {
        left: 75%
    }

    .col-md-push-10 {
        left: 83.33333%
    }

    .col-md-push-11 {
        left: 91.66667%
    }

    .col-md-push-12 {
        left: 100%
    }

    .col-md-offset-0 {
        margin-left: 0
    }

    .col-md-offset-1 {
        margin-left: 8.33333%
    }

    .col-md-offset-2 {
        margin-left: 16.66667%
    }

    .col-md-offset-3 {
        margin-left: 25%
    }

    .col-md-offset-4 {
        margin-left: 33.33333%
    }

    .col-md-offset-5 {
        margin-left: 41.66667%
    }

    .col-md-offset-6 {
        margin-left: 50%
    }

    .col-md-offset-7 {
        margin-left: 58.33333%
    }

    .col-md-offset-8 {
        margin-left: 66.66667%
    }

    .col-md-offset-9 {
        margin-left: 75%
    }

    .col-md-offset-10 {
        margin-left: 83.33333%
    }

    .col-md-offset-11 {
        margin-left: 91.66667%
    }

    .col-md-offset-12 {
        margin-left: 100%
    }
}

@media (min-width: 1200px) {
    .col-lg-1, .col-lg-10, .col-lg-11, .col-lg-12, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9 {
        float: left
    }

    .col-lg-1 {
        width: 8.33333%
    }

    .col-lg-2 {
        width: 16.66667%
    }

    .col-lg-3 {
        width: 25%
    }

    .col-lg-4 {
        width: 33.33333%
    }

    .col-lg-5 {
        width: 41.66667%
    }

    .col-lg-6 {
        width: 50%
    }

    .col-lg-7 {
        width: 58.33333%
    }

    .col-lg-8 {
        width: 66.66667%
    }

    .col-lg-9 {
        width: 75%
    }

    .col-lg-10 {
        width: 83.33333%
    }

    .col-lg-11 {
        width: 91.66667%
    }

    .col-lg-12 {
        width: 100%
    }

    .col-lg-pull-0 {
        right: auto
    }

    .col-lg-pull-1 {
        right: 8.33333%
    }

    .col-lg-pull-2 {
        right: 16.66667%
    }

    .col-lg-pull-3 {
        right: 25%
    }

    .col-lg-pull-4 {
        right: 33.33333%
    }

    .col-lg-pull-5 {
        right: 41.66667%
    }

    .col-lg-pull-6 {
        right: 50%
    }

    .col-lg-pull-7 {
        right: 58.33333%
    }

    .col-lg-pull-8 {
        right: 66.66667%
    }

    .col-lg-pull-9 {
        right: 75%
    }

    .col-lg-pull-10 {
        right: 83.33333%
    }

    .col-lg-pull-11 {
        right: 91.66667%
    }

    .col-lg-pull-12 {
        right: 100%
    }

    .col-lg-push-0 {
        left: auto
    }

    .col-lg-push-1 {
        left: 8.33333%
    }

    .col-lg-push-2 {
        left: 16.66667%
    }

    .col-lg-push-3 {
        left: 25%
    }

    .col-lg-push-4 {
        left: 33.33333%
    }

    .col-lg-push-5 {
        left: 41.66667%
    }

    .col-lg-push-6 {
        left: 50%
    }

    .col-lg-push-7 {
        left: 58.33333%
    }

    .col-lg-push-8 {
        left: 66.66667%
    }

    .col-lg-push-9 {
        left: 75%
    }

    .col-lg-push-10 {
        left: 83.33333%
    }

    .col-lg-push-11 {
        left: 91.66667%
    }

    .col-lg-push-12 {
        left: 100%
    }

    .col-lg-offset-0 {
        margin-left: 0
    }

    .col-lg-offset-1 {
        margin-left: 8.33333%
    }

    .col-lg-offset-2 {
        margin-left: 16.66667%
    }

    .col-lg-offset-3 {
        margin-left: 25%
    }

    .col-lg-offset-4 {
        margin-left: 33.33333%
    }

    .col-lg-offset-5 {
        margin-left: 41.66667%
    }

    .col-lg-offset-6 {
        margin-left: 50%
    }

    .col-lg-offset-7 {
        margin-left: 58.33333%
    }

    .col-lg-offset-8 {
        margin-left: 66.66667%
    }

    .col-lg-offset-9 {
        margin-left: 75%
    }

    .col-lg-offset-10 {
        margin-left: 83.33333%
    }

    .col-lg-offset-11 {
        margin-left: 91.66667%
    }

    .col-lg-offset-12 {
        margin-left: 100%
    }
}

table {
    background-color: transparent
}

caption {
    padding-top: 8px;
    padding-bottom: 8px;
    color: #777;
    text-align: left
}

th {
    text-align: left
}

.table {
    width: 100%;
    max-width: 100%;
    margin-bottom: 20px
}

.table > tbody > tr > td, .table > tbody > tr > th, .table > tfoot > tr > td, .table > tfoot > tr > th, .table > thead > tr > td, .table > thead > tr > th {
    padding: 8px;
    line-height: 1.42857;
    vertical-align: top;
    border-top: 1px solid #ddd
}

.table > thead > tr > th {
    vertical-align: bottom;
    border-bottom: 2px solid #ddd
}

.table > caption + thead > tr:first-child > td, .table > caption + thead > tr:first-child > th, .table > colgroup + thead > tr:first-child > td, .table > colgroup + thead > tr:first-child > th, .table > thead:first-child > tr:first-child > td, .table > thead:first-child > tr:first-child > th {
    border-top: 0
}

.table > tbody + tbody {
    border-top: 2px solid #ddd
}

.table .table {
    background-color: #fff
}

.table-condensed > tbody > tr > td, .table-condensed > tbody > tr > th, .table-condensed > tfoot > tr > td, .table-condensed > tfoot > tr > th, .table-condensed > thead > tr > td, .table-condensed > thead > tr > th {
    padding: 5px
}

.table-bordered {
    border: 1px solid #ddd
}

.table-bordered > tbody > tr > td, .table-bordered > tbody > tr > th, .table-bordered > tfoot > tr > td, .table-bordered > tfoot > tr > th, .table-bordered > thead > tr > td, .table-bordered > thead > tr > th {
    border: 1px solid #ddd
}

.table-bordered > thead > tr > td, .table-bordered > thead > tr > th {
    border-bottom-width: 2px
}

.table-striped > tbody > tr:nth-of-type(odd) {
    background-color: #f9f9f9
}

.table-hover > tbody > tr:hover {
    background-color: #f5f5f5
}

table col[class*=col-] {
    position: static;
    float: none;
    display: table-column
}

table td[class*=col-], table th[class*=col-] {
    position: static;
    float: none;
    display: table-cell
}

.table > tbody > tr.active > td, .table > tbody > tr.active > th, .table > tbody > tr > td.active, .table > tbody > tr > th.active, .table > tfoot > tr.active > td, .table > tfoot > tr.active > th, .table > tfoot > tr > td.active, .table > tfoot > tr > th.active, .table > thead > tr.active > td, .table > thead > tr.active > th, .table > thead > tr > td.active, .table > thead > tr > th.active {
    background-color: #f5f5f5
}

.table-hover > tbody > tr.active:hover > td, .table-hover > tbody > tr.active:hover > th, .table-hover > tbody > tr:hover > .active, .table-hover > tbody > tr > td.active:hover, .table-hover > tbody > tr > th.active:hover {
    background-color: #e8e8e8
}

.table > tbody > tr.success > td, .table > tbody > tr.success > th, .table > tbody > tr > td.success, .table > tbody > tr > th.success, .table > tfoot > tr.success > td, .table > tfoot > tr.success > th, .table > tfoot > tr > td.success, .table > tfoot > tr > th.success, .table > thead > tr.success > td, .table > thead > tr.success > th, .table > thead > tr > td.success, .table > thead > tr > th.success {
    background-color: #dff0d8
}

.table-hover > tbody > tr.success:hover > td, .table-hover > tbody > tr.success:hover > th, .table-hover > tbody > tr:hover > .success, .table-hover > tbody > tr > td.success:hover, .table-hover > tbody > tr > th.success:hover {
    background-color: #d0e9c6
}

.table > tbody > tr.info > td, .table > tbody > tr.info > th, .table > tbody > tr > td.info, .table > tbody > tr > th.info, .table > tfoot > tr.info > td, .table > tfoot > tr.info > th, .table > tfoot > tr > td.info, .table > tfoot > tr > th.info, .table > thead > tr.info > td, .table > thead > tr.info > th, .table > thead > tr > td.info, .table > thead > tr > th.info {
    background-color: #d9edf7
}

.table-hover > tbody > tr.info:hover > td, .table-hover > tbody > tr.info:hover > th, .table-hover > tbody > tr:hover > .info, .table-hover > tbody > tr > td.info:hover, .table-hover > tbody > tr > th.info:hover {
    background-color: #c4e3f3
}

.table > tbody > tr.warning > td, .table > tbody > tr.warning > th, .table > tbody > tr > td.warning, .table > tbody > tr > th.warning, .table > tfoot > tr.warning > td, .table > tfoot > tr.warning > th, .table > tfoot > tr > td.warning, .table > tfoot > tr > th.warning, .table > thead > tr.warning > td, .table > thead > tr.warning > th, .table > thead > tr > td.warning, .table > thead > tr > th.warning {
    background-color: #fcf8e3
}

.table-hover > tbody > tr.warning:hover > td, .table-hover > tbody > tr.warning:hover > th, .table-hover > tbody > tr:hover > .warning, .table-hover > tbody > tr > td.warning:hover, .table-hover > tbody > tr > th.warning:hover {
    background-color: #faf2cc
}

.table > tbody > tr.danger > td, .table > tbody > tr.danger > th, .table > tbody > tr > td.danger, .table > tbody > tr > th.danger, .table > tfoot > tr.danger > td, .table > tfoot > tr.danger > th, .table > tfoot > tr > td.danger, .table > tfoot > tr > th.danger, .table > thead > tr.danger > td, .table > thead > tr.danger > th, .table > thead > tr > td.danger, .table > thead > tr > th.danger {
    background-color: #f2dede
}

.table-hover > tbody > tr.danger:hover > td, .table-hover > tbody > tr.danger:hover > th, .table-hover > tbody > tr:hover > .danger, .table-hover > tbody > tr > td.danger:hover, .table-hover > tbody > tr > th.danger:hover {
    background-color: #ebcccc
}

.table-buttons {
    margin: 0 5px;
    padding: 0
}

.table-buttons li {
    float: left;
    margin: 5px
}

.table-responsive {
    overflow-x: auto;
    min-height: 600px
}

@media screen and (max-width: 767px) {
    .table-responsive {
        width: 100%;
        margin-bottom: 15px;
        overflow-y: hidden;
        -ms-overflow-style: -ms-autohiding-scrollbar;
        border: 1px solid #ddd
    }

    .table-responsive > .table {
        margin-bottom: 0
    }

    .table-responsive > .table > tbody > tr > td, .table-responsive > .table > tbody > tr > th, .table-responsive > .table > tfoot > tr > td, .table-responsive > .table > tfoot > tr > th, .table-responsive > .table > thead > tr > td, .table-responsive > .table > thead > tr > th {
        white-space: nowrap
    }

    .table-responsive > .table-bordered {
        border: 0
    }

    .table-responsive > .table-bordered > tbody > tr > td:first-child, .table-responsive > .table-bordered > tbody > tr > th:first-child, .table-responsive > .table-bordered > tfoot > tr > td:first-child, .table-responsive > .table-bordered > tfoot > tr > th:first-child, .table-responsive > .table-bordered > thead > tr > td:first-child, .table-responsive > .table-bordered > thead > tr > th:first-child {
        border-left: 0
    }

    .table-responsive > .table-bordered > tbody > tr > td:last-child, .table-responsive > .table-bordered > tbody > tr > th:last-child, .table-responsive > .table-bordered > tfoot > tr > td:last-child, .table-responsive > .table-bordered > tfoot > tr > th:last-child, .table-responsive > .table-bordered > thead > tr > td:last-child, .table-responsive > .table-bordered > thead > tr > th:last-child {
        border-right: 0
    }

    .table-responsive > .table-bordered > tbody > tr:last-child > td, .table-responsive > .table-bordered > tbody > tr:last-child > th, .table-responsive > .table-bordered > tfoot > tr:last-child > td, .table-responsive > .table-bordered > tfoot > tr:last-child > th {
        border-bottom: 0
    }
}

fieldset {
    padding: 0;
    margin: 0;
    border: 0;
    min-width: 0
}

legend {
    display: block;
    width: 100%;
    padding: 0;
    margin-bottom: 20px;
    font-size: 21px;
    line-height: inherit;
    color: #333;
    border: 0;
    border-bottom: 1px solid #e5e5e5
}

label {
    display: inline-block;
    max-width: 100%;
    margin-bottom: 5px;
    font-weight: 700
}

input[type=search] {
    box-sizing: border-box
}

input[type=checkbox], input[type=radio] {
    margin: 4px 0 0;
    line-height: normal
}

input[type=file] {
    display: block
}

input[type=range] {
    display: block;
    width: 100%
}

select[multiple], select[size] {
    height: auto
}

input[type=checkbox]:focus, input[type=file]:focus, input[type=radio]:focus {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px
}

output {
    display: block;
    padding-top: 7px;
    font-size: 14px;
    line-height: 1.42857;
    color: #555
}

.form-control {
    display: block;
    width: 100%;
    height: 34px;
    padding: 6px 12px;
    font-size: 14px;
    line-height: 1.42857;
    color: #555;
    background-color: #fff;
    background-image: none;
    border: 1px solid #ccc;
    border-radius: 4px;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075);
    transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s
}

.form-control:focus {
    border-color: #66afe9;
    outline: 0;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 8px rgba(102, 175, 233, .6)
}

.form-control::-moz-placeholder {
    color: #999;
    opacity: 1
}

.form-control:-ms-input-placeholder {
    color: #999
}

.form-control::-webkit-input-placeholder {
    color: #999
}

.form-control::-ms-expand {
    border: 0;
    background-color: transparent
}

.form-control[disabled], .form-control[readonly], fieldset[disabled] .form-control {
    background-color: #eee;
    opacity: 1
}

.form-control[disabled], fieldset[disabled] .form-control {
    cursor: not-allowed
}

textarea.form-control {
    height: auto
}

input[type=search] {
    -webkit-appearance: none
}

@media screen and (-webkit-min-device-pixel-ratio: 0) {
    input[type=date].form-control, input[type=datetime-local].form-control, input[type=month].form-control, input[type=time].form-control {
        line-height: 34px
    }

    .input-group-sm input[type=date], .input-group-sm input[type=datetime-local], .input-group-sm input[type=month], .input-group-sm input[type=time], .input-group-sm > .input-group-btn > input[type=date].btn, .input-group-sm > .input-group-btn > input[type=datetime-local].btn, .input-group-sm > .input-group-btn > input[type=month].btn, .input-group-sm > .input-group-btn > input[type=time].btn, .input-group-sm > input[type=date].form-control, .input-group-sm > input[type=date].input-group-addon, .input-group-sm > input[type=datetime-local].form-control, .input-group-sm > input[type=datetime-local].input-group-addon, .input-group-sm > input[type=month].form-control, .input-group-sm > input[type=month].input-group-addon, .input-group-sm > input[type=time].form-control, .input-group-sm > input[type=time].input-group-addon, input[type=date].input-sm, input[type=datetime-local].input-sm, input[type=month].input-sm, input[type=time].input-sm {
        line-height: 30px
    }

    .input-group-lg input[type=date], .input-group-lg input[type=datetime-local], .input-group-lg input[type=month], .input-group-lg input[type=time], .input-group-lg > .input-group-btn > input[type=date].btn, .input-group-lg > .input-group-btn > input[type=datetime-local].btn, .input-group-lg > .input-group-btn > input[type=month].btn, .input-group-lg > .input-group-btn > input[type=time].btn, .input-group-lg > input[type=date].form-control, .input-group-lg > input[type=date].input-group-addon, .input-group-lg > input[type=datetime-local].form-control, .input-group-lg > input[type=datetime-local].input-group-addon, .input-group-lg > input[type=month].form-control, .input-group-lg > input[type=month].input-group-addon, .input-group-lg > input[type=time].form-control, .input-group-lg > input[type=time].input-group-addon, input[type=date].input-lg, input[type=datetime-local].input-lg, input[type=month].input-lg, input[type=time].input-lg {
        line-height: 46px
    }
}

.form-group {
    margin-bottom: 15px
}

.checkbox, .radio {
    position: relative;
    display: block;
    margin-top: 10px;
    margin-bottom: 10px
}

.checkbox label, .radio label {
    min-height: 20px;
    padding-left: 20px;
    margin-bottom: 0;
    font-weight: 400;
    cursor: pointer
}

.checkbox input[type=checkbox], .checkbox-inline input[type=checkbox], .radio input[type=radio], .radio-inline input[type=radio] {
    position: absolute;
    margin-left: -20px
}

.checkbox + .checkbox, .radio + .radio {
    margin-top: -5px
}

.checkbox-inline, .radio-inline {
    position: relative;
    display: inline-block;
    padding-left: 20px;
    margin-bottom: 0;
    vertical-align: middle;
    font-weight: 400;
    cursor: pointer
}

.checkbox-inline + .checkbox-inline, .radio-inline + .radio-inline {
    margin-top: 0;
    margin-left: 10px
}

fieldset[disabled] input[type=checkbox], fieldset[disabled] input[type=radio], input[type=checkbox].disabled, input[type=checkbox][disabled], input[type=radio].disabled, input[type=radio][disabled] {
    cursor: not-allowed
}

.checkbox-inline.disabled, .radio-inline.disabled, fieldset[disabled] .checkbox-inline, fieldset[disabled] .radio-inline {
    cursor: not-allowed
}

.checkbox.disabled label, .radio.disabled label, fieldset[disabled] .checkbox label, fieldset[disabled] .radio label {
    cursor: not-allowed
}

.form-control-static {
    padding-top: 7px;
    padding-bottom: 7px;
    margin-bottom: 0;
    min-height: 34px
}

.form-control-static.input-lg, .form-control-static.input-sm, .input-group-lg > .form-control-static.form-control, .input-group-lg > .form-control-static.input-group-addon, .input-group-lg > .input-group-btn > .form-control-static.btn, .input-group-sm > .form-control-static.form-control, .input-group-sm > .form-control-static.input-group-addon, .input-group-sm > .input-group-btn > .form-control-static.btn {
    padding-left: 0;
    padding-right: 0
}

.input-group-sm > .form-control, .input-group-sm > .input-group-addon, .input-group-sm > .input-group-btn > .btn, .input-sm {
    height: 30px;
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px
}

.input-group-sm > .input-group-btn > select.btn, .input-group-sm > select.form-control, .input-group-sm > select.input-group-addon, select.input-sm {
    height: 30px;
    line-height: 30px
}

.input-group-sm > .input-group-btn > select[multiple].btn, .input-group-sm > .input-group-btn > textarea.btn, .input-group-sm > select[multiple].form-control, .input-group-sm > select[multiple].input-group-addon, .input-group-sm > textarea.form-control, .input-group-sm > textarea.input-group-addon, select[multiple].input-sm, textarea.input-sm {
    height: auto
}

.form-group-sm .form-control {
    height: 30px;
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px
}

.form-group-sm select.form-control {
    height: 30px;
    line-height: 30px
}

.form-group-sm select[multiple].form-control, .form-group-sm textarea.form-control {
    height: auto
}

.form-group-sm .form-control-static {
    height: 30px;
    min-height: 32px;
    padding: 6px 10px;
    font-size: 12px;
    line-height: 1.5
}

.input-group-lg > .form-control, .input-group-lg > .input-group-addon, .input-group-lg > .input-group-btn > .btn, .input-lg {
    height: 46px;
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33333;
    border-radius: 6px
}

.input-group-lg > .input-group-btn > select.btn, .input-group-lg > select.form-control, .input-group-lg > select.input-group-addon, select.input-lg {
    height: 46px;
    line-height: 46px
}

.input-group-lg > .input-group-btn > select[multiple].btn, .input-group-lg > .input-group-btn > textarea.btn, .input-group-lg > select[multiple].form-control, .input-group-lg > select[multiple].input-group-addon, .input-group-lg > textarea.form-control, .input-group-lg > textarea.input-group-addon, select[multiple].input-lg, textarea.input-lg {
    height: auto
}

.form-group-lg .form-control {
    height: 46px;
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33333;
    border-radius: 6px
}

.form-group-lg select.form-control {
    height: 46px;
    line-height: 46px
}

.form-group-lg select[multiple].form-control, .form-group-lg textarea.form-control {
    height: auto
}

.form-group-lg .form-control-static {
    height: 46px;
    min-height: 38px;
    padding: 11px 16px;
    font-size: 18px;
    line-height: 1.33333
}

.has-feedback {
    position: relative
}

.has-feedback .form-control {
    padding-right: 42.5px
}

.form-control-feedback {
    position: absolute;
    top: 0;
    right: 0;
    z-index: 2;
    display: block;
    width: 34px;
    height: 34px;
    line-height: 34px;
    text-align: center;
    pointer-events: none
}

.form-group-lg .form-control + .form-control-feedback, .input-group-lg + .form-control-feedback, .input-group-lg > .form-control + .form-control-feedback, .input-group-lg > .input-group-addon + .form-control-feedback, .input-group-lg > .input-group-btn > .btn + .form-control-feedback, .input-lg + .form-control-feedback {
    width: 46px;
    height: 46px;
    line-height: 46px
}

.form-group-sm .form-control + .form-control-feedback, .input-group-sm + .form-control-feedback, .input-group-sm > .form-control + .form-control-feedback, .input-group-sm > .input-group-addon + .form-control-feedback, .input-group-sm > .input-group-btn > .btn + .form-control-feedback, .input-sm + .form-control-feedback {
    width: 30px;
    height: 30px;
    line-height: 30px
}

.has-success .checkbox, .has-success .checkbox-inline, .has-success .control-label, .has-success .help-block, .has-success .radio, .has-success .radio-inline, .has-success.checkbox label, .has-success.checkbox-inline label, .has-success.radio label, .has-success.radio-inline label {
    color: #3c763d
}

.has-success .form-control {
    border-color: #3c763d;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075)
}

.has-success .form-control:focus {
    border-color: #2b542c;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #67b168
}

.has-success .input-group-addon {
    color: #3c763d;
    border-color: #3c763d;
    background-color: #dff0d8
}

.has-success .form-control-feedback {
    color: #3c763d
}

.has-warning .checkbox, .has-warning .checkbox-inline, .has-warning .control-label, .has-warning .help-block, .has-warning .radio, .has-warning .radio-inline, .has-warning.checkbox label, .has-warning.checkbox-inline label, .has-warning.radio label, .has-warning.radio-inline label {
    color: #8a6d3b
}

.has-warning .form-control {
    border-color: #8a6d3b;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075)
}

.has-warning .form-control:focus {
    border-color: #66512c;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #c0a16b
}

.has-warning .input-group-addon {
    color: #8a6d3b;
    border-color: #8a6d3b;
    background-color: #fcf8e3
}

.has-warning .form-control-feedback {
    color: #8a6d3b
}

.has-error .checkbox, .has-error .checkbox-inline, .has-error .control-label, .has-error .help-block, .has-error .radio, .has-error .radio-inline, .has-error.checkbox label, .has-error.checkbox-inline label, .has-error.radio label, .has-error.radio-inline label {
    color: #a94442
}

.has-error .form-control {
    border-color: #a94442;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075)
}

.has-error .form-control:focus {
    border-color: #843534;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #ce8483
}

.has-error .input-group-addon {
    color: #a94442;
    border-color: #a94442;
    background-color: #f2dede
}

.has-error .form-control-feedback {
    color: #a94442
}

.has-feedback label ~ .form-control-feedback {
    top: 25px
}

.has-feedback label.sr-only ~ .form-control-feedback {
    top: 0
}

.help-block {
    display: block;
    margin-top: 5px;
    margin-bottom: 10px;
    color: #737373
}

@media (min-width: 768px) {
    .form-inline .form-group {
        display: inline-block;
        margin-bottom: 0;
        vertical-align: middle
    }

    .form-inline .form-control {
        display: inline-block;
        width: auto;
        vertical-align: middle
    }

    .form-inline .form-control-static {
        display: inline-block
    }

    .form-inline .input-group {
        display: inline-table;
        vertical-align: middle
    }

    .form-inline .input-group .form-control, .form-inline .input-group .input-group-addon, .form-inline .input-group .input-group-btn {
        width: auto
    }

    .form-inline .input-group > .form-control {
        width: 100%
    }

    .form-inline .control-label {
        margin-bottom: 0;
        vertical-align: middle
    }

    .form-inline .checkbox, .form-inline .radio {
        display: inline-block;
        margin-top: 0;
        margin-bottom: 0;
        vertical-align: middle
    }

    .form-inline .checkbox label, .form-inline .radio label {
        padding-left: 0
    }

    .form-inline .checkbox input[type=checkbox], .form-inline .radio input[type=radio] {
        position: relative;
        margin-left: 0
    }

    .form-inline .has-feedback .form-control-feedback {
        top: 0
    }
}

.form-horizontal .checkbox, .form-horizontal .checkbox-inline, .form-horizontal .radio, .form-horizontal .radio-inline {
    margin-top: 0;
    margin-bottom: 0;
    padding-top: 7px
}

.form-horizontal .checkbox, .form-horizontal .radio {
    min-height: 27px
}

.form-horizontal .form-group {
    margin-left: -15px;
    margin-right: -15px
}

.form-horizontal .form-group:after, .form-horizontal .form-group:before {
    content: " ";
    display: table
}

.form-horizontal .form-group:after {
    clear: both
}

@media (min-width: 768px) {
    .form-horizontal .control-label {
        text-align: right;
        margin-bottom: 0;
        padding-top: 7px
    }
}

.form-horizontal .has-feedback .form-control-feedback {
    right: 15px
}

@media (min-width: 768px) {
    .form-horizontal .form-group-lg .control-label {
        padding-top: 11px;
        font-size: 18px
    }
}

@media (min-width: 768px) {
    .form-horizontal .form-group-sm .control-label {
        padding-top: 6px;
        font-size: 12px
    }
}

.btn {
    display: inline-block;
    margin-bottom: 0;
    font-weight: 400;
    text-align: center;
    vertical-align: middle;
    -ms-touch-action: manipulation;
    touch-action: manipulation;
    cursor: pointer;
    background-image: none;
    border: 1px solid transparent;
    white-space: nowrap;
    padding: 6px 12px;
    font-size: 14px;
    line-height: 1.42857;
    border-radius: 4px;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none
}

.btn.active.focus, .btn.active:focus, .btn.focus, .btn:active.focus, .btn:active:focus, .btn:focus {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px
}

.btn.focus, .btn:focus, .btn:hover {
    color: #333;
    text-decoration: none
}

.btn.active, .btn:active {
    outline: 0;
    background-image: none;
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125)
}

.btn.disabled, .btn[disabled], fieldset[disabled] .btn {
    cursor: not-allowed;
    opacity: .65;
    box-shadow: none
}

a.btn.disabled, fieldset[disabled] a.btn {
    pointer-events: none
}

.btn-default {
    color: #333;
    background-color: #fff;
    border-color: #ccc
}

.btn-default.focus, .btn-default:focus {
    color: #333;
    background-color: #e6e6e6;
    border-color: #8c8c8c
}

.btn-default:hover {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad
}

.btn-default.active, .btn-default:active, .open > .btn-default.dropdown-toggle {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad
}

.btn-default.active.focus, .btn-default.active:focus, .btn-default.active:hover, .btn-default:active.focus, .btn-default:active:focus, .btn-default:active:hover, .open > .btn-default.dropdown-toggle.focus, .open > .btn-default.dropdown-toggle:focus, .open > .btn-default.dropdown-toggle:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c
}

.btn-default.active, .btn-default:active, .open > .btn-default.dropdown-toggle {
    background-image: none
}

.btn-default.disabled.focus, .btn-default.disabled:focus, .btn-default.disabled:hover, .btn-default[disabled].focus, .btn-default[disabled]:focus, .btn-default[disabled]:hover, fieldset[disabled] .btn-default.focus, fieldset[disabled] .btn-default:focus, fieldset[disabled] .btn-default:hover {
    background-color: #fff;
    border-color: #ccc
}

.btn-default .badge {
    color: #fff;
    background-color: #333
}

.btn-primary {
    color: #fff;
    background-color: #337ab7;
    border-color: #2e6da4
}

.btn-primary.focus, .btn-primary:focus {
    color: #fff;
    background-color: #286090;
    border-color: #122b40
}

.btn-primary:hover {
    color: #fff;
    background-color: #286090;
    border-color: #204d74
}

.btn-primary.active, .btn-primary:active, .open > .btn-primary.dropdown-toggle {
    color: #fff;
    background-color: #286090;
    border-color: #204d74
}

.btn-primary.active.focus, .btn-primary.active:focus, .btn-primary.active:hover, .btn-primary:active.focus, .btn-primary:active:focus, .btn-primary:active:hover, .open > .btn-primary.dropdown-toggle.focus, .open > .btn-primary.dropdown-toggle:focus, .open > .btn-primary.dropdown-toggle:hover {
    color: #fff;
    background-color: #204d74;
    border-color: #122b40
}

.btn-primary.active, .btn-primary:active, .open > .btn-primary.dropdown-toggle {
    background-image: none
}

.btn-primary.disabled.focus, .btn-primary.disabled:focus, .btn-primary.disabled:hover, .btn-primary[disabled].focus, .btn-primary[disabled]:focus, .btn-primary[disabled]:hover, fieldset[disabled] .btn-primary.focus, fieldset[disabled] .btn-primary:focus, fieldset[disabled] .btn-primary:hover {
    background-color: #337ab7;
    border-color: #2e6da4
}

.btn-primary .badge {
    color: #337ab7;
    background-color: #fff
}

.btn-success {
    color: #fff;
    background-color: #5cb85c;
    border-color: #4cae4c
}

.btn-success.focus, .btn-success:focus {
    color: #fff;
    background-color: #449d44;
    border-color: #255625
}

.btn-success:hover {
    color: #fff;
    background-color: #449d44;
    border-color: #398439
}

.btn-success.active, .btn-success:active, .open > .btn-success.dropdown-toggle {
    color: #fff;
    background-color: #449d44;
    border-color: #398439
}

.btn-success.active.focus, .btn-success.active:focus, .btn-success.active:hover, .btn-success:active.focus, .btn-success:active:focus, .btn-success:active:hover, .open > .btn-success.dropdown-toggle.focus, .open > .btn-success.dropdown-toggle:focus, .open > .btn-success.dropdown-toggle:hover {
    color: #fff;
    background-color: #398439;
    border-color: #255625
}

.btn-success.active, .btn-success:active, .open > .btn-success.dropdown-toggle {
    background-image: none
}

.btn-success.disabled.focus, .btn-success.disabled:focus, .btn-success.disabled:hover, .btn-success[disabled].focus, .btn-success[disabled]:focus, .btn-success[disabled]:hover, fieldset[disabled] .btn-success.focus, fieldset[disabled] .btn-success:focus, fieldset[disabled] .btn-success:hover {
    background-color: #5cb85c;
    border-color: #4cae4c
}

.btn-success .badge {
    color: #5cb85c;
    background-color: #fff
}

.btn-info {
    color: #fff;
    background-color: #5bc0de;
    border-color: #46b8da
}

.btn-info.focus, .btn-info:focus {
    color: #fff;
    background-color: #31b0d5;
    border-color: #1b6d85
}

.btn-info:hover {
    color: #fff;
    background-color: #31b0d5;
    border-color: #269abc
}

.btn-info.active, .btn-info:active, .open > .btn-info.dropdown-toggle {
    color: #fff;
    background-color: #31b0d5;
    border-color: #269abc
}

.btn-info.active.focus, .btn-info.active:focus, .btn-info.active:hover, .btn-info:active.focus, .btn-info:active:focus, .btn-info:active:hover, .open > .btn-info.dropdown-toggle.focus, .open > .btn-info.dropdown-toggle:focus, .open > .btn-info.dropdown-toggle:hover {
    color: #fff;
    background-color: #269abc;
    border-color: #1b6d85
}

.btn-info.active, .btn-info:active, .open > .btn-info.dropdown-toggle {
    background-image: none
}

.btn-info.disabled.focus, .btn-info.disabled:focus, .btn-info.disabled:hover, .btn-info[disabled].focus, .btn-info[disabled]:focus, .btn-info[disabled]:hover, fieldset[disabled] .btn-info.focus, fieldset[disabled] .btn-info:focus, fieldset[disabled] .btn-info:hover {
    background-color: #5bc0de;
    border-color: #46b8da
}

.btn-info .badge {
    color: #5bc0de;
    background-color: #fff
}

.btn-warning {
    color: #fff;
    background-color: #f0ad4e;
    border-color: #eea236
}

.btn-warning.focus, .btn-warning:focus {
    color: #fff;
    background-color: #ec971f;
    border-color: #985f0d
}

.btn-warning:hover {
    color: #fff;
    background-color: #ec971f;
    border-color: #d58512
}

.btn-warning.active, .btn-warning:active, .open > .btn-warning.dropdown-toggle {
    color: #fff;
    background-color: #ec971f;
    border-color: #d58512
}

.btn-warning.active.focus, .btn-warning.active:focus, .btn-warning.active:hover, .btn-warning:active.focus, .btn-warning:active:focus, .btn-warning:active:hover, .open > .btn-warning.dropdown-toggle.focus, .open > .btn-warning.dropdown-toggle:focus, .open > .btn-warning.dropdown-toggle:hover {
    color: #fff;
    background-color: #d58512;
    border-color: #985f0d
}

.btn-warning.active, .btn-warning:active, .open > .btn-warning.dropdown-toggle {
    background-image: none
}

.btn-warning.disabled.focus, .btn-warning.disabled:focus, .btn-warning.disabled:hover, .btn-warning[disabled].focus, .btn-warning[disabled]:focus, .btn-warning[disabled]:hover, fieldset[disabled] .btn-warning.focus, fieldset[disabled] .btn-warning:focus, fieldset[disabled] .btn-warning:hover {
    background-color: #f0ad4e;
    border-color: #eea236
}

.btn-warning .badge {
    color: #f0ad4e;
    background-color: #fff
}

.btn-danger {
    color: #fff;
    background-color: #d9534f;
    border-color: #d43f3a
}

.btn-danger.focus, .btn-danger:focus {
    color: #fff;
    background-color: #c9302c;
    border-color: #761c19
}

.btn-danger:hover {
    color: #fff;
    background-color: #c9302c;
    border-color: #ac2925
}

.btn-danger.active, .btn-danger:active, .open > .btn-danger.dropdown-toggle {
    color: #fff;
    background-color: #c9302c;
    border-color: #ac2925
}

.btn-danger.active.focus, .btn-danger.active:focus, .btn-danger.active:hover, .btn-danger:active.focus, .btn-danger:active:focus, .btn-danger:active:hover, .open > .btn-danger.dropdown-toggle.focus, .open > .btn-danger.dropdown-toggle:focus, .open > .btn-danger.dropdown-toggle:hover {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19
}

.btn-danger.active, .btn-danger:active, .open > .btn-danger.dropdown-toggle {
    background-image: none
}

.btn-danger.disabled.focus, .btn-danger.disabled:focus, .btn-danger.disabled:hover, .btn-danger[disabled].focus, .btn-danger[disabled]:focus, .btn-danger[disabled]:hover, fieldset[disabled] .btn-danger.focus, fieldset[disabled] .btn-danger:focus, fieldset[disabled] .btn-danger:hover {
    background-color: #d9534f;
    border-color: #d43f3a
}

.btn-danger .badge {
    color: #d9534f;
    background-color: #fff
}

.btn-link {
    color: #337ab7;
    font-weight: 400;
    border-radius: 0
}

.btn-link, .btn-link.active, .btn-link:active, .btn-link[disabled], fieldset[disabled] .btn-link {
    background-color: transparent;
    box-shadow: none
}

.btn-link, .btn-link:active, .btn-link:focus, .btn-link:hover {
    border-color: transparent
}

.btn-link:focus, .btn-link:hover {
    color: #23527c;
    text-decoration: underline;
    background-color: transparent
}

.btn-link[disabled]:focus, .btn-link[disabled]:hover, fieldset[disabled] .btn-link:focus, fieldset[disabled] .btn-link:hover {
    color: #777;
    text-decoration: none
}

.btn-group-lg > .btn, .btn-lg {
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33333;
    border-radius: 6px
}

.btn-group-sm > .btn, .btn-sm {
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px
}

.btn-group-xs > .btn, .btn-xs {
    padding: 1px 5px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px
}

.btn-block {
    display: block;
    width: 100%
}

.btn-block + .btn-block {
    margin-top: 5px
}

input[type=button].btn-block, input[type=reset].btn-block, input[type=submit].btn-block {
    width: 100%
}

.fade {
    opacity: 0;
    transition: opacity .15s linear
}

.fade.in {
    opacity: 1
}

.collapse {
    display: none
}

.collapse.in {
    display: block
}

tr.collapse.in {
    display: table-row
}

tbody.collapse.in {
    display: table-row-group
}

.collapsing {
    position: relative;
    height: 0;
    overflow: hidden;
    transition-property: height, visibility;
    transition-duration: .35s;
    transition-timing-function: ease
}

.caret {
    display: inline-block;
    width: 0;
    height: 0;
    margin-left: 2px;
    vertical-align: middle;
    border-top: 4px dashed;
    border-right: 4px solid transparent;
    border-left: 4px solid transparent
}

.dropdown, .dropup {
    position: relative
}

.dropdown-toggle:focus {
    outline: 0
}

.dropdown-menu {
    position: absolute;
    top: 100%;
    left: 0;
    z-index: 1000;
    display: none;
    float: left;
    min-width: 160px;
    padding: 5px 0;
    margin: 2px 0 0;
    list-style: none;
    font-size: 14px;
    text-align: left;
    background-color: #fff;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, .15);
    border-radius: 4px;
    box-shadow: 0 6px 12px rgba(0, 0, 0, .175);
    background-clip: padding-box
}

.dropdown-menu.pull-right {
    right: 0;
    left: auto
}

.dropdown-menu .divider {
    height: 1px;
    margin: 9px 0;
    overflow: hidden;
    background-color: #e5e5e5
}

.dropdown-menu > li > a {
    display: block;
    padding: 3px 20px;
    clear: both;
    font-weight: 400;
    line-height: 1.42857;
    color: #333;
    white-space: nowrap
}

.dropdown-menu > li > a:focus, .dropdown-menu > li > a:hover {
    text-decoration: none;
    color: #262626;
    background-color: #f5f5f5
}

.dropdown-menu > .active > a, .dropdown-menu > .active > a:focus, .dropdown-menu > .active > a:hover {
    color: #fff;
    text-decoration: none;
    outline: 0;
    background-color: #337ab7
}

.dropdown-menu > .disabled > a, .dropdown-menu > .disabled > a:focus, .dropdown-menu > .disabled > a:hover {
    color: #777
}

.dropdown-menu > .disabled > a:focus, .dropdown-menu > .disabled > a:hover {
    text-decoration: none;
    background-color: transparent;
    background-image: none;
    cursor: not-allowed
}

.open > .dropdown-menu {
    display: block
}

.open > a {
    outline: 0
}

.dropdown-menu-right {
    left: auto;
    right: 0
}

.dropdown-menu-left {
    left: 0;
    right: auto
}

.dropdown-header {
    display: block;
    padding: 3px 20px;
    font-size: 12px;
    line-height: 1.42857;
    color: #777;
    white-space: nowrap
}

.dropdown-backdrop {
    position: fixed;
    left: 0;
    right: 0;
    bottom: 0;
    top: 0;
    z-index: 990
}

.pull-right > .dropdown-menu {
    right: 0;
    left: auto
}

.dropup .caret, .navbar-fixed-bottom .dropdown .caret {
    border-top: 0;
    border-bottom: 4px dashed;
    content: ""
}

.dropup .dropdown-menu, .navbar-fixed-bottom .dropdown .dropdown-menu {
    top: auto;
    bottom: 100%;
    margin-bottom: 2px
}

@media (min-width: 768px) {
    .navbar-right .dropdown-menu {
        right: 0;
        left: auto
    }

    .navbar-right .dropdown-menu-left {
        left: 0;
        right: auto
    }
}

.btn-group, .btn-group-vertical {
    position: relative;
    display: inline-block;
    vertical-align: middle
}

.btn-group-vertical > .btn, .btn-group > .btn {
    position: relative;
    float: left
}

.btn-group-vertical > .btn.active, .btn-group-vertical > .btn:active, .btn-group-vertical > .btn:focus, .btn-group-vertical > .btn:hover, .btn-group > .btn.active, .btn-group > .btn:active, .btn-group > .btn:focus, .btn-group > .btn:hover {
    z-index: 2
}

.btn-group .btn + .btn, .btn-group .btn + .btn-group, .btn-group .btn-group + .btn, .btn-group .btn-group + .btn-group {
    margin-left: -1px
}

.btn-toolbar {
    margin-left: -5px
}

.btn-toolbar:after, .btn-toolbar:before {
    content: " ";
    display: table
}

.btn-toolbar:after {
    clear: both
}

.btn-toolbar .btn, .btn-toolbar .btn-group, .btn-toolbar .input-group {
    float: left
}

.btn-toolbar > .btn, .btn-toolbar > .btn-group, .btn-toolbar > .input-group {
    margin-left: 5px
}

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
    border-radius: 0
}

.btn-group > .btn:first-child {
    margin-left: 0
}

.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0
}

.btn-group > .btn:last-child:not(:first-child), .btn-group > .dropdown-toggle:not(:first-child) {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0
}

.btn-group > .btn-group {
    float: left
}

.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
    border-radius: 0
}

.btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child, .btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0
}

.btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0
}

.btn-group .dropdown-toggle:active, .btn-group.open .dropdown-toggle {
    outline: 0
}

.btn-group > .btn + .dropdown-toggle {
    padding-left: 8px;
    padding-right: 8px
}

.btn-group-lg.btn-group > .btn + .dropdown-toggle, .btn-group > .btn-lg + .dropdown-toggle {
    padding-left: 12px;
    padding-right: 12px
}

.btn-group.open .dropdown-toggle {
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125)
}

.btn-group.open .dropdown-toggle.btn-link {
    box-shadow: none
}

.btn .caret {
    margin-left: 0
}

.btn-group-lg > .btn .caret, .btn-lg .caret {
    border-width: 5px 5px 0;
    border-bottom-width: 0
}

.dropup .btn-group-lg > .btn .caret, .dropup .btn-lg .caret {
    border-width: 0 5px 5px
}

.btn-group-vertical > .btn, .btn-group-vertical > .btn-group, .btn-group-vertical > .btn-group > .btn {
    display: block;
    float: none;
    width: 100%;
    max-width: 100%
}

.btn-group-vertical > .btn-group:after, .btn-group-vertical > .btn-group:before {
    content: " ";
    display: table
}

.btn-group-vertical > .btn-group:after {
    clear: both
}

.btn-group-vertical > .btn-group > .btn {
    float: none
}

.btn-group-vertical > .btn + .btn, .btn-group-vertical > .btn + .btn-group, .btn-group-vertical > .btn-group + .btn, .btn-group-vertical > .btn-group + .btn-group {
    margin-top: -1px;
    margin-left: 0
}

.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
    border-radius: 0
}

.btn-group-vertical > .btn:first-child:not(:last-child) {
    border-top-right-radius: 4px;
    border-top-left-radius: 4px;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0
}

.btn-group-vertical > .btn:last-child:not(:first-child) {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
    border-bottom-right-radius: 4px;
    border-bottom-left-radius: 4px
}

.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
    border-radius: 0
}

.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child, .btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0
}

.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0
}

.btn-group-justified {
    display: table;
    width: 100%;
    table-layout: fixed;
    border-collapse: separate
}

.btn-group-justified > .btn, .btn-group-justified > .btn-group {
    float: none;
    display: table-cell;
    width: 1%
}

.btn-group-justified > .btn-group .btn {
    width: 100%
}

.btn-group-justified > .btn-group .dropdown-menu {
    left: auto
}

[data-toggle=buttons] > .btn input[type=checkbox], [data-toggle=buttons] > .btn input[type=radio], [data-toggle=buttons] > .btn-group > .btn input[type=checkbox], [data-toggle=buttons] > .btn-group > .btn input[type=radio] {
    position: absolute;
    clip: rect(0, 0, 0, 0);
    pointer-events: none
}

.input-group {
    position: relative;
    display: table;
    border-collapse: separate
}

.input-group[class*=col-] {
    float: none;
    padding-left: 0;
    padding-right: 0
}

.input-group .form-control {
    position: relative;
    z-index: 2;
    float: left;
    width: 100%;
    margin-bottom: 0
}

.input-group .form-control:focus {
    z-index: 3
}

.input-group .form-control, .input-group-addon, .input-group-btn {
    display: table-cell
}

.input-group .form-control:not(:first-child):not(:last-child), .input-group-addon:not(:first-child):not(:last-child), .input-group-btn:not(:first-child):not(:last-child) {
    border-radius: 0
}

.input-group-addon, .input-group-btn {
    width: 1%;
    white-space: nowrap;
    vertical-align: middle
}

.input-group-addon {
    padding: 6px 12px;
    font-size: 14px;
    font-weight: 400;
    line-height: 1;
    color: #555;
    text-align: center;
    background-color: #eee;
    border: 1px solid #ccc;
    border-radius: 4px
}

.input-group-addon.input-sm, .input-group-sm > .input-group-addon, .input-group-sm > .input-group-btn > .input-group-addon.btn {
    padding: 5px 10px;
    font-size: 12px;
    border-radius: 3px
}

.input-group-addon.input-lg, .input-group-lg > .input-group-addon, .input-group-lg > .input-group-btn > .input-group-addon.btn {
    padding: 10px 16px;
    font-size: 18px;
    border-radius: 6px
}

.input-group-addon input[type=checkbox], .input-group-addon input[type=radio] {
    margin-top: 0
}

.input-group .form-control:first-child, .input-group-addon:first-child, .input-group-btn:first-child > .btn, .input-group-btn:first-child > .btn-group > .btn, .input-group-btn:first-child > .dropdown-toggle, .input-group-btn:last-child > .btn-group:not(:last-child) > .btn, .input-group-btn:last-child > .btn:not(:last-child):not(.dropdown-toggle) {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0
}

.input-group-addon:first-child {
    border-right: 0
}

.input-group .form-control:last-child, .input-group-addon:last-child, .input-group-btn:first-child > .btn-group:not(:first-child) > .btn, .input-group-btn:first-child > .btn:not(:first-child), .input-group-btn:last-child > .btn, .input-group-btn:last-child > .btn-group > .btn, .input-group-btn:last-child > .dropdown-toggle {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0
}

.input-group-addon:last-child {
    border-left: 0
}

.input-group-btn {
    position: relative;
    font-size: 0;
    white-space: nowrap
}

.input-group-btn > .btn {
    position: relative
}

.input-group-btn > .btn + .btn {
    margin-left: -1px
}

.input-group-btn > .btn:active, .input-group-btn > .btn:focus, .input-group-btn > .btn:hover {
    z-index: 2
}

.input-group-btn:first-child > .btn, .input-group-btn:first-child > .btn-group {
    margin-right: -1px
}

.input-group-btn:last-child > .btn, .input-group-btn:last-child > .btn-group {
    z-index: 2;
    margin-left: -1px
}

.nav {
    margin-bottom: 0;
    padding-left: 0;
    list-style: none
}

.nav:after, .nav:before {
    content: " ";
    display: table
}

.nav:after {
    clear: both
}

.nav > li {
    position: relative;
    display: block
}

.nav > li > a {
    position: relative;
    display: block;
    padding: 10px 15px
}

.nav > li > a:focus, .nav > li > a:hover {
    text-decoration: none;
    background-color: #eee
}

.nav > li.disabled > a {
    color: #777
}

.nav > li.disabled > a:focus, .nav > li.disabled > a:hover {
    color: #777;
    text-decoration: none;
    background-color: transparent;
    cursor: not-allowed
}

.nav .open > a, .nav .open > a:focus, .nav .open > a:hover {
    background-color: #eee;
    border-color: #337ab7
}

.nav .nav-divider {
    height: 1px;
    margin: 9px 0;
    overflow: hidden;
    background-color: #e5e5e5
}

.nav > li > a > img {
    max-width: none
}

.nav-tabs {
    border-bottom: 1px solid #ddd
}

.nav-tabs > li {
    float: left;
    margin-bottom: -1px
}

.nav-tabs > li > a {
    margin-right: 2px;
    line-height: 1.42857;
    border: 1px solid transparent;
    border-radius: 4px 4px 0 0
}

.nav-tabs > li > a:hover {
    border-color: #eee #eee #ddd
}

.nav-tabs > li.active > a, .nav-tabs > li.active > a:focus, .nav-tabs > li.active > a:hover {
    color: #555;
    background-color: #fff;
    border: 1px solid #ddd;
    border-bottom-color: transparent;
    cursor: default
}

.nav-pills > li {
    float: left
}

.nav-pills > li > a {
    border-radius: 4px
}

.nav-pills > li + li {
    margin-left: 2px
}

.nav-pills > li.active > a, .nav-pills > li.active > a:focus, .nav-pills > li.active > a:hover {
    color: #fff;
    background-color: #337ab7
}

.nav-stacked > li {
    float: none
}

.nav-stacked > li + li {
    margin-top: 2px;
    margin-left: 0
}

.nav-justified, .nav-tabs.nav-justified {
    width: 100%
}

.nav-justified > li, .nav-tabs.nav-justified > li {
    float: none
}

.nav-justified > li > a, .nav-tabs.nav-justified > li > a {
    text-align: center;
    margin-bottom: 5px
}

.nav-justified > .dropdown .dropdown-menu {
    top: auto;
    left: auto
}

@media (min-width: 768px) {
    .nav-justified > li, .nav-tabs.nav-justified > li {
        display: table-cell;
        width: 1%
    }

    .nav-justified > li > a, .nav-tabs.nav-justified > li > a {
        margin-bottom: 0
    }
}

.nav-tabs-justified, .nav-tabs.nav-justified {
    border-bottom: 0
}

.nav-tabs-justified > li > a, .nav-tabs.nav-justified > li > a {
    margin-right: 0;
    border-radius: 4px
}

.nav-tabs-justified > .active > a, .nav-tabs-justified > .active > a:focus, .nav-tabs-justified > .active > a:hover, .nav-tabs.nav-justified > .active > a, .nav-tabs.nav-justified > .active > a:focus, .nav-tabs.nav-justified > .active > a:hover {
    border: 1px solid #ddd
}

@media (min-width: 768px) {
    .nav-tabs-justified > li > a, .nav-tabs.nav-justified > li > a {
        border-bottom: 1px solid #ddd;
        border-radius: 4px 4px 0 0
    }

    .nav-tabs-justified > .active > a, .nav-tabs-justified > .active > a:focus, .nav-tabs-justified > .active > a:hover, .nav-tabs.nav-justified > .active > a, .nav-tabs.nav-justified > .active > a:focus, .nav-tabs.nav-justified > .active > a:hover {
        border-bottom-color: #fff
    }
}

.tab-content > .tab-pane {
    display: none
}

.tab-content > .active {
    display: block
}

.nav-tabs .dropdown-menu {
    margin-top: -1px;
    border-top-right-radius: 0;
    border-top-left-radius: 0
}

.navbar {
    position: relative;
    min-height: 50px;
    margin-bottom: 20px;
    border: 1px solid transparent
}

.navbar:after, .navbar:before {
    content: " ";
    display: table
}

.navbar:after {
    clear: both
}

@media (min-width: 768px) {
    .navbar {
        border-radius: 4px
    }
}

.navbar-header:after, .navbar-header:before {
    content: " ";
    display: table
}

.navbar-header:after {
    clear: both
}

@media (min-width: 768px) {
    .navbar-header {
        float: left
    }
}

.navbar-collapse {
    overflow-x: visible;
    padding-right: 15px;
    padding-left: 15px;
    border-top: 1px solid transparent;
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, .1);
    -webkit-overflow-scrolling: touch
}

.navbar-collapse:after, .navbar-collapse:before {
    content: " ";
    display: table
}

.navbar-collapse:after {
    clear: both
}

.navbar-collapse.in {
    overflow-y: auto
}

@media (min-width: 768px) {
    .navbar-collapse {
        width: auto;
        border-top: 0;
        box-shadow: none
    }

    .navbar-collapse.collapse {
        display: block !important;
        height: auto !important;
        padding-bottom: 0;
        overflow: visible !important
    }

    .navbar-collapse.in {
        overflow-y: visible
    }

    .navbar-fixed-bottom .navbar-collapse, .navbar-fixed-top .navbar-collapse, .navbar-static-top .navbar-collapse {
        padding-left: 0;
        padding-right: 0
    }
}

.navbar-fixed-bottom .navbar-collapse, .navbar-fixed-top .navbar-collapse {
    max-height: 340px
}

@media (max-device-width: 480px) and (orientation: landscape) {
    .navbar-fixed-bottom .navbar-collapse, .navbar-fixed-top .navbar-collapse {
        max-height: 200px
    }
}

.container-fluid > .navbar-collapse, .container-fluid > .navbar-header, .container > .navbar-collapse, .container > .navbar-header {
    margin-right: -15px;
    margin-left: -15px
}

@media (min-width: 768px) {
    .container-fluid > .navbar-collapse, .container-fluid > .navbar-header, .container > .navbar-collapse, .container > .navbar-header {
        margin-right: 0;
        margin-left: 0
    }
}

.navbar-static-top {
    z-index: 1000;
    border-width: 0 0 1px
}

@media (min-width: 768px) {
    .navbar-static-top {
        border-radius: 0
    }
}

.navbar-fixed-bottom, .navbar-fixed-top {
    position: fixed;
    right: 0;
    left: 0;
    z-index: 1030
}

@media (min-width: 768px) {
    .navbar-fixed-bottom, .navbar-fixed-top {
        border-radius: 0
    }
}

.navbar-fixed-top {
    top: 0;
    border-width: 0 0 1px
}

.navbar-fixed-bottom {
    bottom: 0;
    margin-bottom: 0;
    border-width: 1px 0 0
}

.navbar-brand {
    float: left;
    padding: 0 15px;
    font-size: 18px;
    line-height: 20px;
    height: 60px
}

.navbar-brand:focus, .navbar-brand:hover {
    text-decoration: none
}

.navbar-brand > img {
    display: block
}

@media (min-width: 768px) {
    .navbar > .container .navbar-brand, .navbar > .container-fluid .navbar-brand {
        margin-left: -15px
    }
}

.navbar-toggle {
    position: relative;
    float: right;
    margin-right: 15px;
    padding: 9px 10px;
    margin-top: 8px;
    margin-bottom: 8px;
    background-color: transparent;
    background-image: none;
    border: 1px solid transparent;
    border-radius: 4px
}

.navbar-toggle:focus {
    outline: 0
}

.navbar-toggle .icon-bar {
    display: block;
    width: 22px;
    height: 2px;
    border-radius: 1px
}

.navbar-toggle .icon-bar + .icon-bar {
    margin-top: 4px
}

@media (min-width: 768px) {
    .navbar-toggle {
        display: none
    }
}

.navbar-nav {
    margin: 7.5px -15px
}

.navbar-nav > li > a {
    padding-top: 10px;
    padding-bottom: 10px;
    line-height: 20px
}

@media (max-width: 767px) {
    .navbar-nav .open .dropdown-menu {
        position: static;
        float: none;
        width: auto;
        margin-top: 0;
        background-color: transparent;
        border: 0;
        box-shadow: none
    }

    .navbar-nav .open .dropdown-menu .dropdown-header, .navbar-nav .open .dropdown-menu > li > a {
        padding: 5px 15px 5px 25px
    }

    .navbar-nav .open .dropdown-menu > li > a {
        line-height: 20px
    }

    .navbar-nav .open .dropdown-menu > li > a:focus, .navbar-nav .open .dropdown-menu > li > a:hover {
        background-image: none
    }
}

@media (min-width: 768px) {
    .navbar-nav {
        float: left;
        margin: 0
    }

    .navbar-nav > li {
        float: left
    }

    .navbar-nav > li > a {
        padding-top: 15px;
        padding-bottom: 15px
    }
}

.navbar-form {
    margin-left: -15px;
    margin-right: -15px;
    padding: 10px 15px;
    border-top: 1px solid transparent;
    border-bottom: 1px solid transparent;
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, .1), 0 1px 0 rgba(255, 255, 255, .1);
    margin-top: 8px;
    margin-bottom: 8px
}

@media (min-width: 768px) {
    .navbar-form .form-group {
        display: inline-block;
        margin-bottom: 0;
        vertical-align: middle
    }

    .navbar-form .form-control {
        display: inline-block;
        width: auto;
        vertical-align: middle
    }

    .navbar-form .form-control-static {
        display: inline-block
    }

    .navbar-form .input-group {
        display: inline-table;
        vertical-align: middle
    }

    .navbar-form .input-group .form-control, .navbar-form .input-group .input-group-addon, .navbar-form .input-group .input-group-btn {
        width: auto
    }

    .navbar-form .input-group > .form-control {
        width: 100%
    }

    .navbar-form .control-label {
        margin-bottom: 0;
        vertical-align: middle
    }

    .navbar-form .checkbox, .navbar-form .radio {
        display: inline-block;
        margin-top: 0;
        margin-bottom: 0;
        vertical-align: middle
    }

    .navbar-form .checkbox label, .navbar-form .radio label {
        padding-left: 0
    }

    .navbar-form .checkbox input[type=checkbox], .navbar-form .radio input[type=radio] {
        position: relative;
        margin-left: 0
    }

    .navbar-form .has-feedback .form-control-feedback {
        top: 0
    }
}

@media (max-width: 767px) {
    .navbar-form .form-group {
        margin-bottom: 5px
    }

    .navbar-form .form-group:last-child {
        margin-bottom: 0
    }
}

@media (min-width: 768px) {
    .navbar-form {
        width: auto;
        border: 0;
        margin-left: 0;
        margin-right: 0;
        padding-top: 0;
        padding-bottom: 0;
        box-shadow: none
    }
}

.navbar-nav > li > .dropdown-menu {
    margin-top: 0;
    border-top-right-radius: 0;
    border-top-left-radius: 0
}

.navbar-fixed-bottom .navbar-nav > li > .dropdown-menu {
    margin-bottom: 0;
    border-top-right-radius: 4px;
    border-top-left-radius: 4px;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0
}

.navbar-btn {
    margin-top: 8px;
    margin-bottom: 8px
}

.btn-group-sm > .navbar-btn.btn, .navbar-btn.btn-sm {
    margin-top: 10px;
    margin-bottom: 10px
}

.btn-group-xs > .navbar-btn.btn, .navbar-btn.btn-xs {
    margin-top: 14px;
    margin-bottom: 14px
}

.navbar-text {
    margin-top: 15px;
    margin-bottom: 15px
}

@media (min-width: 768px) {
    .navbar-text {
        float: left;
        margin-left: 15px;
        margin-right: 15px
    }
}

@media (min-width: 768px) {
    .navbar-left {
        float: left !important
    }

    .navbar-right {
        float: right !important;
        margin-right: -15px
    }

    .navbar-right ~ .navbar-right {
        margin-right: 0
    }
}

.navbar-default {
    background-color: #f8f8f8;
    border-color: #e7e7e7
}

.navbar-default .navbar-brand {
    color: #777
}

.navbar-default .navbar-brand:focus, .navbar-default .navbar-brand:hover {
    color: #5e5e5e;
    background-color: transparent
}

.navbar-default .navbar-text {
    color: #777
}

.navbar-default .navbar-nav > li > a {
    color: #777
}

.navbar-default .navbar-nav > li > a:focus, .navbar-default .navbar-nav > li > a:hover {
    color: #333;
    background-color: transparent
}

.navbar-default .navbar-nav > .active > a, .navbar-default .navbar-nav > .active > a:focus, .navbar-default .navbar-nav > .active > a:hover {
    color: #555;
    background-color: #e7e7e7
}

.navbar-default .navbar-nav > .disabled > a, .navbar-default .navbar-nav > .disabled > a:focus, .navbar-default .navbar-nav > .disabled > a:hover {
    color: #ccc;
    background-color: transparent
}

.navbar-default .navbar-toggle {
    border-color: #ddd
}

.navbar-default .navbar-toggle:focus, .navbar-default .navbar-toggle:hover {
    background-color: #ddd
}

.navbar-default .navbar-toggle .icon-bar {
    background-color: #888
}

.navbar-default .navbar-collapse, .navbar-default .navbar-form {
    border-color: #e7e7e7
}

.navbar-default .navbar-nav > .open > a, .navbar-default .navbar-nav > .open > a:focus, .navbar-default .navbar-nav > .open > a:hover {
    background-color: #e7e7e7;
    color: #555
}

@media (max-width: 767px) {
    .navbar-default .navbar-nav .open .dropdown-menu > li > a {
        color: #777
    }

    .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus, .navbar-default .navbar-nav .open .dropdown-menu > li > a:hover {
        color: #333;
        background-color: transparent
    }

    .navbar-default .navbar-nav .open .dropdown-menu > .active > a, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:focus, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:hover {
        color: #555;
        background-color: #e7e7e7
    }

    .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:focus, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:hover {
        color: #ccc;
        background-color: transparent
    }
}

.navbar-default .navbar-link {
    color: #777
}

.navbar-default .navbar-link:hover {
    color: #333
}

.navbar-default .btn-link {
    color: #777
}

.navbar-default .btn-link:focus, .navbar-default .btn-link:hover {
    color: #333
}

.navbar-default .btn-link[disabled]:focus, .navbar-default .btn-link[disabled]:hover, fieldset[disabled] .navbar-default .btn-link:focus, fieldset[disabled] .navbar-default .btn-link:hover {
    color: #ccc
}

.navbar-inverse {
    background-color: #222;
    border-color: #090909
}

.navbar-inverse .navbar-brand {
    color: #9d9d9d
}

.navbar-inverse .navbar-brand:focus, .navbar-inverse .navbar-brand:hover {
    color: #fff;
    background-color: transparent
}

.navbar-inverse .navbar-text {
    color: #9d9d9d
}

.navbar-inverse .navbar-nav > li > a {
    color: #9d9d9d
}

.navbar-inverse .navbar-nav > li > a:focus, .navbar-inverse .navbar-nav > li > a:hover {
    color: #fff;
    background-color: transparent
}

.navbar-inverse .navbar-nav > .active > a, .navbar-inverse .navbar-nav > .active > a:focus, .navbar-inverse .navbar-nav > .active > a:hover {
    color: #fff;
    background-color: #090909
}

.navbar-inverse .navbar-nav > .disabled > a, .navbar-inverse .navbar-nav > .disabled > a:focus, .navbar-inverse .navbar-nav > .disabled > a:hover {
    color: #444;
    background-color: transparent
}

.navbar-inverse .navbar-toggle {
    border-color: #333
}

.navbar-inverse .navbar-toggle:focus, .navbar-inverse .navbar-toggle:hover {
    background-color: #333
}

.navbar-inverse .navbar-toggle .icon-bar {
    background-color: #fff
}

.navbar-inverse .navbar-collapse, .navbar-inverse .navbar-form {
    border-color: #101010
}

.navbar-inverse .navbar-nav > .open > a, .navbar-inverse .navbar-nav > .open > a:focus, .navbar-inverse .navbar-nav > .open > a:hover {
    background-color: #090909;
    color: #fff
}

@media (max-width: 767px) {
    .navbar-inverse .navbar-nav .open .dropdown-menu > .dropdown-header {
        border-color: #090909
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu .divider {
        background-color: #090909
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu > li > a {
        color: #9d9d9d
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:focus, .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:hover {
        color: #fff;
        background-color: transparent
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:focus, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:hover {
        color: #fff;
        background-color: #090909
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:focus, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:hover {
        color: #444;
        background-color: transparent
    }
}

.navbar-inverse .navbar-link {
    color: #9d9d9d
}

.navbar-inverse .navbar-link:hover {
    color: #fff
}

.navbar-inverse .btn-link {
    color: #9d9d9d
}

.navbar-inverse .btn-link:focus, .navbar-inverse .btn-link:hover {
    color: #fff
}

.navbar-inverse .btn-link[disabled]:focus, .navbar-inverse .btn-link[disabled]:hover, fieldset[disabled] .navbar-inverse .btn-link:focus, fieldset[disabled] .navbar-inverse .btn-link:hover {
    color: #444
}

.breadcrumb {
    padding: 8px 15px;
    margin-bottom: 20px;
    list-style: none;
    background-color: #f5f5f5;
    border-radius: 4px
}

.breadcrumb > li {
    display: inline-block
}

.breadcrumb > li + li:before {
    content: "/ ";
    padding: 0 5px;
    color: #ccc
}

.breadcrumb > .active {
    color: #777
}

.pagination {
    display: inline-block;
    padding-left: 0;
    margin: 20px 0;
    border-radius: 4px
}

.pagination > li {
    display: inline
}

.pagination > li > a, .pagination > li > span {
    position: relative;
    float: left;
    padding: 6px 12px;
    line-height: 1.42857;
    text-decoration: none;
    color: #337ab7;
    background-color: #fff;
    border: 1px solid #ddd;
    margin-left: -1px
}

.pagination > li:first-child > a, .pagination > li:first-child > span {
    margin-left: 0;
    border-bottom-left-radius: 4px;
    border-top-left-radius: 4px
}

.pagination > li:last-child > a, .pagination > li:last-child > span {
    border-bottom-right-radius: 4px;
    border-top-right-radius: 4px
}

.pagination > li > a:focus, .pagination > li > a:hover, .pagination > li > span:focus, .pagination > li > span:hover {
    z-index: 2;
    color: #23527c;
    background-color: #eee;
    border-color: #ddd
}

.pagination > .active > a, .pagination > .active > a:focus, .pagination > .active > a:hover, .pagination > .active > span, .pagination > .active > span:focus, .pagination > .active > span:hover {
    z-index: 3;
    color: #fff;
    background-color: #337ab7;
    border-color: #337ab7;
    cursor: default
}

.pagination > .disabled > a, .pagination > .disabled > a:focus, .pagination > .disabled > a:hover, .pagination > .disabled > span, .pagination > .disabled > span:focus, .pagination > .disabled > span:hover {
    color: #777;
    background-color: #fff;
    border-color: #ddd;
    cursor: not-allowed
}

.pagination-lg > li > a, .pagination-lg > li > span {
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33333
}

.pagination-lg > li:first-child > a, .pagination-lg > li:first-child > span {
    border-bottom-left-radius: 6px;
    border-top-left-radius: 6px
}

.pagination-lg > li:last-child > a, .pagination-lg > li:last-child > span {
    border-bottom-right-radius: 6px;
    border-top-right-radius: 6px
}

.pagination-sm > li > a, .pagination-sm > li > span {
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5
}

.pagination-sm > li:first-child > a, .pagination-sm > li:first-child > span {
    border-bottom-left-radius: 3px;
    border-top-left-radius: 3px
}

.pagination-sm > li:last-child > a, .pagination-sm > li:last-child > span {
    border-bottom-right-radius: 3px;
    border-top-right-radius: 3px
}

.pager {
    padding-left: 0;
    margin: 20px 0;
    list-style: none;
    text-align: center
}

.pager:after, .pager:before {
    content: " ";
    display: table
}

.pager:after {
    clear: both
}

.pager li {
    display: inline
}

.pager li > a, .pager li > span {
    display: inline-block;
    padding: 5px 14px;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 15px
}

.pager li > a:focus, .pager li > a:hover {
    text-decoration: none;
    background-color: #eee
}

.pager .next > a, .pager .next > span {
    float: right
}

.pager .previous > a, .pager .previous > span {
    float: left
}

.pager .disabled > a, .pager .disabled > a:focus, .pager .disabled > a:hover, .pager .disabled > span {
    color: #777;
    background-color: #fff;
    cursor: not-allowed
}

.label {
    display: inline;
    padding: .2em .6em .3em;
    font-size: 75%;
    font-weight: 700;
    line-height: 1;
    color: #fff;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    border-radius: .25em
}

.label:empty {
    display: none
}

.btn .label {
    position: relative;
    top: -1px
}

a.label:focus, a.label:hover {
    color: #fff;
    text-decoration: none;
    cursor: pointer
}

.label-default {
    background-color: #777
}

.label-default[href]:focus, .label-default[href]:hover {
    background-color: #5e5e5e
}

.label-primary {
    background-color: #337ab7
}

.label-primary[href]:focus, .label-primary[href]:hover {
    background-color: #286090
}

.label-success {
    background-color: #5cb85c
}

.label-success[href]:focus, .label-success[href]:hover {
    background-color: #449d44
}

.label-info {
    background-color: #5bc0de
}

.label-info[href]:focus, .label-info[href]:hover {
    background-color: #31b0d5
}

.label-warning {
    background-color: #f0ad4e
}

.label-warning[href]:focus, .label-warning[href]:hover {
    background-color: #ec971f
}

.label-danger {
    background-color: #d9534f
}

.label-danger[href]:focus, .label-danger[href]:hover {
    background-color: #c9302c
}

.badge {
    display: inline-block;
    min-width: 10px;
    padding: 3px 7px;
    font-size: 12px;
    font-weight: 700;
    color: #fff;
    line-height: 1;
    vertical-align: middle;
    white-space: nowrap;
    text-align: center;
    background-color: #777;
    border-radius: 10px
}

.badge:empty {
    display: none
}

.btn .badge {
    position: relative;
    top: -1px
}

.btn-group-xs > .btn .badge, .btn-xs .badge {
    top: 0;
    padding: 1px 5px
}

.list-group-item.active > .badge, .nav-pills > .active > a > .badge {
    color: #337ab7;
    background-color: #fff
}

.list-group-item > .badge {
    float: right
}

.list-group-item > .badge + .badge {
    margin-right: 5px
}

.nav-pills > li > a > .badge {
    margin-left: 3px
}

a.badge:focus, a.badge:hover {
    color: #fff;
    text-decoration: none;
    cursor: pointer
}

.jumbotron {
    padding-top: 30px;
    padding-bottom: 30px;
    margin-bottom: 30px;
    color: inherit;
    background-color: #eee
}

.jumbotron .h1, .jumbotron h1 {
    color: inherit
}

.jumbotron p {
    margin-bottom: 15px;
    font-size: 21px;
    font-weight: 200
}

.jumbotron > hr {
    border-top-color: #d5d5d5
}

.container .jumbotron, .container-fluid .jumbotron {
    border-radius: 6px;
    padding-left: 15px;
    padding-right: 15px
}

.jumbotron .container {
    max-width: 100%
}

@media screen and (min-width: 768px) {
    .jumbotron {
        padding-top: 48px;
        padding-bottom: 48px
    }

    .container .jumbotron, .container-fluid .jumbotron {
        padding-left: 60px;
        padding-right: 60px
    }

    .jumbotron .h1, .jumbotron h1 {
        font-size: 63px
    }
}

.thumbnail {
    display: block;
    padding: 4px;
    margin-bottom: 20px;
    line-height: 1.42857;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 4px;
    transition: border .2s ease-in-out
}

.thumbnail a > img, .thumbnail > img {
    display: block;
    max-width: 100%;
    height: auto;
    margin-left: auto;
    margin-right: auto
}

.thumbnail .caption {
    padding: 9px;
    color: #333
}

a.thumbnail.active, a.thumbnail:focus, a.thumbnail:hover {
    border-color: #337ab7
}

.alert {
    padding: 15px;
    margin-bottom: 20px;
    border: 1px solid transparent;
    border-radius: 4px
}

.alert h4 {
    margin-top: 0;
    color: inherit
}

.alert .alert-link {
    font-weight: 700
}

.alert > p, .alert > ul {
    margin-bottom: 0
}

.alert > p + p {
    margin-top: 5px
}

.alert-dismissable, .alert-dismissible {
    padding-right: 35px
}

.alert-dismissable .close, .alert-dismissible .close {
    position: relative;
    top: -2px;
    right: -21px;
    color: inherit
}

.alert-success {
    background-color: #dff0d8;
    border-color: #d6e9c6;
    color: #3c763d
}

.alert-success hr {
    border-top-color: #c9e2b3
}

.alert-success .alert-link {
    color: #2b542c
}

.alert-info {
    background-color: #d9edf7;
    border-color: #bce8f1;
    color: #31708f
}

.alert-info hr {
    border-top-color: #a6e1ec
}

.alert-info .alert-link {
    color: #245269
}

.alert-warning {
    background-color: #fcf8e3;
    border-color: #faebcc;
    color: #8a6d3b
}

.alert-warning hr {
    border-top-color: #f7e1b5
}

.alert-warning .alert-link {
    color: #66512c
}

.alert-danger {
    background-color: #f2dede;
    border-color: #ebccd1;
    color: #a94442
}

.alert-danger hr {
    border-top-color: #e4b9c0
}

.alert-danger .alert-link {
    color: #843534
}

@keyframes progress-bar-stripes {
    from {
        background-position: 40px 0
    }
    to {
        background-position: 0 0
    }
}

.progress {
    overflow: hidden;
    height: 20px;
    margin-bottom: 20px;
    background-color: #f5f5f5;
    border-radius: 4px;
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1)
}

.progress-bar {
    float: left;
    width: 0%;
    height: 100%;
    font-size: 12px;
    line-height: 20px;
    color: #fff;
    text-align: center;
    background-color: #337ab7;
    box-shadow: inset 0 -1px 0 rgba(0, 0, 0, .15);
    transition: width .6s ease
}

.progress-bar-striped, .progress-striped .progress-bar {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
    background-size: 40px 40px
}

.progress-bar.active, .progress.active .progress-bar {
    animation: progress-bar-stripes 2s linear infinite
}

.progress-bar-success {
    background-color: #5cb85c
}

.progress-striped .progress-bar-success {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent)
}

.progress-bar-info {
    background-color: #5bc0de
}

.progress-striped .progress-bar-info {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent)
}

.progress-bar-warning {
    background-color: #f0ad4e
}

.progress-striped .progress-bar-warning {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent)
}

.progress-bar-danger {
    background-color: #d9534f
}

.progress-striped .progress-bar-danger {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent)
}

.media {
    margin-top: 15px
}

.media:first-child {
    margin-top: 0
}

.media, .media-body {
    zoom: 1;
    overflow: hidden
}

.media-body {
    width: 10000px
}

.media-object {
    display: block
}

.media-object.img-thumbnail {
    max-width: none
}

.media-right, .media > .pull-right {
    padding-left: 10px
}

.media-left, .media > .pull-left {
    padding-right: 10px
}

.media-body, .media-left, .media-right {
    display: table-cell;
    vertical-align: top
}

.media-middle {
    vertical-align: middle
}

.media-bottom {
    vertical-align: bottom
}

.media-heading {
    margin-top: 0;
    margin-bottom: 5px
}

.media-list {
    padding-left: 0;
    list-style: none
}

.list-group {
    margin-bottom: 20px;
    padding-left: 0
}

.list-group-item {
    position: relative;
    display: block;
    padding: 10px 15px;
    margin-bottom: -1px;
    background-color: #fff;
    border: 1px solid #ddd
}

.list-group-item:first-child {
    border-top-right-radius: 4px;
    border-top-left-radius: 4px
}

.list-group-item:last-child {
    margin-bottom: 0;
    border-bottom-right-radius: 4px;
    border-bottom-left-radius: 4px
}

a.list-group-item, button.list-group-item {
    color: #555
}

a.list-group-item .list-group-item-heading, button.list-group-item .list-group-item-heading {
    color: #333
}

a.list-group-item:focus, a.list-group-item:hover, button.list-group-item:focus, button.list-group-item:hover {
    text-decoration: none;
    color: #555;
    background-color: #f5f5f5
}

button.list-group-item {
    width: 100%;
    text-align: left
}

.list-group-item.disabled, .list-group-item.disabled:focus, .list-group-item.disabled:hover {
    background-color: #eee;
    color: #777;
    cursor: not-allowed
}

.list-group-item.disabled .list-group-item-heading, .list-group-item.disabled:focus .list-group-item-heading, .list-group-item.disabled:hover .list-group-item-heading {
    color: inherit
}

.list-group-item.disabled .list-group-item-text, .list-group-item.disabled:focus .list-group-item-text, .list-group-item.disabled:hover .list-group-item-text {
    color: #777
}

.list-group-item.active, .list-group-item.active:focus, .list-group-item.active:hover {
    z-index: 2;
    color: #fff;
    background-color: #337ab7;
    border-color: #337ab7
}

.list-group-item.active .list-group-item-heading, .list-group-item.active .list-group-item-heading > .small, .list-group-item.active .list-group-item-heading > small, .list-group-item.active:focus .list-group-item-heading, .list-group-item.active:focus .list-group-item-heading > .small, .list-group-item.active:focus .list-group-item-heading > small, .list-group-item.active:hover .list-group-item-heading, .list-group-item.active:hover .list-group-item-heading > .small, .list-group-item.active:hover .list-group-item-heading > small {
    color: inherit
}

.list-group-item.active .list-group-item-text, .list-group-item.active:focus .list-group-item-text, .list-group-item.active:hover .list-group-item-text {
    color: #c7ddef
}

.list-group-item-success {
    color: #3c763d;
    background-color: #dff0d8
}

a.list-group-item-success, button.list-group-item-success {
    color: #3c763d
}

a.list-group-item-success .list-group-item-heading, button.list-group-item-success .list-group-item-heading {
    color: inherit
}

a.list-group-item-success:focus, a.list-group-item-success:hover, button.list-group-item-success:focus, button.list-group-item-success:hover {
    color: #3c763d;
    background-color: #d0e9c6
}

a.list-group-item-success.active, a.list-group-item-success.active:focus, a.list-group-item-success.active:hover, button.list-group-item-success.active, button.list-group-item-success.active:focus, button.list-group-item-success.active:hover {
    color: #fff;
    background-color: #3c763d;
    border-color: #3c763d
}

.list-group-item-info {
    color: #31708f;
    background-color: #d9edf7
}

a.list-group-item-info, button.list-group-item-info {
    color: #31708f
}

a.list-group-item-info .list-group-item-heading, button.list-group-item-info .list-group-item-heading {
    color: inherit
}

a.list-group-item-info:focus, a.list-group-item-info:hover, button.list-group-item-info:focus, button.list-group-item-info:hover {
    color: #31708f;
    background-color: #c4e3f3
}

a.list-group-item-info.active, a.list-group-item-info.active:focus, a.list-group-item-info.active:hover, button.list-group-item-info.active, button.list-group-item-info.active:focus, button.list-group-item-info.active:hover {
    color: #fff;
    background-color: #31708f;
    border-color: #31708f
}

.list-group-item-warning {
    color: #8a6d3b;
    background-color: #fcf8e3
}

a.list-group-item-warning, button.list-group-item-warning {
    color: #8a6d3b
}

a.list-group-item-warning .list-group-item-heading, button.list-group-item-warning .list-group-item-heading {
    color: inherit
}

a.list-group-item-warning:focus, a.list-group-item-warning:hover, button.list-group-item-warning:focus, button.list-group-item-warning:hover {
    color: #8a6d3b;
    background-color: #faf2cc
}

a.list-group-item-warning.active, a.list-group-item-warning.active:focus, a.list-group-item-warning.active:hover, button.list-group-item-warning.active, button.list-group-item-warning.active:focus, button.list-group-item-warning.active:hover {
    color: #fff;
    background-color: #8a6d3b;
    border-color: #8a6d3b
}

.list-group-item-danger {
    color: #a94442;
    background-color: #f2dede
}

a.list-group-item-danger, button.list-group-item-danger {
    color: #a94442
}

a.list-group-item-danger .list-group-item-heading, button.list-group-item-danger .list-group-item-heading {
    color: inherit
}

a.list-group-item-danger:focus, a.list-group-item-danger:hover, button.list-group-item-danger:focus, button.list-group-item-danger:hover {
    color: #a94442;
    background-color: #ebcccc
}

a.list-group-item-danger.active, a.list-group-item-danger.active:focus, a.list-group-item-danger.active:hover, button.list-group-item-danger.active, button.list-group-item-danger.active:focus, button.list-group-item-danger.active:hover {
    color: #fff;
    background-color: #a94442;
    border-color: #a94442
}

.list-group-item-heading {
    margin-top: 0;
    margin-bottom: 5px
}

.list-group-item-text {
    margin-bottom: 0;
    line-height: 1.3
}

.panel {
    margin-bottom: 20px;
    background-color: #fff;
    border: 1px solid transparent;
    border-radius: 4px;
    box-shadow: 0 1px 1px rgba(0, 0, 0, .05)
}

.panel-body {
    padding: 15px
}

.panel-body:after, .panel-body:before {
    content: " ";
    display: table
}

.panel-body:after {
    clear: both
}

.panel-heading {
    padding: 10px 15px;
    border-bottom: 1px solid transparent;
    border-top-right-radius: 3px;
    border-top-left-radius: 3px
}

.panel-heading > .dropdown .dropdown-toggle {
    color: inherit
}

.panel-title {
    margin-top: 0;
    margin-bottom: 0;
    font-size: 16px;
    color: inherit
}

.panel-title > .small, .panel-title > .small > a, .panel-title > a, .panel-title > small, .panel-title > small > a {
    color: inherit
}

.panel-footer {
    padding: 10px 15px;
    background-color: #f5f5f5;
    border-top: 1px solid #ddd;
    border-bottom-right-radius: 3px;
    border-bottom-left-radius: 3px
}

.panel > .list-group, .panel > .panel-collapse > .list-group {
    margin-bottom: 0
}

.panel > .list-group .list-group-item, .panel > .panel-collapse > .list-group .list-group-item {
    border-width: 1px 0;
    border-radius: 0
}

.panel > .list-group:first-child .list-group-item:first-child, .panel > .panel-collapse > .list-group:first-child .list-group-item:first-child {
    border-top: 0;
    border-top-right-radius: 3px;
    border-top-left-radius: 3px
}

.panel > .list-group:last-child .list-group-item:last-child, .panel > .panel-collapse > .list-group:last-child .list-group-item:last-child {
    border-bottom: 0;
    border-bottom-right-radius: 3px;
    border-bottom-left-radius: 3px
}

.panel > .panel-heading + .panel-collapse > .list-group .list-group-item:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0
}

.panel-heading + .list-group .list-group-item:first-child {
    border-top-width: 0
}

.list-group + .panel-footer {
    border-top-width: 0
}

.panel > .panel-collapse > .table, .panel > .table, .panel > .table-responsive > .table {
    margin-bottom: 0
}

.panel > .panel-collapse > .table caption, .panel > .table caption, .panel > .table-responsive > .table caption {
    padding-left: 15px;
    padding-right: 15px
}

.panel > .table-responsive:first-child > .table:first-child, .panel > .table:first-child {
    border-top-right-radius: 3px;
    border-top-left-radius: 3px
}

.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child, .panel > .table:first-child > tbody:first-child > tr:first-child, .panel > .table:first-child > thead:first-child > tr:first-child {
    border-top-left-radius: 3px;
    border-top-right-radius: 3px
}

.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child, .panel > .table:first-child > tbody:first-child > tr:first-child td:first-child, .panel > .table:first-child > tbody:first-child > tr:first-child th:first-child, .panel > .table:first-child > thead:first-child > tr:first-child td:first-child, .panel > .table:first-child > thead:first-child > tr:first-child th:first-child {
    border-top-left-radius: 3px
}

.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child, .panel > .table:first-child > tbody:first-child > tr:first-child td:last-child, .panel > .table:first-child > tbody:first-child > tr:first-child th:last-child, .panel > .table:first-child > thead:first-child > tr:first-child td:last-child, .panel > .table:first-child > thead:first-child > tr:first-child th:last-child {
    border-top-right-radius: 3px
}

.panel > .table-responsive:last-child > .table:last-child, .panel > .table:last-child {
    border-bottom-right-radius: 3px;
    border-bottom-left-radius: 3px
}

.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child, .panel > .table:last-child > tbody:last-child > tr:last-child, .panel > .table:last-child > tfoot:last-child > tr:last-child {
    border-bottom-left-radius: 3px;
    border-bottom-right-radius: 3px
}

.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child, .panel > .table:last-child > tbody:last-child > tr:last-child td:first-child, .panel > .table:last-child > tbody:last-child > tr:last-child th:first-child, .panel > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .panel > .table:last-child > tfoot:last-child > tr:last-child th:first-child {
    border-bottom-left-radius: 3px
}

.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child, .panel > .table:last-child > tbody:last-child > tr:last-child td:last-child, .panel > .table:last-child > tbody:last-child > tr:last-child th:last-child, .panel > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .panel > .table:last-child > tfoot:last-child > tr:last-child th:last-child {
    border-bottom-right-radius: 3px
}

.panel > .panel-body + .table, .panel > .panel-body + .table-responsive, .panel > .table + .panel-body, .panel > .table-responsive + .panel-body {
    border-top: 1px solid #ddd
}

.panel > .table > tbody:first-child > tr:first-child td, .panel > .table > tbody:first-child > tr:first-child th {
    border-top: 0
}

.panel > .table-bordered, .panel > .table-responsive > .table-bordered {
    border: 0
}

.panel > .table-bordered > tbody > tr > td:first-child, .panel > .table-bordered > tbody > tr > th:first-child, .panel > .table-bordered > tfoot > tr > td:first-child, .panel > .table-bordered > tfoot > tr > th:first-child, .panel > .table-bordered > thead > tr > td:first-child, .panel > .table-bordered > thead > tr > th:first-child, .panel > .table-responsive > .table-bordered > tbody > tr > td:first-child, .panel > .table-responsive > .table-bordered > tbody > tr > th:first-child, .panel > .table-responsive > .table-bordered > tfoot > tr > td:first-child, .panel > .table-responsive > .table-bordered > tfoot > tr > th:first-child, .panel > .table-responsive > .table-bordered > thead > tr > td:first-child, .panel > .table-responsive > .table-bordered > thead > tr > th:first-child {
    border-left: 0
}

.panel > .table-bordered > tbody > tr > td:last-child, .panel > .table-bordered > tbody > tr > th:last-child, .panel > .table-bordered > tfoot > tr > td:last-child, .panel > .table-bordered > tfoot > tr > th:last-child, .panel > .table-bordered > thead > tr > td:last-child, .panel > .table-bordered > thead > tr > th:last-child, .panel > .table-responsive > .table-bordered > tbody > tr > td:last-child, .panel > .table-responsive > .table-bordered > tbody > tr > th:last-child, .panel > .table-responsive > .table-bordered > tfoot > tr > td:last-child, .panel > .table-responsive > .table-bordered > tfoot > tr > th:last-child, .panel > .table-responsive > .table-bordered > thead > tr > td:last-child, .panel > .table-responsive > .table-bordered > thead > tr > th:last-child {
    border-right: 0
}

.panel > .table-bordered > tbody > tr:first-child > td, .panel > .table-bordered > tbody > tr:first-child > th, .panel > .table-bordered > thead > tr:first-child > td, .panel > .table-bordered > thead > tr:first-child > th, .panel > .table-responsive > .table-bordered > tbody > tr:first-child > td, .panel > .table-responsive > .table-bordered > tbody > tr:first-child > th, .panel > .table-responsive > .table-bordered > thead > tr:first-child > td, .panel > .table-responsive > .table-bordered > thead > tr:first-child > th {
    border-bottom: 0
}

.panel > .table-bordered > tbody > tr:last-child > td, .panel > .table-bordered > tbody > tr:last-child > th, .panel > .table-bordered > tfoot > tr:last-child > td, .panel > .table-bordered > tfoot > tr:last-child > th, .panel > .table-responsive > .table-bordered > tbody > tr:last-child > td, .panel > .table-responsive > .table-bordered > tbody > tr:last-child > th, .panel > .table-responsive > .table-bordered > tfoot > tr:last-child > td, .panel > .table-responsive > .table-bordered > tfoot > tr:last-child > th {
    border-bottom: 0
}

.panel > .table-responsive {
    border: 0;
    margin-bottom: 0
}

.panel-group {
    margin-bottom: 20px
}

.panel-group .panel {
    margin-bottom: 0;
    border-radius: 4px
}

.panel-group .panel + .panel {
    margin-top: 5px
}

.panel-group .panel-heading {
    border-bottom: 0
}

.panel-group .panel-heading + .panel-collapse > .list-group, .panel-group .panel-heading + .panel-collapse > .panel-body {
    border-top: 1px solid #ddd
}

.panel-group .panel-footer {
    border-top: 0
}

.panel-group .panel-footer + .panel-collapse .panel-body {
    border-bottom: 1px solid #ddd
}

.panel-default {
    border-color: #ddd
}

.panel-default > .panel-heading {
    color: #333;
    background-color: #f5f5f5;
    border-color: #ddd
}

.panel-default > .panel-heading + .panel-collapse > .panel-body {
    border-top-color: #ddd
}

.panel-default > .panel-heading .badge {
    color: #f5f5f5;
    background-color: #333
}

.panel-default > .panel-footer + .panel-collapse > .panel-body {
    border-bottom-color: #ddd
}

.panel-primary {
    border-color: #337ab7
}

.panel-primary > .panel-heading {
    color: #fff;
    background-color: #337ab7;
    border-color: #337ab7
}

.panel-primary > .panel-heading + .panel-collapse > .panel-body {
    border-top-color: #337ab7
}

.panel-primary > .panel-heading .badge {
    color: #337ab7;
    background-color: #fff
}

.panel-primary > .panel-footer + .panel-collapse > .panel-body {
    border-bottom-color: #337ab7
}

.panel-success {
    border-color: #d6e9c6
}

.panel-success > .panel-heading {
    color: #3c763d;
    background-color: #dff0d8;
    border-color: #d6e9c6
}

.panel-success > .panel-heading + .panel-collapse > .panel-body {
    border-top-color: #d6e9c6
}

.panel-success > .panel-heading .badge {
    color: #dff0d8;
    background-color: #3c763d
}

.panel-success > .panel-footer + .panel-collapse > .panel-body {
    border-bottom-color: #d6e9c6
}

.panel-info {
    border-color: #bce8f1
}

.panel-info > .panel-heading {
    color: #31708f;
    background-color: #d9edf7;
    border-color: #bce8f1
}

.panel-info > .panel-heading + .panel-collapse > .panel-body {
    border-top-color: #bce8f1
}

.panel-info > .panel-heading .badge {
    color: #d9edf7;
    background-color: #31708f
}

.panel-info > .panel-footer + .panel-collapse > .panel-body {
    border-bottom-color: #bce8f1
}

.panel-warning {
    border-color: #faebcc
}

.panel-warning > .panel-heading {
    color: #8a6d3b;
    background-color: #fcf8e3;
    border-color: #faebcc
}

.panel-warning > .panel-heading + .panel-collapse > .panel-body {
    border-top-color: #faebcc
}

.panel-warning > .panel-heading .badge {
    color: #fcf8e3;
    background-color: #8a6d3b
}

.panel-warning > .panel-footer + .panel-collapse > .panel-body {
    border-bottom-color: #faebcc
}

.panel-danger {
    border-color: #ebccd1
}

.panel-danger > .panel-heading {
    color: #a94442;
    background-color: #f2dede;
    border-color: #ebccd1
}

.panel-danger > .panel-heading + .panel-collapse > .panel-body {
    border-top-color: #ebccd1
}

.panel-danger > .panel-heading .badge {
    color: #f2dede;
    background-color: #a94442
}

.panel-danger > .panel-footer + .panel-collapse > .panel-body {
    border-bottom-color: #ebccd1
}

.well {
    min-height: 20px;
    padding: 19px;
    margin-bottom: 20px;
    background-color: #f5f5f5;
    border: 1px solid #e3e3e3;
    border-radius: 4px;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .05)
}

.well blockquote {
    border-color: #ddd;
    border-color: rgba(0, 0, 0, .15)
}

.well-lg {
    padding: 24px;
    border-radius: 6px
}

.well-sm {
    padding: 9px;
    border-radius: 3px
}

.close {
    float: right;
    font-size: 21px;
    font-weight: 700;
    line-height: 1;
    color: #000;
    text-shadow: 0 1px 0 #fff;
    opacity: .2
}

.close:focus, .close:hover {
    color: #000;
    text-decoration: none;
    cursor: pointer;
    opacity: .5
}

button.close {
    padding: 0;
    cursor: pointer;
    background: 0 0;
    border: 0;
    -webkit-appearance: none
}

.modal-open {
    overflow: hidden
}

.modal {
    display: none;
    overflow: hidden;
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1050;
    -webkit-overflow-scrolling: touch;
    outline: 0
}

.modal.fade .modal-dialog {
    -ms-transform: translate(0, -25%);
    transform: translate(0, -25%);
    transition: transform .3s ease-out
}

.modal.in .modal-dialog {
    -ms-transform: translate(0, 0);
    transform: translate(0, 0)
}

.modal-open .modal {
    overflow-x: hidden;
    overflow-y: auto
}

.modal-dialog {
    position: relative;
    width: auto;
    margin: 10px
}

.modal-content {
    position: relative;
    background-color: #fff;
    border: 1px solid #999;
    border: 1px solid rgba(0, 0, 0, .2);
    border-radius: 6px;
    box-shadow: 0 3px 9px rgba(0, 0, 0, .5);
    background-clip: padding-box;
    outline: 0
}

.modal-backdrop {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1040;
    background-color: #000
}

.modal-backdrop.fade {
    opacity: 0
}

.modal-backdrop.in {
    opacity: .5
}

.modal-header {
    padding: 15px;
    border-bottom: 1px solid #e5e5e5
}

.modal-header:after, .modal-header:before {
    content: " ";
    display: table
}

.modal-header:after {
    clear: both
}

.modal-header .close {
    margin-top: -2px
}

.modal-title {
    margin: 0;
    line-height: 1.42857
}

.modal-body {
    position: relative;
    padding: 15px
}

.modal-footer {
    padding: 15px;
    text-align: right;
    border-top: 1px solid #e5e5e5
}

.modal-footer:after, .modal-footer:before {
    content: " ";
    display: table
}

.modal-footer:after {
    clear: both
}

.modal-footer .btn + .btn {
    margin-left: 5px;
    margin-bottom: 0
}

.modal-footer .btn-group .btn + .btn {
    margin-left: -1px
}

.modal-footer .btn-block + .btn-block {
    margin-left: 0
}

.modal-scrollbar-measure {
    position: absolute;
    top: -9999px;
    width: 50px;
    height: 50px;
    overflow: scroll
}

@media (min-width: 768px) {
    .modal-dialog {
        width: 600px;
        margin: 30px auto
    }

    .modal-content {
        box-shadow: 0 5px 15px rgba(0, 0, 0, .5)
    }

    .modal-sm {
        width: 300px
    }
}

@media (min-width: 992px) {
    .modal-lg {
        width: 900px
    }
}

.clearfix:after, .clearfix:before {
    content: " ";
    display: table
}

.clearfix:after {
    clear: both
}

.center-block {
    display: block;
    margin-left: auto;
    margin-right: auto
}

.pull-right {
    float: right !important
}

.pull-left {
    float: left !important
}

.hide {
    display: none !important
}

.show {
    display: block !important
}

.invisible {
    visibility: hidden
}

.text-hide {
    font: 0/0 a;
    color: transparent;
    text-shadow: none;
    background-color: transparent;
    border: 0
}

.hidden {
    display: none !important
}

.affix {
    position: fixed
}

@-ms-viewport {
    width: device-width
}

.visible-xs {
    display: none !important
}

.visible-sm {
    display: none !important
}

.visible-md {
    display: none !important
}

.visible-lg {
    display: none !important
}

.visible-lg-block, .visible-lg-inline, .visible-lg-inline-block, .visible-md-block, .visible-md-inline, .visible-md-inline-block, .visible-sm-block, .visible-sm-inline, .visible-sm-inline-block, .visible-xs-block, .visible-xs-inline, .visible-xs-inline-block {
    display: none !important
}

@media (max-width: 767px) {
    .visible-xs {
        display: block !important
    }

    table.visible-xs {
        display: table !important
    }

    tr.visible-xs {
        display: table-row !important
    }

    td.visible-xs, th.visible-xs {
        display: table-cell !important
    }
}

@media (max-width: 767px) {
    .visible-xs-block {
        display: block !important
    }
}

@media (max-width: 767px) {
    .visible-xs-inline {
        display: inline !important
    }
}

@media (max-width: 767px) {
    .visible-xs-inline-block {
        display: inline-block !important
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .visible-sm {
        display: block !important
    }

    table.visible-sm {
        display: table !important
    }

    tr.visible-sm {
        display: table-row !important
    }

    td.visible-sm, th.visible-sm {
        display: table-cell !important
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .visible-sm-block {
        display: block !important
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .visible-sm-inline {
        display: inline !important
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .visible-sm-inline-block {
        display: inline-block !important
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .visible-md {
        display: block !important
    }

    table.visible-md {
        display: table !important
    }

    tr.visible-md {
        display: table-row !important
    }

    td.visible-md, th.visible-md {
        display: table-cell !important
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .visible-md-block {
        display: block !important
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .visible-md-inline {
        display: inline !important
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .visible-md-inline-block {
        display: inline-block !important
    }
}

@media (min-width: 1200px) {
    .visible-lg {
        display: block !important
    }

    table.visible-lg {
        display: table !important
    }

    tr.visible-lg {
        display: table-row !important
    }

    td.visible-lg, th.visible-lg {
        display: table-cell !important
    }
}

@media (min-width: 1200px) {
    .visible-lg-block {
        display: block !important
    }
}

@media (min-width: 1200px) {
    .visible-lg-inline {
        display: inline !important
    }
}

@media (min-width: 1200px) {
    .visible-lg-inline-block {
        display: inline-block !important
    }
}

@media (max-width: 767px) {
    .hidden-xs {
        display: none !important
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .hidden-sm {
        display: none !important
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .hidden-md {
        display: none !important
    }
}

@media (min-width: 1200px) {
    .hidden-lg {
        display: none !important
    }
}

.visible-print {
    display: none !important
}

@media print {
    .visible-print {
        display: block !important
    }

    table.visible-print {
        display: table !important
    }

    tr.visible-print {
        display: table-row !important
    }

    td.visible-print, th.visible-print {
        display: table-cell !important
    }
}

.visible-print-block {
    display: none !important
}

@media print {
    .visible-print-block {
        display: block !important
    }
}

.visible-print-inline {
    display: none !important
}

@media print {
    .visible-print-inline {
        display: inline !important
    }
}

.visible-print-inline-block {
    display: none !important
}

@media print {
    .visible-print-inline-block {
        display: inline-block !important
    }
}

@media print {
    .hidden-print {
        display: none !important
    }
}

@font-face {
    font-family: FontAwesome;
    src: url(../fonts/fontawesome-webfont.eot);
    src: url(../fonts/fontawesome-webfont.eot) format("embedded-opentype"), url(../fonts/fontawesome-webfont.woff) format("woff"), url(../fonts/fontawesome-webfont.ttf) format("truetype"), url(../fonts/fontawesome-webfont.svg) format("svg");
    font-weight: 400;
    font-style: normal
}

.fa {
    display: inline-block;
    font-family: FontAwesome;
    font-style: normal;
    font-weight: 400;
    line-height: 1;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale
}

.fa-lg {
    font-size: 1.33333em;
    line-height: .75em;
    vertical-align: -15%
}

.fa-2x {
    font-size: 2em
}

.fa-3x {
    font-size: 3em
}

.fa-4x {
    font-size: 4em
}

.fa-5x {
    font-size: 5em
}

.fa-fw {
    width: 1.28571em;
    text-align: center
}

.fa-ul {
    padding-left: 0;
    margin-left: 2.14286em;
    list-style-type: none
}

.fa-ul > li {
    position: relative
}

.fa-li {
    position: absolute;
    left: -2.14286em;
    width: 2.14286em;
    top: .14286em;
    text-align: center
}

.fa-li.fa-lg {
    left: -1.85714em
}

.fa-border {
    padding: .2em .25em .15em;
    border: solid .08em #eee;
    border-radius: .1em
}

.pull-right {
    float: right
}

.pull-left {
    float: left
}

.fa.pull-left {
    margin-right: .3em
}

.fa.pull-right {
    margin-left: .3em
}

.fa-spin {
    animation: spin 2s infinite linear
}

@keyframes spin {
    0% {
        transform: rotate(0)
    }
    100% {
        transform: rotate(359deg)
    }
}

.fa-rotate-90 {
    -ms-transform: rotate(90deg);
    transform: rotate(90deg)
}

.fa-rotate-180 {
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}

.fa-rotate-270 {
    -ms-transform: rotate(270deg);
    transform: rotate(270deg)
}

.fa-flip-horizontal {
    -ms-transform: scale(-1, 1);
    transform: scale(-1, 1)
}

.fa-flip-vertical {
    -ms-transform: scale(1, -1);
    transform: scale(1, -1)
}

.fa-stack {
    position: relative;
    display: inline-block;
    width: 2em;
    height: 2em;
    line-height: 2em;
    vertical-align: middle
}

.fa-stack-1x, .fa-stack-2x {
    position: absolute;
    left: 0;
    width: 100%;
    text-align: center
}

.fa-stack-1x {
    line-height: inherit
}

.fa-stack-2x {
    font-size: 2em
}

.fa-inverse {
    color: #fff
}

.fa-glass:before {
    content: ""
}

.fa-music:before {
    content: ""
}

.fa-search:before {
    content: ""
}

.fa-envelope-o:before {
    content: ""
}

.fa-heart:before {
    content: ""
}

.fa-star:before {
    content: ""
}

.fa-star-o:before {
    content: ""
}

.fa-user:before {
    content: ""
}

.fa-film:before {
    content: ""
}

.fa-th-large:before {
    content: ""
}

.fa-th:before {
    content: ""
}

.fa-th-list:before {
    content: ""
}

.fa-check:before {
    content: ""
}

.fa-times:before {
    content: ""
}

.fa-search-plus:before {
    content: ""
}

.fa-search-minus:before {
    content: ""
}

.fa-power-off:before {
    content: ""
}

.fa-signal:before {
    content: ""
}

.fa-cog:before, .fa-gear:before {
    content: ""
}

.fa-trash-o:before {
    content: ""
}

.fa-home:before {
    content: ""
}

.fa-file-o:before {
    content: ""
}

.fa-clock-o:before {
    content: ""
}

.fa-road:before {
    content: ""
}

.fa-download:before {
    content: ""
}

.fa-arrow-circle-o-down:before {
    content: ""
}

.fa-arrow-circle-o-up:before {
    content: ""
}

.fa-inbox:before {
    content: ""
}

.fa-play-circle-o:before {
    content: ""
}

.fa-repeat:before, .fa-rotate-right:before {
    content: ""
}

.fa-refresh:before {
    content: ""
}

.fa-list-alt:before {
    content: ""
}

.fa-lock:before {
    content: ""
}

.fa-flag:before {
    content: ""
}

.fa-headphones:before {
    content: ""
}

.fa-volume-off:before {
    content: ""
}

.fa-volume-down:before {
    content: ""
}

.fa-volume-up:before {
    content: ""
}

.fa-qrcode:before {
    content: ""
}

.fa-barcode:before {
    content: ""
}

.fa-tag:before {
    content: ""
}

.fa-tags:before {
    content: ""
}

.fa-book:before {
    content: ""
}

.fa-bookmark:before {
    content: ""
}

.fa-print:before {
    content: ""
}

.fa-camera:before {
    content: ""
}

.fa-font:before {
    content: ""
}

.fa-bold:before {
    content: ""
}

.fa-italic:before {
    content: ""
}

.fa-text-height:before {
    content: ""
}

.fa-text-width:before {
    content: ""
}

.fa-align-left:before {
    content: ""
}

.fa-align-center:before {
    content: ""
}

.fa-align-right:before {
    content: ""
}

.fa-align-justify:before {
    content: ""
}

.fa-list:before {
    content: ""
}

.fa-dedent:before, .fa-outdent:before {
    content: ""
}

.fa-indent:before {
    content: ""
}

.fa-video-camera:before {
    content: ""
}

.fa-picture-o:before {
    content: ""
}

.fa-pencil:before {
    content: ""
}

.fa-map-marker:before {
    content: ""
}

.fa-adjust:before {
    content: ""
}

.fa-tint:before {
    content: ""
}

.fa-edit:before, .fa-pencil-square-o:before {
    content: ""
}

.fa-share-square-o:before {
    content: ""
}

.fa-check-square-o:before {
    content: ""
}

.fa-arrows:before {
    content: ""
}

.fa-step-backward:before {
    content: ""
}

.fa-fast-backward:before {
    content: ""
}

.fa-backward:before {
    content: ""
}

.fa-play:before {
    content: ""
}

.fa-pause:before {
    content: ""
}

.fa-stop:before {
    content: ""
}

.fa-forward:before {
    content: ""
}

.fa-fast-forward:before {
    content: ""
}

.fa-step-forward:before {
    content: ""
}

.fa-eject:before {
    content: ""
}

.fa-chevron-left:before {
    content: ""
}

.fa-chevron-right:before {
    content: ""
}

.fa-plus-circle:before {
    content: ""
}

.fa-minus-circle:before {
    content: ""
}

.fa-times-circle:before {
    content: ""
}

.fa-check-circle:before {
    content: ""
}

.fa-question-circle:before {
    content: ""
}

.fa-info-circle:before {
    content: ""
}

.fa-crosshairs:before {
    content: ""
}

.fa-times-circle-o:before {
    content: ""
}

.fa-check-circle-o:before {
    content: ""
}

.fa-ban:before {
    content: ""
}

.fa-arrow-left:before {
    content: ""
}

.fa-arrow-right:before {
    content: ""
}

.fa-arrow-up:before {
    content: ""
}

.fa-arrow-down:before {
    content: ""
}

.fa-mail-forward:before, .fa-share:before {
    content: ""
}

.fa-expand:before {
    content: ""
}

.fa-compress:before {
    content: ""
}

.fa-plus:before {
    content: ""
}

.fa-minus:before {
    content: ""
}

.fa-asterisk:before {
    content: ""
}

.fa-exclamation-circle:before {
    content: ""
}

.fa-gift:before {
    content: ""
}

.fa-leaf:before {
    content: ""
}

.fa-fire:before {
    content: ""
}

.fa-eye:before {
    content: ""
}

.fa-eye-slash:before {
    content: ""
}

.fa-exclamation-triangle:before, .fa-warning:before {
    content: ""
}

.fa-plane:before {
    content: ""
}

.fa-calendar:before {
    content: ""
}

.fa-random:before {
    content: ""
}

.fa-comment:before {
    content: ""
}

.fa-magnet:before {
    content: ""
}

.fa-chevron-up:before {
    content: ""
}

.fa-chevron-down:before {
    content: ""
}

.fa-retweet:before {
    content: ""
}

.fa-shopping-cart:before {
    content: ""
}

.fa-folder:before {
    content: ""
}

.fa-folder-open:before {
    content: ""
}

.fa-arrows-v:before {
    content: ""
}

.fa-arrows-h:before {
    content: ""
}

.fa-bar-chart-o:before {
    content: ""
}

.fa-twitter-square:before {
    content: ""
}

.fa-facebook-square:before {
    content: ""
}

.fa-camera-retro:before {
    content: ""
}

.fa-key:before {
    content: ""
}

.fa-cogs:before, .fa-gears:before {
    content: ""
}

.fa-comments:before {
    content: ""
}

.fa-thumbs-o-up:before {
    content: ""
}

.fa-thumbs-o-down:before {
    content: ""
}

.fa-star-half:before {
    content: ""
}

.fa-heart-o:before {
    content: ""
}

.fa-sign-out:before {
    content: ""
}

.fa-linkedin-square:before {
    content: ""
}

.fa-thumb-tack:before {
    content: ""
}

.fa-external-link:before {
    content: ""
}

.fa-sign-in:before {
    content: ""
}

.fa-trophy:before {
    content: ""
}

.fa-github-square:before {
    content: ""
}

.fa-upload:before {
    content: ""
}

.fa-lemon-o:before {
    content: ""
}

.fa-phone:before {
    content: ""
}

.fa-square-o:before {
    content: ""
}

.fa-bookmark-o:before {
    content: ""
}

.fa-phone-square:before {
    content: ""
}

.fa-twitter:before {
    content: ""
}

.fa-facebook:before {
    content: ""
}

.fa-github:before {
    content: ""
}

.fa-unlock:before {
    content: ""
}

.fa-credit-card:before {
    content: ""
}

.fa-rss:before {
    content: ""
}

.fa-hdd-o:before {
    content: ""
}

.fa-bullhorn:before {
    content: ""
}

.fa-bell:before {
    content: ""
}

.fa-certificate:before {
    content: ""
}

.fa-hand-o-right:before {
    content: ""
}

.fa-hand-o-left:before {
    content: ""
}

.fa-hand-o-up:before {
    content: ""
}

.fa-hand-o-down:before {
    content: ""
}

.fa-arrow-circle-left:before {
    content: ""
}

.fa-arrow-circle-right:before {
    content: ""
}

.fa-arrow-circle-up:before {
    content: ""
}

.fa-arrow-circle-down:before {
    content: ""
}

.fa-globe:before {
    content: ""
}

.fa-wrench:before {
    content: ""
}

.fa-tasks:before {
    content: ""
}

.fa-filter:before {
    content: ""
}

.fa-briefcase:before {
    content: ""
}

.fa-arrows-alt:before {
    content: ""
}

.fa-group:before, .fa-users:before {
    content: ""
}

.fa-chain:before, .fa-link:before {
    content: ""
}

.fa-cloud:before {
    content: ""
}

.fa-flask:before {
    content: ""
}

.fa-cut:before, .fa-scissors:before {
    content: ""
}

.fa-copy:before, .fa-files-o:before {
    content: ""
}

.fa-paperclip:before {
    content: ""
}

.fa-floppy-o:before, .fa-save:before {
    content: ""
}

.fa-square:before {
    content: ""
}

.fa-bars:before {
    content: ""
}

.fa-list-ul:before {
    content: ""
}

.fa-list-ol:before {
    content: ""
}

.fa-strikethrough:before {
    content: ""
}

.fa-underline:before {
    content: ""
}

.fa-table:before {
    content: ""
}

.fa-magic:before {
    content: ""
}

.fa-truck:before {
    content: ""
}

.fa-pinterest:before {
    content: ""
}

.fa-pinterest-square:before {
    content: ""
}

.fa-google-plus-square:before {
    content: ""
}

.fa-google-plus:before {
    content: ""
}

.fa-money:before {
    content: ""
}

.fa-caret-down:before {
    content: ""
}

.fa-caret-up:before {
    content: ""
}

.fa-caret-left:before {
    content: ""
}

.fa-caret-right:before {
    content: ""
}

.fa-columns:before {
    content: ""
}

.fa-sort:before, .fa-unsorted:before {
    content: ""
}

.fa-sort-asc:before, .fa-sort-down:before {
    content: ""
}

.fa-sort-desc:before, .fa-sort-up:before {
    content: ""
}

.fa-envelope:before {
    content: ""
}

.fa-linkedin:before {
    content: ""
}

.fa-rotate-left:before, .fa-undo:before {
    content: ""
}

.fa-gavel:before, .fa-legal:before {
    content: ""
}

.fa-dashboard:before, .fa-tachometer:before {
    content: ""
}

.fa-comment-o:before {
    content: ""
}

.fa-comments-o:before {
    content: ""
}

.fa-bolt:before, .fa-flash:before {
    content: ""
}

.fa-sitemap:before {
    content: ""
}

.fa-umbrella:before {
    content: ""
}

.fa-clipboard:before, .fa-paste:before {
    content: ""
}

.fa-lightbulb-o:before {
    content: ""
}

.fa-exchange:before {
    content: ""
}

.fa-cloud-download:before {
    content: ""
}

.fa-cloud-upload:before {
    content: ""
}

.fa-user-md:before {
    content: ""
}

.fa-stethoscope:before {
    content: ""
}

.fa-suitcase:before {
    content: ""
}

.fa-bell-o:before {
    content: ""
}

.fa-coffee:before {
    content: ""
}

.fa-cutlery:before {
    content: ""
}

.fa-file-text-o:before {
    content: ""
}

.fa-building-o:before {
    content: ""
}

.fa-hospital-o:before {
    content: ""
}

.fa-ambulance:before {
    content: ""
}

.fa-medkit:before {
    content: ""
}

.fa-fighter-jet:before {
    content: ""
}

.fa-beer:before {
    content: ""
}

.fa-h-square:before {
    content: ""
}

.fa-plus-square:before {
    content: ""
}

.fa-angle-double-left:before {
    content: ""
}

.fa-angle-double-right:before {
    content: ""
}

.fa-angle-double-up:before {
    content: ""
}

.fa-angle-double-down:before {
    content: ""
}

.fa-angle-left:before {
    content: ""
}

.fa-angle-right:before {
    content: ""
}

.fa-angle-up:before {
    content: ""
}

.fa-angle-down:before {
    content: ""
}

.fa-desktop:before {
    content: ""
}

.fa-laptop:before {
    content: ""
}

.fa-tablet:before {
    content: ""
}

.fa-mobile-phone:before, .fa-mobile:before {
    content: ""
}

.fa-circle-o:before {
    content: ""
}

.fa-quote-left:before {
    content: ""
}

.fa-quote-right:before {
    content: ""
}

.fa-spinner:before {
    content: ""
}

.fa-circle:before {
    content: ""
}

.fa-mail-reply:before, .fa-reply:before {
    content: ""
}

.fa-github-alt:before {
    content: ""
}

.fa-folder-o:before {
    content: ""
}

.fa-folder-open-o:before {
    content: ""
}

.fa-smile-o:before {
    content: ""
}

.fa-frown-o:before {
    content: ""
}

.fa-meh-o:before {
    content: ""
}

.fa-gamepad:before {
    content: ""
}

.fa-keyboard-o:before {
    content: ""
}

.fa-flag-o:before {
    content: ""
}

.fa-flag-checkered:before {
    content: ""
}

.fa-terminal:before {
    content: ""
}

.fa-code:before {
    content: ""
}

.fa-reply-all:before {
    content: ""
}

.fa-mail-reply-all:before {
    content: ""
}

.fa-star-half-empty:before, .fa-star-half-full:before, .fa-star-half-o:before {
    content: ""
}

.fa-location-arrow:before {
    content: ""
}

.fa-crop:before {
    content: ""
}

.fa-code-fork:before {
    content: ""
}

.fa-chain-broken:before, .fa-unlink:before {
    content: ""
}

.fa-question:before {
    content: ""
}

.fa-info:before {
    content: ""
}

.fa-exclamation:before {
    content: ""
}

.fa-superscript:before {
    content: ""
}

.fa-subscript:before {
    content: ""
}

.fa-eraser:before {
    content: ""
}

.fa-puzzle-piece:before {
    content: ""
}

.fa-microphone:before {
    content: ""
}

.fa-microphone-slash:before {
    content: ""
}

.fa-shield:before {
    content: ""
}

.fa-calendar-o:before {
    content: ""
}

.fa-fire-extinguisher:before {
    content: ""
}

.fa-rocket:before {
    content: ""
}

.fa-maxcdn:before {
    content: ""
}

.fa-chevron-circle-left:before {
    content: ""
}

.fa-chevron-circle-right:before {
    content: ""
}

.fa-chevron-circle-up:before {
    content: ""
}

.fa-chevron-circle-down:before {
    content: ""
}

.fa-html5:before {
    content: ""
}

.fa-css3:before {
    content: ""
}

.fa-anchor:before {
    content: ""
}

.fa-unlock-alt:before {
    content: ""
}

.fa-bullseye:before {
    content: ""
}

.fa-ellipsis-h:before {
    content: ""
}

.fa-ellipsis-v:before {
    content: ""
}

.fa-rss-square:before {
    content: ""
}

.fa-play-circle:before {
    content: ""
}

.fa-ticket:before {
    content: ""
}

.fa-minus-square:before {
    content: ""
}

.fa-minus-square-o:before {
    content: ""
}

.fa-level-up:before {
    content: ""
}

.fa-level-down:before {
    content: ""
}

.fa-check-square:before {
    content: ""
}

.fa-pencil-square:before {
    content: ""
}

.fa-external-link-square:before {
    content: ""
}

.fa-share-square:before {
    content: ""
}

.fa-compass:before {
    content: ""
}

.fa-caret-square-o-down:before, .fa-toggle-down:before {
    content: ""
}

.fa-caret-square-o-up:before, .fa-toggle-up:before {
    content: ""
}

.fa-caret-square-o-right:before, .fa-toggle-right:before {
    content: ""
}

.fa-eur:before, .fa-euro:before {
    content: ""
}

.fa-gbp:before {
    content: ""
}

.fa-dollar:before, .fa-usd:before {
    content: ""
}

.fa-inr:before, .fa-rupee:before {
    content: ""
}

.fa-cny:before, .fa-jpy:before, .fa-rmb:before, .fa-yen:before {
    content: ""
}

.fa-rouble:before, .fa-rub:before, .fa-ruble:before {
    content: ""
}

.fa-krw:before, .fa-won:before {
    content: ""
}

.fa-bitcoin:before, .fa-btc:before {
    content: ""
}

.fa-file:before {
    content: ""
}

.fa-file-text:before {
    content: ""
}

.fa-sort-alpha-asc:before {
    content: ""
}

.fa-sort-alpha-desc:before {
    content: ""
}

.fa-sort-amount-asc:before {
    content: ""
}

.fa-sort-amount-desc:before {
    content: ""
}

.fa-sort-numeric-asc:before {
    content: ""
}

.fa-sort-numeric-desc:before {
    content: ""
}

.fa-thumbs-up:before {
    content: ""
}

.fa-thumbs-down:before {
    content: ""
}

.fa-youtube-square:before {
    content: ""
}

.fa-youtube:before {
    content: ""
}

.fa-xing:before {
    content: ""
}

.fa-xing-square:before {
    content: ""
}

.fa-youtube-play:before {
    content: ""
}

.fa-dropbox:before {
    content: ""
}

.fa-stack-overflow:before {
    content: ""
}

.fa-instagram:before {
    content: ""
}

.fa-flickr:before {
    content: ""
}

.fa-adn:before {
    content: ""
}

.fa-bitbucket:before {
    content: ""
}

.fa-bitbucket-square:before {
    content: ""
}

.fa-tumblr:before {
    content: ""
}

.fa-tumblr-square:before {
    content: ""
}

.fa-long-arrow-down:before {
    content: ""
}

.fa-long-arrow-up:before {
    content: ""
}

.fa-long-arrow-left:before {
    content: ""
}

.fa-long-arrow-right:before {
    content: ""
}

.fa-apple:before {
    content: ""
}

.fa-windows:before {
    content: ""
}

.fa-android:before {
    content: ""
}

.fa-linux:before {
    content: ""
}

.fa-dribbble:before {
    content: ""
}

.fa-skype:before {
    content: ""
}

.fa-foursquare:before {
    content: ""
}

.fa-trello:before {
    content: ""
}

.fa-female:before {
    content: ""
}

.fa-male:before {
    content: ""
}

.fa-gittip:before {
    content: ""
}

.fa-sun-o:before {
    content: ""
}

.fa-moon-o:before {
    content: ""
}

.fa-archive:before {
    content: ""
}

.fa-bug:before {
    content: ""
}

.fa-vk:before {
    content: ""
}

.fa-weibo:before {
    content: ""
}

.fa-renren:before {
    content: ""
}

.fa-pagelines:before {
    content: ""
}

.fa-stack-exchange:before {
    content: ""
}

.fa-arrow-circle-o-right:before {
    content: ""
}

.fa-arrow-circle-o-left:before {
    content: ""
}

.fa-caret-square-o-left:before, .fa-toggle-left:before {
    content: ""
}

.fa-dot-circle-o:before {
    content: ""
}

.fa-wheelchair:before {
    content: ""
}

.fa-vimeo-square:before {
    content: ""
}

.fa-try:before, .fa-turkish-lira:before {
    content: ""
}

.fa-plus-square-o:before {
    content: ""
}

#wrapper {
    width: 100%
}

#page-wrapper {
    padding: 0;
    min-height: 568px;
    background-color: #fff
}

#page-wrapper + footer {
    background-color: #fff;
    min-height: 30px;
    padding: 5px
}

.snippet-content {
    height: 100%
}

.row {
    margin: 0;
    height: 100%
}

.content {
    padding: 28px
}

.content h2 {
    font-size: 20px;
    font-weight: 700;
    margin-top: -3px;
    margin-bottom: 13px
}

.content .alert {
    margin: 20px 15px
}

.header {
    padding: 30px 24px 24px 28px;
    height: 91px;
    border-bottom: 1px solid #e1e1e1
}

.header .btn {
    float: right;
    margin-left: 15px
}

.header .breadcrumb li, .header h1 {
    margin: 0;
    font-size: 24px;
    display: inline-block;
    float: left;
    white-space: nowrap;
    max-width: 100%
}

a, button {
    transition: all .4s ease;
    color: #428bca;
    font-weight: 400
}

a:active, button:active {
    transition: all .4s ease
}

a:hover, button:hover {
    transition: all .4s ease;
    color: #428bca;
    text-decoration: underline
}

a:active, button:active {
    color: #428bca
}

.uc {
    text-transform: uppercase
}

li, ul {
    margin: 0
}

h1, h2, h3, h4 {
    background: 0 0
}

h3 {
    font-size: 16px;
    text-transform: uppercase;
    line-height: 22px;
    margin-bottom: 16px;
    color: #000
}

html {
    height: 100%;
    background-color: #f8f8f8
}

body {
    height: 100%;
    padding-top: 100px;
    background-color: #f8f8f8
}

a, body, del, div, em, fieldset, form, h1, h2, h3, h4, h5, html, img, label, li, ol, p, span, ul {
    font-family: Helvetica, Arial, sans-serif
}

img {
    max-width: 100%
}

::-moz-selection {
    color: #fff;
    background-color: #08b1ff
}

::selection {
    color: #fff;
    background-color: #08b1ff
}

::-moz-selection {
    color: #fff;
    background-color: #08b1ff
}

.navbar-top-links li {
    display: inline-block
}

.navbar-top-links li:last-child {
    margin-right: 15px
}

.navbar-top-links li a {
    min-height: 50px
}

.navbar-top-links .dropdown-menu li {
    display: block
}

.navbar-top-links .dropdown-menu li:last-child {
    margin-right: 0
}

.navbar-top-links .dropdown-menu li a {
    padding: 3px 20px;
    min-height: 0
}

.navbar-top-links .dropdown-menu li a div {
    white-space: normal
}

.navbar-top-links li .dropdown-toggle {
    position: relative;
    display: block;
    padding: 10px 15px;
    min-height: 50px
}

.navbar-static-side ul li {
    border-bottom: 1px solid #e7e7e7
}

@media (min-width: 767px) {
    #page-wrapper {
        position: inherit;
        padding: 5px 0 0;
        min-height: 600px;
        margin: 0 0 0 250px;
        border-left: 1px solid #e7e7e7
    }

    #page-wrapper + footer {
        margin: 0 0 0 250px;
        border-left: 1px solid #e7e7e7
    }
}

@media (max-width: 767px) {
    body {
        padding-top: 45px
    }

    .header {
        padding: 24px 15px 24px 15px;
        height: 70px
    }

    .header .btn {
        font-size: 12px;
        padding: 2px 12px;
        height: 34px;
        line-height: 27px
    }
}

@media (min-width: 768px) {
    .navbar-static-side {
        z-index: 1;
        position: absolute;
        width: 250px;
        margin-top: 51px
    }
}

@media (max-height: 600px) and (max-width: 767px) {
    .sidebar-collapse {
        max-height: 300px;
        overflow-y: scroll
    }
}

@media (max-height: 400px) and (max-width: 767px) {
    .sidebar-collapse {
        max-height: 200px;
        overflow-y: scroll
    }
}

#sticky-flash {
    position: fixed;
    left: 0;
    right: 0;
    margin: 15px 40% 0 40%;
    width: 20%;
    z-index: 99
}

.alert {
    padding: 10px;
    text-align: center;
    position: relative
}

.alert .close {
    position: absolute;
    top: 30%;
    margin-top: -5px;
    right: 6px
}

.alert .btn {
    border: none;
    background: 0 0;
    box-shadow: none;
    padding: 0;
    margin: 0;
    width: auto;
    min-width: 0;
    text-decoration: underline;
    height: auto;
    vertical-align: bottom
}

.ac.dropdown-menu {
    display: block;
    top: initial;
    left: initial;
    min-width: 240px;
    max-height: 400px;
    overflow: scroll
}

.ac.dropdown-menu li {
    height: 42px
}

.ac.dropdown-menu .active {
    text-decoration: none;
    color: #262626;
    background-color: #f5f5f5
}

.ac-buttons, .ac-item {
    position: relative;
    display: inline-block;
    width: 100%
}

.ac-buttons .goog-icon-remove, .ac-item .goog-icon-remove {
    position: absolute;
    right: 12px;
    top: 7px;
    color: #ed3535
}

.ac-buttons .open-list, .ac-item .open-list {
    position: absolute;
    top: 6px;
    right: 0;
    width: 30px;
    height: 30px;
    text-indent: -1000em;
    border: none;
    background-image: url(../images/select-arrow.png);
    background-repeat: no-repeat;
    background-position: 4px center
}

.ac-buttons .ac-highlighted, .ac-item .ac-highlighted {
    background: #5bc0de
}

.ac-buttons .ac-image, .ac-item .ac-image {
    width: 40px;
    height: 40px;
    margin-right: 12px;
    border-radius: 50%;
    background-clip: padding-box;
    width: 30px;
    height: 30px;
    border: 1px solid #d2d2d2
}

.ac-buttons .ac-image-placeholder, .ac-item .ac-image-placeholder {
    width: 40px;
    height: 40px;
    margin-right: 12px;
    border-radius: 50%;
    background-clip: padding-box;
    width: 30px;
    height: 30px;
    border: 1px solid #d2d2d2;
    text-align: center;
    display: inline-block;
    font-family: FontAwesome;
    font-style: normal;
    font-weight: 400;
    line-height: 1;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    border: none;
    padding-top: 3px;
    padding: 8px
}

.ac-buttons .ac-image-placeholder:before, .ac-item .ac-image-placeholder:before {
    font-family: se;
    content: "\e60d";
    font-size: 20px;
    color: #aeaeae
}

.ac-buttons > .ac-image, .ac-item > .ac-image {
    position: absolute;
    left: 10px;
    top: 5px;
    width: 30px;
    height: 30px;
    z-index: 9
}

.ac-buttons > .ac-image-placeholder, .ac-item > .ac-image-placeholder {
    top: 2px;
    position: absolute;
    width: 30px;
    height: 30px
}

.ac-buttons input.with-image, .ac-item input.with-image {
    padding-left: 50px
}

.ac-buttons .ac-row, .ac-item .ac-row {
    padding: 5px;
    vertical-align: middle
}

.breadcrumb {
    padding: 0;
    margin: 0;
    background-color: transparent;
    float: left;
    margin-top: -2px;
    color: #000
}

.breadcrumb a {
    color: #000
}

.breadcrumb li {
    float: left;
    display: block;
    overflow: hidden;
    text-overflow: ellipsis;
    line-height: 32px
}

.breadcrumb > li + li:before {
    font-family: FontAwesome;
    content: "\f105";
    font-size: 13px;
    vertical-align: middle;
    padding: 0 10px
}

.breadcrumb .active {
    color: #000;
    font-weight: 400
}

.breadcrumb li:first-child:before {
    display: none
}

form {
    margin-right: 0;
    padding: 0;
    width: 100%
}

form .required {
    color: #ed3535
}

form .required-hint {
    color: #aeaeae;
    margin: 15px 0;
    clear: both
}

form .help {
    color: #aeaeae;
    margin: 2px 0;
    font-size: 80%
}

form .btn {
    margin-top: 15px
}

form .field-value a {
    line-height: 40px
}

form .field-value a.btn {
    line-height: normal
}

form div {
    margin-bottom: 0;
    padding: 0;
    vertical-align: middle;
    clear: none
}

form .errorlist {
    margin-top: 5px;
    padding: 0
}

form .errorlist li {
    list-style-type: none;
    padding: 15px;
    margin-bottom: 20px;
    border: 1px solid transparent;
    border-radius: 4px;
    background-color: #ed3535;
    border-color: #de0e0e;
    color: #fff;
    padding: 10px;
    text-align: center
}

form .errorlist li h4 {
    margin-top: 0;
    color: inherit
}

form .errorlist li .alert-link {
    font-weight: 700
}

form .errorlist li > p, form .errorlist li > ul {
    margin-bottom: 0
}

form .errorlist li > p + p {
    margin-top: 5px
}

form .errorlist li hr {
    border-top-color: #c60c0c
}

form .errorlist li .alert-link {
    color: #e6e6e6
}

form .errorlist li .btn {
    border: none;
    background: 0 0;
    box-shadow: none;
    padding: 0;
    margin: 0;
    width: auto;
    min-width: 0;
    text-decoration: underline;
    height: auto;
    vertical-align: bottom
}

form .field.error .ac-item input, form .field.error input, form .field.error select, form .field.error textarea {
    border-color: #a94442
}

input[type=checkbox] {
    font-size: 20px
}

fieldset {
    display: inline-block;
    width: 100%
}

legend {
    margin: 0 0 10px 0;
    padding: 30px 0 0
}

[type=email], [type=number], [type=password], [type=tel], [type=text], [type=url] {
    border: 1px solid #ccc;
    background: #fbfbfb;
    padding: 5px 14px;
    color: #414141;
    width: 100%;
    box-shadow: none;
    border-radius: 2px;
    background-clip: padding-box;
    background: #fbfbfb;
    height: 40px
}

input[type=text].date, input[type=text].datetime {
    padding-left: 36px;
    position: relative;
    background: #fbfbfb url(../images/cal.png) 10px center no-repeat
}

select, select.form-control {
    border: 1px solid #ccc;
    background: #fbfbfb;
    padding: 5px 14px;
    color: #414141;
    width: 100%;
    box-shadow: none;
    border-radius: 2px;
    background-clip: padding-box;
    background-color: #fbfbfb;
    cursor: pointer;
    height: 40px;
    -webkit-appearance: button;
    background-image: url(../images/select-arrow.png);
    background-position: center right;
    background-repeat: no-repeat;
    margin: 0;
    width: 100%;
    font-size: 14px;
    overflow: hidden;
    padding-left: 14px;
    white-space: nowrap;
    position: relative;
    vertical-align: middle
}

textarea {
    border: 1px solid #ccc;
    background: #fbfbfb;
    padding: 5px 14px;
    color: #414141;
    width: 100%;
    box-shadow: none;
    border-radius: 2px;
    background-clip: padding-box;
    background-color: #fbfbfb;
    height: 140px;
    resize: vertical
}

textarea.transparent {
    background-color: transparent
}

.form-group {
    margin-bottom: 13px
}

.form-group label {
    color: #565656;
    margin: 15px 0 4px;
    font-weight: 400
}

::-webkit-input-placeholder {
    color: #a4a4a4;
    font-weight: 400
}

::-moz-placeholder {
    color: #a4a4a4;
    font-weight: 400
}

:-ms-input-placeholder {
    color: #a4a4a4;
    font-weight: 400
}

input:-moz-placeholder {
    color: #a4a4a4;
    font-weight: 400
}

input:focus, select:focus, textarea:focus {
    outline-color: #428bca
}

table.form td, table.form th {
    padding: 0 5px 0
}

.form-horizontal .form-group {
    margin: 0
}

.form-horizontal .table-responsive {
    clear: both
}

.page-view .form-btns {
    z-index: 100;
    position: fixed;
    bottom: 0;
    right: 0;
    left: 200px;
    background: #f8f8f8;
    padding: 5px 20px 20px 20px;
    text-align: right;
    border-top: 1px solid #e7e7e7
}

.page-view .form-btns .pull-left {
    margin-top: 10px;
    width: 100%
}

.page-view .form-btns .pull-left .btn {
    margin: 3px 0 3px 3px;
    float: right
}

.page-view .form-btns .pull-left .btn-cancel {
    float: left;
    margin: 3px 3px 3px 0
}

input[type=submit][disabled] {
    -webkit-opacity: .5;
    -moz-opacity: .5;
    opacity: .5
}

.btn-link:hover {
    text-decoration: none
}

.grid tr:focus {
    outline: 0
}

.grid tbody > tr > td {
    vertical-align: middle;
    padding: 4px 4px 2px 4px
}

.grid thead > tr > th {
    vertical-align: top;
    position: relative;
    white-space: nowrap;
    padding: 8px 4px
}

.grid thead > tr > th:after {
    content: '';
    position: absolute;
    bottom: 44px;
    left: 0;
    width: 100%;
    height: 1px;
    background: #ddd
}

.grid thead > tr > th input, .grid thead > tr > th select {
    width: 100%;
    font-size: 12px;
    height: 29px;
    padding: 3px 7px;
    margin-top: 13px
}

.grid thead > tr > th .filter-extended {
    width: 50px;
    margin-top: 0;
    margin-right: 5px
}

.grid thead > tr > th input.date, .grid thead > tr > th input.datetime, .grid thead > tr > th input[type=number] {
    width: 60%
}

.grid thead > tr > th .ac-buttons > .ac-image {
    width: 20px;
    height: 20px;
    top: 17px
}

.grid thead > tr > th .ac-buttons > .ac-image-placeholder {
    width: 20px;
    height: 20px;
    top: 9px
}

.grid thead > tr > th .ac-item .open-list {
    top: 13px;
    right: -3px
}

.grid thead > tr > th .ac-item .goog-icon-remove {
    top: 15px
}

.grid td {
    padding: 10px
}

.grid td.id {
    width: 7%;
    color: #9a9a9a
}

.grid td.date {
    width: 11%
}

.grid td.status {
    width: 12%
}

.grid td.actions {
    white-space: nowrap
}

.grid td.actions a {
    margin-left: 6px;
    color: #888;
    text-decoration: none
}

.grid td.actions .btn {
    height: auto;
    padding: 0 4px;
    margin-left: 5px;
    min-width: 0;
    border-color: transparent;
    color: #888;
    font-family: FontAwesome;
    font-size: 20px;
    background-color: transparent
}

.grid td.actions .btn:hover {
    color: #000;
    background: 0 0
}

.grid td.actions .btn.btn-danger, .grid td.actions .btn.remote-button {
    color: #ed3535
}

.grid td.actions .btn.btn-danger:before, .grid td.actions .btn.remote-button:before {
    content: "\f00d"
}

.grid td.actions .btn.activate:before, .grid td.actions .btn.deactivate:before {
    content: "\f011"
}

.grid td.actions .btn.edit:before {
    content: "\f040"
}

.grid td.actions .btn.detail:before {
    content: "\f129"
}

.grid td.actions .btn:before {
    font-family: FontAwesome
}

.grid td.actions .btn.download:before {
    content: "\f0ed"
}

.grid td.actions .btn span {
    display: none
}

.grid .filter {
    position: relative
}

.grid > thead > tr > th {
    border-bottom: 1px solid #ddd
}

.paginator {
    background-color: #fff
}

.paginator .caption {
    vertical-align: text-bottom;
    margin: 0 2px
}

.paginator i.fa {
    font-size: 25px
}

.paginator .pagination {
    float: right;
    margin: -2px 0 0
}

.paginator .pagination:hover {
    cursor: pointer
}

.paginator .pagination i {
    color: #565656
}

.paginator .pagination i:hover {
    color: #aeaeae
}

.paginator .pagination span:hover {
    background-color: #fff
}

.paginator .pagination .disabled i {
    color: #aeaeae
}

.paginator .result-displayed {
    text-align: right;
    margin-right: 2px
}

.paginator .result-caption {
    color: #aeaeae
}

.paginator .result-number {
    padding-left: 5px
}

@media (min-width: 1200px) {
    .paginator.bottom {
        width: 100%;
        padding: 0
    }
}

@media (max-width: 1199px) {
    .paginator.bottom {
        background: 0 0
    }
}

.snippet-badge {
    display: inline-block
}

.snippet-badge .badge {
    position: static
}

.goog-date-picker {
    position: absolute;
    left: 0;
    float: left;
    min-width: 160px;
    margin: 2px 0 0;
    font-size: 14px;
    list-style: none;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid rgba(0, 0, 0, .15);
    border-radius: 4px;
    background-clip: padding-box;
    box-shadow: 0 6px 12px rgba(0, 0, 0, .175);
    top: 0;
    width: 250px;
    padding: 4px;
    margin-top: 1px;
    z-index: 99999
}

.goog-date-picker th {
    text-align: center;
    font-size: .9em
}

.goog-date-picker th div {
    float: left
}

.goog-date-picker td {
    text-align: center;
    vertical-align: middle;
    padding: 1px 3px
}

.goog-date-picker button {
    padding: 5px 0;
    margin: 1px 0;
    border: 0;
    font-weight: 400;
    background: 0 0;
    box-shadow: none
}

.goog-date-picker button:hover {
    text-decoration: underline
}

.goog-date-picker-menu {
    position: absolute;
    background: threedface;
    border: 1px solid gray;
    -moz-user-focus: normal;
    -moz-user-select: none;
    z-index: 1;
    outline: 0
}

.goog-date-picker-menu ul {
    list-style: none;
    margin: 0;
    padding: 0
}

.goog-date-picker-menu ul li {
    cursor: default
}

.goog-date-picker-menu-selected {
    background: #3276b1;
    color: #fff
}

.goog-date-picker-date {
    background: #fff
}

.goog-date-picker-wday, .goog-date-picker-week {
    padding: 1px 3px;
    border: 0;
    border-color: #e0e0e0;
    border-style: solid
}

.goog-date-picker-week {
    border-right-width: 1px
}

.goog-date-picker-wday {
    border-bottom-width: 1px
}

.goog-date-picker-head td {
    text-align: center
}

td.goog-date-picker-none-cont, td.goog-date-picker-today-cont {
    text-align: center
}

.goog-date-picker-month {
    white-space: nowrap
}

.goog-date-picker-year {
    white-space: nowrap
}

.goog-date-picker-monthyear {
    white-space: nowrap
}

.goog-date-picker table {
    border-collapse: collapse
}

.goog-date-picker-other-month {
    color: #888
}

.goog-date-picker-wkend-end, .goog-date-picker-wkend-start {
    background: #eee
}

td.goog-date-picker-selected {
    background: #3276b1;
    color: #fff
}

.goog-date-picker-today {
    background: #9ab;
    font-weight: 700;
    border-color: #246 #9bd #9bd #246;
    color: #fff
}

.tag-container {
    margin-top: 5px
}

.tag {
    float: left;
    border: 1px solid #ddd;
    position: relative;
    background: #fdfdfd;
    padding: 5px;
    height: 40px;
    margin: 0 5px 5px 0;
    border-radius: 3px;
    background-clip: padding-box
}

.tag .ac-image {
    margin-right: 10px;
    border-radius: 50%;
    background-clip: padding-box;
    width: 30px;
    height: 30px;
    border: 1px solid #d2d2d2
}

.tag .ac-image-placeholder {
    border-radius: 50%;
    background-clip: padding-box;
    width: 30px;
    height: 30px;
    border: 1px solid #d2d2d2;
    text-align: center;
    display: inline-block;
    font-family: FontAwesome;
    font-style: normal;
    font-weight: 400;
    line-height: 1;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    border: none;
    padding-top: 3px
}

.tag .ac-image-placeholder:before {
    font-family: se;
    content: "\e60d";
    font-size: 20px;
    color: #aeaeae
}

.tag .goog-icon-remove {
    cursor: pointer;
    right: 6px;
    bottom: 5px;
    margin-left: 10px;
    color: #ed3535
}

.tag .goog-icon-remove:before {
    font-family: FontAwesome;
    content: "\f00d"
}

a, body, del, div, em, fieldset, form, h1, h2, h3, h4, h5, html, img, label, li, ol, p, span, ul {
    font-family: inherit
}

body {
    font-family: "Fira Sans", "Helvetica Neue", Helvetica, Arial, sans-serif
}

.weight-normal {
    font-weight: 400
}

.snippet-content {
    height: auto
}

.navbar-default {
    margin: 0
}

.ml15 {
    margin-left: 15px
}

@media (min-width: 992px) {
    .mr-sub40 {
        margin-right: -40px
    }
}

.no-margin {
    margin: 0
}

.label {
    font-size: 1.15em;
    border-radius: 2px
}

.header-label {
    display: inline-block;
    padding: 10px 24px;
    font-weight: 400
}

@media (max-width: 767px) {
    .header-label {
        padding: 10px
    }
}

.label-danger {
    border: 1px solid #fd8f97;
    color: #fe3e4d;
    background: #fbeff0
}

.label-success {
    border: 1px solid #46c303;
    color: #46c303;
    background: #f3ffeb
}

.label-warning {
    border: 1px solid #f39c11;
    color: #f39c11;
    background: #fffcf9
}

.label-info {
    border: 1px solid #5bc0de;
    color: #5bc0de;
    background: #f3fdff
}

.btn-min-width {
    min-width: 220px
}

table {
    margin: 20px 0
}

@media (min-width: 768px) {
    .navbar-static-side {
        top: 51px;
        margin-top: 0;
        position: fixed;
        float: left;
        height: 100%;
        height: calc(100% - 51px);
        width: 20%;
        width: calc(200px);
        padding-bottom: 60px
    }
}

.view-set-password-backenduser .alert {
    margin-top: 80px
}

.view-set-password-backenduser .set-password-is-backenduser-form input {
    width: 90%
}

.header .btn {
    position: relative;
    top: -3px
}

.textarea .html_body_cs textarea {
    min-width: 800px;
    min-height: 600px
}

* {
    outline: 0
}

.close-text {
    color: #3ea1ff;
    text-decoration: underline;
    text-align: center;
    margin-top: 38px
}

.close-text:hover {
    text-decoration: none
}

.breadcrumb {
    width: auto;
    margin-bottom: 45px;
    float: left
}

.breadcrumb li a {
    color: #2a4d6a
}

.breadcrumb li:last-child a {
    color: #587893
}

.breadcrumb li:first-child a {
    font-weight: 700;
    color: #2a4d6a
}

.form-group label {
    font-weight: 700
}

legend {
    font-weight: 700;
    color: #2a4d6a
}

form .content {
    padding: 0 !important
}

form .field .close.btn-icon {
    position: relative;
    top: -30px;
    right: 15px
}

form input, form select {
    background-color: #fff
}

form input {
    padding-bottom: 2px
}

form .inline-line > .field {
    position: relative;
    vertical-align: top
}

form .inline-line > .field .close {
    position: absolute;
    top: 10px;
    right: 15px
}

form .inline-line > .field textarea {
    height: 70px;
    max-width: 300px
}

form .inline-line > .field select {
    min-width: 120px
}

form .errorlist {
    clear: both
}

.content form .no-inline-items {
    padding: .7em 6em .6em
}

.ac-buttons .open-list {
    background-color: transparent
}

.ac-choose-value {
    padding-top: 5px;
    padding-left: 5px;
    text-decoration: underline;
    cursor: pointer;
    color: #428bca
}

.ac-choose-value:hover {
    text-decoration: none
}

.btn-spinner {
    margin-left: 10px
}

.date-input, .date-time-input, .email-input, .multiple-select, .number-input, .price-number-input, .select, .sequence-select, .text-input, .u-rl-input {
    max-width: 330px
}

.textarea {
    max-width: 460px
}

.date-input .field-value, .date-time-input .field-value, .multiple-select .field-value, .select .field-value, .sequence-select .field-value, .u-rl-input .field-value {
    position: relative
}

.date-input .close {
    position: absolute;
    top: 10px;
    right: 15px
}

.tabular-inline th {
    min-width: 140px
}

.field-validation-icon {
    margin-left: 10px;
    font-size: 22px;
    visibility: hidden;
    vertical-align: text-bottom
}

.field-validation-icon.fa-check-circle {
    color: #46c303
}

.field-validation-icon.fa-times-circle {
    color: #ff2334
}

.field-validation-icon.fa-check-circle, .field-validation-icon.fa-times-circle {
    visibility: visible
}

.error .field-value input, .error .field-value textarea, .error .form-col input, .error .form-col textarea, .field-has-error .field-value input, .field-has-error .field-value textarea, .field-has-error .form-col input, .field-has-error .form-col textarea {
    border-color: #ff2334
}

.error .errorlist li, .field-has-error .errorlist li {
    margin-bottom: 0;
    border: 0;
    background-color: transparent;
    color: #ff2334;
    padding: 0;
    text-align: left
}

.sortable {
    position: relative
}

.sortable:after {
    content: '';
    height: 7px;
    width: 7px;
    position: absolute;
    right: -15px;
    top: 50%;
    margin-top: -4px;
    -webkit-opacity: .3;
    -moz-opacity: .3;
    opacity: .3;
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}

@media (max-width: 767px) {
    .sortable:after {
        right: -10px
    }
}

.goog-tablesorter-sorted:after {
    -webkit-opacity: 1;
    -moz-opacity: 1;
    opacity: 1
}

.goog-tablesorter-sorted-reverse:after {
    -webkit-opacity: 1;
    -moz-opacity: 1;
    opacity: 1;
    -ms-transform: rotate(0);
    transform: rotate(0)
}

.listing-pane .table-responsive {
    background: 0 0;
    box-shadow: none;
    padding: 0
}

.table-responsive ul.inline-list{
    list-style-type: none
}

.grid thead > tr > th {
    position: relative
}

.grid thead > tr > th .filter-extended {
    width: 40px;
    margin-top: 0;
    margin-right: 5px;
    background-position-x: 24px
}

.grid thead > tr > th select input {
    padding-bottom: 3px
}

.grid thead > tr > th input.date, .grid thead > tr > th input.datetime, .grid thead > tr > th input[type=number] {
    width: 60%
}

.grid thead > tr > th .close {
    position: absolute;
    bottom: 12px;
    right: 5px
}

.grid .goog-container a.btn {
    margin: 0;
    display: block;
    height: 100%;
    width: 100%;
    text-align: left
}

.grid .actions a.btn {
    display: inline
}

.grid td.actions .btn.copy:before {
    content: "\f0c5"
}

.table-striped tr:nth-child(odd) > td > td {
    background-color: #f3f6fc
}

.table-striped tr:nth-child(odd) > td > th {
    background-color: #f3f6fc
}

.paginator.top {
    visibility: hidden !important
}

.columns-dropdown ul {
    padding: 0
}

.columns-dropdown li {
    list-style-type: none;
    margin: .5em
}

.columns-dropdown li label {
    margin-left: .1em
}

.columns-dropdown .is-filtered:after {
    content: "\f0b0";
    font-family: FontAwesome;
    margin-left: .3em
}

.columns-dropdown {
    clear: both
}

.columns-dropdown label {
    cursor: pointer
}

.content .columns-filtering-text {
    margin: 1em 0 0
}

.content .columns-filtering-text .delete-filtering {
    color: #3ea1ff;
    text-decoration: underline;
    cursor: pointer
}

.content .columns-filtering-text .columns {
    font-weight: 700
}

.navbar-brand {
    text-indent: -9999px;
    width: 140px;
    height: 41px;
    margin-top: 5px
}

.app-backend-env-accept .navbar-fixed-top {
    background-color: #b6ffbd
}

.app-backend-env-integration .navbar-fixed-top {
    background-color: #f4d9d0
}

.app-backend-env-local .navbar-fixed-top {
    background-color: #fdffb6
}

.app-backend-env-preprod .navbar-fixed-top {
    background-color: #d6cdc8
}

.app-backend-env-prod .navbar-fixed-top {
    background-color: inherit
}

.app-backend-env-train .navbar-fixed-top {
    background-color: #b5dce1
}

.nav-tabs {
    width: 100%
}

.navbar-static-side ul {
    margin-bottom: 0;
    padding-left: 0;
    list-style: none
}

.navbar-static-side ul .menu-item {
    border-bottom: 0;
    border-left: 4px solid #fff
}

.navbar-static-side ul .menu-item.active {
    border-left: 4px solid #3fa2ff;
    background-color: #f3f6fa
}

.navbar-static-side ul .menu-item.active > a, .navbar-static-side ul .menu-item.active > button {
    font-weight: 700
}

.navbar-static-side ul .menu-item.expanded {
    border-left: 4px solid #aaa
}

.navbar-static-side ul .menu-item.expanded .collapsible-content {
    max-height: 10000px
}

.navbar-static-side ul .menu-item.expanded > button {
    background-color: #eee
}

.navbar-static-side ul .menu-item.expanded .menu-item:not(.active) {
    border-left: 4px solid #aaa
}

.navbar-static-side ul .menu-item .collapsible-content {
    margin-left: -4px;
    max-height: 0;
    overflow: hidden;
    transition: max-height .5s;
    background-color: #fff
}

.navbar-static-side ul .menu-item .collapsible-content a {
    padding-left: 25px
}

.navbar-static-side ul .menu-item > a, .navbar-static-side ul .menu-item > button {
    position: relative;
    display: block;
    width: 100%;
    padding: 10px 15px;
    border: none;
    background-color: transparent;
    text-align: left;
    font-weight: 400;
    color: #2a4d6a
}

.navbar-static-side ul .menu-item > a:active, .navbar-static-side ul .menu-item > a:hover, .navbar-static-side ul .menu-item > button:active, .navbar-static-side ul .menu-item > button:hover {
    text-decoration: none;
    background-color: #eee
}

.navbar-static-side ul .menu-item > a:disabled, .navbar-static-side ul .menu-item > button:disabled {
    color: #cbd2d9
}

@media (min-width: 768px) {
    .navbar-static-side {
        width: 210px
    }

    #page-wrapper, #page-wrapper + footer {
        margin-left: 210px
    }
}

.goog-tooltip {
    border-radius: 5px;
    padding: 3px;
    padding-right: 11px;
    margin-top: 5px;
    max-width: 500px;
    background-color: #000;
    color: #fff;
    z-index: 1031
}

.goog-tooltip:before {
    content: "";
    border-color: green;
    border-left: 5px solid transparent;
    border-right: 5px solid transparent;
    border-bottom: 5px solid #000;
    position: relative;
    top: -22px;
    left: 5px;
    font-size: 1px
}

.flash-msg {
    padding: 10px 20px
}

.flash-permanent {
    margin-top: -60px
}

.alert-error {
    background-color: #ed3535;
    border-color: #de0e0e;
    color: #fff
}

.alert-error hr {
    border-top-color: #c60c0c
}

.alert-error .alert-link {
    color: #e6e6e6
}

.alert-success {
    background-color: #49b270;
    border-color: #3ea063;
    color: #fff;
    padding: 10px 25px
}

.alert-success hr {
    border-top-color: #378e58
}

.alert-success .alert-link {
    color: #e6e6e6
}

#sticky-flash, #sticky-flash-cljs {
    z-index: 1051;
    position: fixed;
    left: 0;
    right: 0;
    margin: 15px auto 0 auto;
    width: 300px
}

body {
    overflow-x: hidden;
    min-height: 100%
}

body:after, body:before {
    content: '';
    display: table
}

#wrapper {
    height: 100%;
    background: #f4f7fa
}

#page-wrapper {
    width: calc(100% - 210px)
}

@media (max-width: 767px) {
    #page-wrapper {
        width: 100%
    }
}

.modal-dialog {
    z-index: 1020;
    margin-left: auto;
    margin-right: auto
}

@media (min-width: 768px) {
    .modal-dialog {
        width: 782px;
        max-width: 95%
    }
}

@media (max-width: 767px) {
    .modal-dialog {
        margin-top: 15px;
        margin-left: 7.5px;
        margin-right: 7.5px
    }
}

.modal-header {
    padding: 20px
}

.close {
    top: 12px;
    right: 25px
}

@media (max-width: 991px) {
    .close {
        top: 18px
    }
}

.modal-content {
    border-radius: 2px
}

.welcome-slide label {
    font-weight: 400;
    color: #81909f
}

.welcome-slide input {
    margin-right: 7px
}

.modal-backdrop {
    background-color: #2a4d6a;
    z-index: 1050
}

.level-details-modal .modal-body p {
    text-align: center;
    margin-bottom: 46px
}

.modal-body {
    color: #2a4d6a;
    max-height: 80vh;
    overflow-y: auto
}

.modal-body .header {
    height: auto;
    padding: 0;
    margin-top: 15px
}

@media (max-width: 767px) {
    .modal-body .header {
        margin: 0
    }
}

.modal-body .header .breadcrumb {
    float: none;
    margin-bottom: 15px;
    text-align: center
}

@media (max-width: 767px) {
    .modal-body .header .breadcrumb {
        text-align: left
    }
}

.modal-body .header .breadcrumb .active, .modal-body .header .breadcrumb li {
    float: none;
    color: #2a4d6a;
    font-weight: 700
}

.modal-body h1 {
    font-size: 24px;
    font-weight: 700;
    text-align: center;
    margin-bottom: 28px;
    margin-top: 15px
}

.modal-body p {
    font-size: 16px
}

.modal-body .modal-col-wrapper {
    margin-bottom: 48px
}

.modal-body .modal-col-title {
    font-size: 18px;
    font-weight: 700;
    margin-bottom: 6px
}

.modal-body .modal-col-text {
    opacity: .7;
    color: #2a4d6a;
    font-size: 16px;
    font-weight: 400;
    line-height: 24px
}

@media (max-width: 991px) {
    .modal-body .btn.next-slide {
        margin-right: 45px
    }
}

.modal-body .btn.next-slide:hover:after {
    background-color: #5db0ff
}

.modal-body .btn.next-slide:after {
    content: '\203A';
    position: absolute;
    right: -46px;
    top: 0;
    bottom: 0;
    margin: auto;
    width: 46px;
    height: 46px;
    background-color: #3ea1ff;
    border-radius: 100%;
    line-height: 37px !important;
    color: #fff;
    font-size: 29px
}

.modal-body .btn-close {
    background-color: #3ea1ff;
    padding: 11px 0;
    width: 117px;
    color: #fff;
    border-radius: 0
}

.modal-body .btn-close:hover {
    background-color: #5db0ff
}

.modal-body .btn.previous-slide {
    position: relative;
    color: #2a4d6a;
    background-color: transparent;
    float: left;
    outline: 0;
    line-height: 32px !important
}

@media (max-width: 991px) {
    .modal-body .btn.previous-slide {
        margin-left: 45px
    }
}

.modal-body .btn.previous-slide:hover:before {
    background-color: #3ea1ff
}

.modal-body .btn.previous-slide:before {
    content: '\2039';
    position: absolute;
    left: -46px;
    top: 0;
    bottom: 0;
    margin: auto;
    width: 46px;
    height: 46px;
    background-color: #bfc9d2;
    border-radius: 100%;
    line-height: 37px !important;
    color: #fff;
    font-size: 29px
}

.modal-body .modal-level-info {
    margin-bottom: 30px
}

.modal-body .modal-level-info .level-description {
    padding: 10px
}

.modal-body .modal-level-info .col-md-5 {
    padding: 0 !important
}

.modal-body .modal-level-info p {
    margin: 0;
    text-align: left
}

@media (max-width: 991px) {
    .modal-body .modal-level-info p {
        text-align: center
    }
}

.modal-body .modal-level-info p:first-child {
    margin-bottom: 5px
}

@media (max-width: 991px) {
    .modal-body .modal-level-info p:first-child {
        margin-top: 10px
    }
}

@media (max-width: 991px) {
    .modal-body .modal-level-info .icon {
        margin: 20px auto auto
    }
}

@media (min-width: 768px) {
    .modal-dialog {
        margin: 90px auto 20px
    }
}

@media (max-width: 767px) {
    .modal .modal-content .close {
        margin: 0;
        top: 10px;
        right: 10px;
        width: 25px;
        height: 25px;
        background-size: 100%
    }
}

@media (max-width: 767px) and (max-width: 767px) {
    .modal-body > .col-lg-12 {
        padding-left: 0;
        padding-right: 0
    }
}

.modal .modal-content .modal-body {
    padding: 15px 15px 40px 15px
}

.modal .modal-content .modal-body .form-btns {
    left: 0;
    width: 100%
}

.app-backend.app-activity.view-edit-activity #page-wrapper, .app-backend.app-contract.view-edit-contract #page-wrapper, .app-backend.app-customer.view-edit-customer #page-wrapper, .app-backend.app-eshop.view-edit-eshop #page-wrapper, .app-backend.app-order.view-edit-order #page-wrapper {
    border-left: 0;
    height: calc(100% - 74px)
}

.app-backend.app-activity.view-edit-activity #page-wrapper .main-content, .app-backend.app-contract.view-edit-contract #page-wrapper .main-content, .app-backend.app-customer.view-edit-customer #page-wrapper .main-content, .app-backend.app-eshop.view-edit-eshop #page-wrapper .main-content, .app-backend.app-order.view-edit-order #page-wrapper .main-content {
    border-left: 1px solid #e7e7e7;
    padding-bottom: 74px
}

.date-range-wrapper {
    margin-top: 13px
}

.date-range-wrapper .btn {
    min-width: 30px;
    line-height: 24px;
    margin-top: 0
}

.date-range-wrapper .btn .label {
    top: 1px
}

.date-range-wrapper .btn .fa {
    margin-right: 5px;
    position: static
}

.date-range-wrapper .popup {
    width: 660px;
    height: 350px
}

.date-range-wrapper .date-picker-wrapper {
    position: static;
    float: left
}

.date-range-wrapper .date-picker-wrapper__to .goog-date-picker {
    left: 250px
}

.date-range-wrapper .date-picker-wrapper__to .time-picker {
    left: 70px
}

.date-range-wrapper .date-picker-wrapper .time-picker {
    margin-left: 70px;
    position: relative;
    bottom: -310px;
    margin-top: -4px
}

.date-range-wrapper .date-picker-wrapper .time-picker select {
    position: static;
    width: 50px;
    float: left;
    margin-top: 0
}

.date-range-wrapper .date-picker-wrapper .time-picker .separator {
    float: left;
    line-height: 25px;
    margin: 0 5px
}

.date-range-wrapper .date-picker-wrapper .goog-date-picker {
    box-shadow: none;
    border: none;
    z-index: auto;
    margin-left: 10px
}

.date-range-wrapper .date-picker-wrapper .goog-date-picker .goog-date-picker-btn {
    margin: 1px -5px
}

.date-range-wrapper .overlay {
    z-index: 990;
    position: fixed;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    opacity: 0
}

.date-range-wrapper .filter-buttons {
    position: absolute;
    right: 10px;
    top: 10px
}

.date-range-wrapper .action-buttons {
    right: 10px;
    bottom: 10px;
    position: absolute
}

.ansi1 {
    font-weight: 700
}

.ansi2 {
    font-weight: lighter
}

.ansi3 {
    font-style: italic
}

.ansi4 {
    text-decoration: underline
}

.ansi5 {
    text-decoration: blink
}

.ansi6 {
    text-decoration: blink
}

.ansi8 {
    visibility: hidden
}

.ansi9 {
    text-decoration: line-through
}

.ansi30 {
    color: #000316
}

.inv30 {
    background-color: #000316
}

.ansi31 {
    color: #a00
}

.inv31 {
    background-color: #a00
}

.ansi32 {
    color: #0a0
}

.inv32 {
    background-color: #0a0
}

.ansi33 {
    color: #a50
}

.inv33 {
    background-color: #a50
}

.ansi34 {
    color: #00a
}

.inv34 {
    background-color: #00a
}

.ansi35 {
    color: #e850a8
}

.inv35 {
    background-color: #e850a8
}

.ansi36 {
    color: #0aa
}

.inv36 {
    background-color: #0aa
}

.ansi37 {
    color: #f5f1de
}

.inv37 {
    background-color: #f5f1de
}

.ansi40 {
    background-color: #000316
}

.inv40 {
    color: #000316
}

.ansi41 {
    background-color: #a00
}

.inv41 {
    color: #a00
}

.ansi42 {
    background-color: #0a0
}

.inv42 {
    color: #0a0
}

.ansi43 {
    background-color: #a50
}

.inv43 {
    color: #a50
}

.ansi44 {
    background-color: #00a
}

.inv44 {
    color: #00a
}

.ansi45 {
    background-color: #e850a8
}

.inv45 {
    color: #e850a8
}

.ansi46 {
    background-color: #0aa
}

.inv46 {
    color: #0aa
}

.ansi47 {
    background-color: #f5f1de
}

.inv47 {
    color: #f5f1de
}

.ansi38-0 {
    color: #000316
}

.inv38-0 {
    background-color: #000316
}

.ansi38-1 {
    color: #a00
}

.inv38-1 {
    background-color: #a00
}

.ansi38-2 {
    color: #0a0
}

.inv38-2 {
    background-color: #0a0
}

.ansi38-3 {
    color: #a50
}

.inv38-3 {
    background-color: #a50
}

.ansi38-4 {
    color: #00a
}

.inv38-4 {
    background-color: #00a
}

.ansi38-5 {
    color: #e850a8
}

.inv38-5 {
    background-color: #e850a8
}

.ansi38-6 {
    color: #0aa
}

.inv38-6 {
    background-color: #0aa
}

.ansi38-7 {
    color: #f5f1de
}

.inv38-7 {
    background-color: #f5f1de
}

.ansi38-8 {
    color: #7f7f7f
}

.inv38-8 {
    background-color: #7f7f7f
}

.ansi38-9 {
    color: red
}

.inv38-9 {
    background-color: red
}

.ansi38-10 {
    color: #0f0
}

.inv38-10 {
    background-color: #0f0
}

.ansi38-11 {
    color: #ff0
}

.inv38-11 {
    background-color: #ff0
}

.ansi38-12 {
    color: #5c5cff
}

.inv38-12 {
    background-color: #5c5cff
}

.ansi38-13 {
    color: #f0f
}

.inv38-13 {
    background-color: #f0f
}

.ansi38-14 {
    color: #0ff
}

.inv38-14 {
    background-color: #0ff
}

.ansi38-15 {
    color: #fff
}

.inv38-15 {
    background-color: #fff
}

.ansi48-0 {
    background-color: #000316
}

.inv48-0 {
    color: #000316
}

.ansi48-1 {
    background-color: #a00
}

.inv48-1 {
    color: #a00
}

.ansi48-2 {
    background-color: #0a0
}

.inv48-2 {
    color: #0a0
}

.ansi48-3 {
    background-color: #a50
}

.inv48-3 {
    color: #a50
}

.ansi48-4 {
    background-color: #00a
}

.inv48-4 {
    color: #00a
}

.ansi48-5 {
    background-color: #e850a8
}

.inv48-5 {
    color: #e850a8
}

.ansi48-6 {
    background-color: #0aa
}

.inv48-6 {
    color: #0aa
}

.ansi48-7 {
    background-color: #f5f1de
}

.inv48-7 {
    color: #f5f1de
}

.ansi48-8 {
    background-color: #7f7f7f
}

.inv48-8 {
    color: #7f7f7f
}

.ansi48-9 {
    background-color: red
}

.inv48-9 {
    color: red
}

.ansi48-10 {
    background-color: #0f0
}

.inv48-10 {
    color: #0f0
}

.ansi48-11 {
    background-color: #ff0
}

.inv48-11 {
    color: #ff0
}

.ansi48-12 {
    background-color: #5c5cff
}

.inv48-12 {
    color: #5c5cff
}

.ansi48-13 {
    background-color: #f0f
}

.inv48-13 {
    color: #f0f
}

.ansi48-14 {
    background-color: #0ff
}

.inv48-14 {
    color: #0ff
}

.ansi48-15 {
    background-color: #fff
}

.inv48-15 {
    color: #fff
}

.ansi38-16 {
    color: #000
}

.inv38-16 {
    background: #000
}

.ansi48-16 {
    background: #000
}

.inv48-16 {
    color: #000
}

.ansi38-17 {
    color: #00002a
}

.inv38-17 {
    background: #00002a
}

.ansi48-17 {
    background: #00002a
}

.inv48-17 {
    color: #00002a
}

.ansi38-18 {
    color: #000054
}

.inv38-18 {
    background: #000054
}

.ansi48-18 {
    background: #000054
}

.inv48-18 {
    color: #000054
}

.ansi38-19 {
    color: #00007e
}

.inv38-19 {
    background: #00007e
}

.ansi48-19 {
    background: #00007e
}

.inv48-19 {
    color: #00007e
}

.ansi38-20 {
    color: #0000a8
}

.inv38-20 {
    background: #0000a8
}

.ansi48-20 {
    background: #0000a8
}

.inv48-20 {
    color: #0000a8
}

.ansi38-21 {
    color: #0000d2
}

.inv38-21 {
    background: #0000d2
}

.ansi48-21 {
    background: #0000d2
}

.inv48-21 {
    color: #0000d2
}

.ansi38-52 {
    color: #2a0000
}

.inv38-52 {
    background: #2a0000
}

.ansi48-52 {
    background: #2a0000
}

.inv48-52 {
    color: #2a0000
}

.ansi38-53 {
    color: #2a002a
}

.inv38-53 {
    background: #2a002a
}

.ansi48-53 {
    background: #2a002a
}

.inv48-53 {
    color: #2a002a
}

.ansi38-54 {
    color: #2a0054
}

.inv38-54 {
    background: #2a0054
}

.ansi48-54 {
    background: #2a0054
}

.inv48-54 {
    color: #2a0054
}

.ansi38-55 {
    color: #2a007e
}

.inv38-55 {
    background: #2a007e
}

.ansi48-55 {
    background: #2a007e
}

.inv48-55 {
    color: #2a007e
}

.ansi38-56 {
    color: #2a00a8
}

.inv38-56 {
    background: #2a00a8
}

.ansi48-56 {
    background: #2a00a8
}

.inv48-56 {
    color: #2a00a8
}

.ansi38-57 {
    color: #2a00d2
}

.inv38-57 {
    background: #2a00d2
}

.ansi48-57 {
    background: #2a00d2
}

.inv48-57 {
    color: #2a00d2
}

.ansi38-88 {
    color: #540000
}

.inv38-88 {
    background: #540000
}

.ansi48-88 {
    background: #540000
}

.inv48-88 {
    color: #540000
}

.ansi38-89 {
    color: #54002a
}

.inv38-89 {
    background: #54002a
}

.ansi48-89 {
    background: #54002a
}

.inv48-89 {
    color: #54002a
}

.ansi38-90 {
    color: #540054
}

.inv38-90 {
    background: #540054
}

.ansi48-90 {
    background: #540054
}

.inv48-90 {
    color: #540054
}

.ansi38-91 {
    color: #54007e
}

.inv38-91 {
    background: #54007e
}

.ansi48-91 {
    background: #54007e
}

.inv48-91 {
    color: #54007e
}

.ansi38-92 {
    color: #5400a8
}

.inv38-92 {
    background: #5400a8
}

.ansi48-92 {
    background: #5400a8
}

.inv48-92 {
    color: #5400a8
}

.ansi38-93 {
    color: #5400d2
}

.inv38-93 {
    background: #5400d2
}

.ansi48-93 {
    background: #5400d2
}

.inv48-93 {
    color: #5400d2
}

.ansi38-124 {
    color: #7e0000
}

.inv38-124 {
    background: #7e0000
}

.ansi48-124 {
    background: #7e0000
}

.inv48-124 {
    color: #7e0000
}

.ansi38-125 {
    color: #7e002a
}

.inv38-125 {
    background: #7e002a
}

.ansi48-125 {
    background: #7e002a
}

.inv48-125 {
    color: #7e002a
}

.ansi38-126 {
    color: #7e0054
}

.inv38-126 {
    background: #7e0054
}

.ansi48-126 {
    background: #7e0054
}

.inv48-126 {
    color: #7e0054
}

.ansi38-127 {
    color: #7e007e
}

.inv38-127 {
    background: #7e007e
}

.ansi48-127 {
    background: #7e007e
}

.inv48-127 {
    color: #7e007e
}

.ansi38-128 {
    color: #7e00a8
}

.inv38-128 {
    background: #7e00a8
}

.ansi48-128 {
    background: #7e00a8
}

.inv48-128 {
    color: #7e00a8
}

.ansi38-129 {
    color: #7e00d2
}

.inv38-129 {
    background: #7e00d2
}

.ansi48-129 {
    background: #7e00d2
}

.inv48-129 {
    color: #7e00d2
}

.ansi38-160 {
    color: #a80000
}

.inv38-160 {
    background: #a80000
}

.ansi48-160 {
    background: #a80000
}

.inv48-160 {
    color: #a80000
}

.ansi38-161 {
    color: #a8002a
}

.inv38-161 {
    background: #a8002a
}

.ansi48-161 {
    background: #a8002a
}

.inv48-161 {
    color: #a8002a
}

.ansi38-162 {
    color: #a80054
}

.inv38-162 {
    background: #a80054
}

.ansi48-162 {
    background: #a80054
}

.inv48-162 {
    color: #a80054
}

.ansi38-163 {
    color: #a8007e
}

.inv38-163 {
    background: #a8007e
}

.ansi48-163 {
    background: #a8007e
}

.inv48-163 {
    color: #a8007e
}

.ansi38-164 {
    color: #a800a8
}

.inv38-164 {
    background: #a800a8
}

.ansi48-164 {
    background: #a800a8
}

.inv48-164 {
    color: #a800a8
}

.ansi38-165 {
    color: #a800d2
}

.inv38-165 {
    background: #a800d2
}

.ansi48-165 {
    background: #a800d2
}

.inv48-165 {
    color: #a800d2
}

.ansi38-196 {
    color: #d20000
}

.inv38-196 {
    background: #d20000
}

.ansi48-196 {
    background: #d20000
}

.inv48-196 {
    color: #d20000
}

.ansi38-197 {
    color: #d2002a
}

.inv38-197 {
    background: #d2002a
}

.ansi48-197 {
    background: #d2002a
}

.inv48-197 {
    color: #d2002a
}

.ansi38-198 {
    color: #d20054
}

.inv38-198 {
    background: #d20054
}

.ansi48-198 {
    background: #d20054
}

.inv48-198 {
    color: #d20054
}

.ansi38-199 {
    color: #d2007e
}

.inv38-199 {
    background: #d2007e
}

.ansi48-199 {
    background: #d2007e
}

.inv48-199 {
    color: #d2007e
}

.ansi38-200 {
    color: #d200a8
}

.inv38-200 {
    background: #d200a8
}

.ansi48-200 {
    background: #d200a8
}

.inv48-200 {
    color: #d200a8
}

.ansi38-201 {
    color: #d200d2
}

.inv38-201 {
    background: #d200d2
}

.ansi48-201 {
    background: #d200d2
}

.inv48-201 {
    color: #d200d2
}

.ansi38-22 {
    color: #002a00
}

.inv38-22 {
    background: #002a00
}

.ansi48-22 {
    background: #002a00
}

.inv48-22 {
    color: #002a00
}

.ansi38-23 {
    color: #002a2a
}

.inv38-23 {
    background: #002a2a
}

.ansi48-23 {
    background: #002a2a
}

.inv48-23 {
    color: #002a2a
}

.ansi38-24 {
    color: #002a54
}

.inv38-24 {
    background: #002a54
}

.ansi48-24 {
    background: #002a54
}

.inv48-24 {
    color: #002a54
}

.ansi38-25 {
    color: #002a7e
}

.inv38-25 {
    background: #002a7e
}

.ansi48-25 {
    background: #002a7e
}

.inv48-25 {
    color: #002a7e
}

.ansi38-26 {
    color: #002aa8
}

.inv38-26 {
    background: #002aa8
}

.ansi48-26 {
    background: #002aa8
}

.inv48-26 {
    color: #002aa8
}

.ansi38-27 {
    color: #002ad2
}

.inv38-27 {
    background: #002ad2
}

.ansi48-27 {
    background: #002ad2
}

.inv48-27 {
    color: #002ad2
}

.ansi38-58 {
    color: #2a2a00
}

.inv38-58 {
    background: #2a2a00
}

.ansi48-58 {
    background: #2a2a00
}

.inv48-58 {
    color: #2a2a00
}

.ansi38-59 {
    color: #2a2a2a
}

.inv38-59 {
    background: #2a2a2a
}

.ansi48-59 {
    background: #2a2a2a
}

.inv48-59 {
    color: #2a2a2a
}

.ansi38-60 {
    color: #2a2a54
}

.inv38-60 {
    background: #2a2a54
}

.ansi48-60 {
    background: #2a2a54
}

.inv48-60 {
    color: #2a2a54
}

.ansi38-61 {
    color: #2a2a7e
}

.inv38-61 {
    background: #2a2a7e
}

.ansi48-61 {
    background: #2a2a7e
}

.inv48-61 {
    color: #2a2a7e
}

.ansi38-62 {
    color: #2a2aa8
}

.inv38-62 {
    background: #2a2aa8
}

.ansi48-62 {
    background: #2a2aa8
}

.inv48-62 {
    color: #2a2aa8
}

.ansi38-63 {
    color: #2a2ad2
}

.inv38-63 {
    background: #2a2ad2
}

.ansi48-63 {
    background: #2a2ad2
}

.inv48-63 {
    color: #2a2ad2
}

.ansi38-94 {
    color: #542a00
}

.inv38-94 {
    background: #542a00
}

.ansi48-94 {
    background: #542a00
}

.inv48-94 {
    color: #542a00
}

.ansi38-95 {
    color: #542a2a
}

.inv38-95 {
    background: #542a2a
}

.ansi48-95 {
    background: #542a2a
}

.inv48-95 {
    color: #542a2a
}

.ansi38-96 {
    color: #542a54
}

.inv38-96 {
    background: #542a54
}

.ansi48-96 {
    background: #542a54
}

.inv48-96 {
    color: #542a54
}

.ansi38-97 {
    color: #542a7e
}

.inv38-97 {
    background: #542a7e
}

.ansi48-97 {
    background: #542a7e
}

.inv48-97 {
    color: #542a7e
}

.ansi38-98 {
    color: #542aa8
}

.inv38-98 {
    background: #542aa8
}

.ansi48-98 {
    background: #542aa8
}

.inv48-98 {
    color: #542aa8
}

.ansi38-99 {
    color: #542ad2
}

.inv38-99 {
    background: #542ad2
}

.ansi48-99 {
    background: #542ad2
}

.inv48-99 {
    color: #542ad2
}

.ansi38-130 {
    color: #7e2a00
}

.inv38-130 {
    background: #7e2a00
}

.ansi48-130 {
    background: #7e2a00
}

.inv48-130 {
    color: #7e2a00
}

.ansi38-131 {
    color: #7e2a2a
}

.inv38-131 {
    background: #7e2a2a
}

.ansi48-131 {
    background: #7e2a2a
}

.inv48-131 {
    color: #7e2a2a
}

.ansi38-132 {
    color: #7e2a54
}

.inv38-132 {
    background: #7e2a54
}

.ansi48-132 {
    background: #7e2a54
}

.inv48-132 {
    color: #7e2a54
}

.ansi38-133 {
    color: #7e2a7e
}

.inv38-133 {
    background: #7e2a7e
}

.ansi48-133 {
    background: #7e2a7e
}

.inv48-133 {
    color: #7e2a7e
}

.ansi38-134 {
    color: #7e2aa8
}

.inv38-134 {
    background: #7e2aa8
}

.ansi48-134 {
    background: #7e2aa8
}

.inv48-134 {
    color: #7e2aa8
}

.ansi38-135 {
    color: #7e2ad2
}

.inv38-135 {
    background: #7e2ad2
}

.ansi48-135 {
    background: #7e2ad2
}

.inv48-135 {
    color: #7e2ad2
}

.ansi38-166 {
    color: #a82a00
}

.inv38-166 {
    background: #a82a00
}

.ansi48-166 {
    background: #a82a00
}

.inv48-166 {
    color: #a82a00
}

.ansi38-167 {
    color: #a82a2a
}

.inv38-167 {
    background: #a82a2a
}

.ansi48-167 {
    background: #a82a2a
}

.inv48-167 {
    color: #a82a2a
}

.ansi38-168 {
    color: #a82a54
}

.inv38-168 {
    background: #a82a54
}

.ansi48-168 {
    background: #a82a54
}

.inv48-168 {
    color: #a82a54
}

.ansi38-169 {
    color: #a82a7e
}

.inv38-169 {
    background: #a82a7e
}

.ansi48-169 {
    background: #a82a7e
}

.inv48-169 {
    color: #a82a7e
}

.ansi38-170 {
    color: #a82aa8
}

.inv38-170 {
    background: #a82aa8
}

.ansi48-170 {
    background: #a82aa8
}

.inv48-170 {
    color: #a82aa8
}

.ansi38-171 {
    color: #a82ad2
}

.inv38-171 {
    background: #a82ad2
}

.ansi48-171 {
    background: #a82ad2
}

.inv48-171 {
    color: #a82ad2
}

.ansi38-202 {
    color: #d22a00
}

.inv38-202 {
    background: #d22a00
}

.ansi48-202 {
    background: #d22a00
}

.inv48-202 {
    color: #d22a00
}

.ansi38-203 {
    color: #d22a2a
}

.inv38-203 {
    background: #d22a2a
}

.ansi48-203 {
    background: #d22a2a
}

.inv48-203 {
    color: #d22a2a
}

.ansi38-204 {
    color: #d22a54
}

.inv38-204 {
    background: #d22a54
}

.ansi48-204 {
    background: #d22a54
}

.inv48-204 {
    color: #d22a54
}

.ansi38-205 {
    color: #d22a7e
}

.inv38-205 {
    background: #d22a7e
}

.ansi48-205 {
    background: #d22a7e
}

.inv48-205 {
    color: #d22a7e
}

.ansi38-206 {
    color: #d22aa8
}

.inv38-206 {
    background: #d22aa8
}

.ansi48-206 {
    background: #d22aa8
}

.inv48-206 {
    color: #d22aa8
}

.ansi38-207 {
    color: #d22ad2
}

.inv38-207 {
    background: #d22ad2
}

.ansi48-207 {
    background: #d22ad2
}

.inv48-207 {
    color: #d22ad2
}

.ansi38-28 {
    color: #005400
}

.inv38-28 {
    background: #005400
}

.ansi48-28 {
    background: #005400
}

.inv48-28 {
    color: #005400
}

.ansi38-29 {
    color: #00542a
}

.inv38-29 {
    background: #00542a
}

.ansi48-29 {
    background: #00542a
}

.inv48-29 {
    color: #00542a
}

.ansi38-30 {
    color: #005454
}

.inv38-30 {
    background: #005454
}

.ansi48-30 {
    background: #005454
}

.inv48-30 {
    color: #005454
}

.ansi38-31 {
    color: #00547e
}

.inv38-31 {
    background: #00547e
}

.ansi48-31 {
    background: #00547e
}

.inv48-31 {
    color: #00547e
}

.ansi38-32 {
    color: #0054a8
}

.inv38-32 {
    background: #0054a8
}

.ansi48-32 {
    background: #0054a8
}

.inv48-32 {
    color: #0054a8
}

.ansi38-33 {
    color: #0054d2
}

.inv38-33 {
    background: #0054d2
}

.ansi48-33 {
    background: #0054d2
}

.inv48-33 {
    color: #0054d2
}

.ansi38-64 {
    color: #2a5400
}

.inv38-64 {
    background: #2a5400
}

.ansi48-64 {
    background: #2a5400
}

.inv48-64 {
    color: #2a5400
}

.ansi38-65 {
    color: #2a542a
}

.inv38-65 {
    background: #2a542a
}

.ansi48-65 {
    background: #2a542a
}

.inv48-65 {
    color: #2a542a
}

.ansi38-66 {
    color: #2a5454
}

.inv38-66 {
    background: #2a5454
}

.ansi48-66 {
    background: #2a5454
}

.inv48-66 {
    color: #2a5454
}

.ansi38-67 {
    color: #2a547e
}

.inv38-67 {
    background: #2a547e
}

.ansi48-67 {
    background: #2a547e
}

.inv48-67 {
    color: #2a547e
}

.ansi38-68 {
    color: #2a54a8
}

.inv38-68 {
    background: #2a54a8
}

.ansi48-68 {
    background: #2a54a8
}

.inv48-68 {
    color: #2a54a8
}

.ansi38-69 {
    color: #2a54d2
}

.inv38-69 {
    background: #2a54d2
}

.ansi48-69 {
    background: #2a54d2
}

.inv48-69 {
    color: #2a54d2
}

.ansi38-100 {
    color: #545400
}

.inv38-100 {
    background: #545400
}

.ansi48-100 {
    background: #545400
}

.inv48-100 {
    color: #545400
}

.ansi38-101 {
    color: #54542a
}

.inv38-101 {
    background: #54542a
}

.ansi48-101 {
    background: #54542a
}

.inv48-101 {
    color: #54542a
}

.ansi38-102 {
    color: #545454
}

.inv38-102 {
    background: #545454
}

.ansi48-102 {
    background: #545454
}

.inv48-102 {
    color: #545454
}

.ansi38-103 {
    color: #54547e
}

.inv38-103 {
    background: #54547e
}

.ansi48-103 {
    background: #54547e
}

.inv48-103 {
    color: #54547e
}

.ansi38-104 {
    color: #5454a8
}

.inv38-104 {
    background: #5454a8
}

.ansi48-104 {
    background: #5454a8
}

.inv48-104 {
    color: #5454a8
}

.ansi38-105 {
    color: #5454d2
}

.inv38-105 {
    background: #5454d2
}

.ansi48-105 {
    background: #5454d2
}

.inv48-105 {
    color: #5454d2
}

.ansi38-136 {
    color: #7e5400
}

.inv38-136 {
    background: #7e5400
}

.ansi48-136 {
    background: #7e5400
}

.inv48-136 {
    color: #7e5400
}

.ansi38-137 {
    color: #7e542a
}

.inv38-137 {
    background: #7e542a
}

.ansi48-137 {
    background: #7e542a
}

.inv48-137 {
    color: #7e542a
}

.ansi38-138 {
    color: #7e5454
}

.inv38-138 {
    background: #7e5454
}

.ansi48-138 {
    background: #7e5454
}

.inv48-138 {
    color: #7e5454
}

.ansi38-139 {
    color: #7e547e
}

.inv38-139 {
    background: #7e547e
}

.ansi48-139 {
    background: #7e547e
}

.inv48-139 {
    color: #7e547e
}

.ansi38-140 {
    color: #7e54a8
}

.inv38-140 {
    background: #7e54a8
}

.ansi48-140 {
    background: #7e54a8
}

.inv48-140 {
    color: #7e54a8
}

.ansi38-141 {
    color: #7e54d2
}

.inv38-141 {
    background: #7e54d2
}

.ansi48-141 {
    background: #7e54d2
}

.inv48-141 {
    color: #7e54d2
}

.ansi38-172 {
    color: #a85400
}

.inv38-172 {
    background: #a85400
}

.ansi48-172 {
    background: #a85400
}

.inv48-172 {
    color: #a85400
}

.ansi38-173 {
    color: #a8542a
}

.inv38-173 {
    background: #a8542a
}

.ansi48-173 {
    background: #a8542a
}

.inv48-173 {
    color: #a8542a
}

.ansi38-174 {
    color: #a85454
}

.inv38-174 {
    background: #a85454
}

.ansi48-174 {
    background: #a85454
}

.inv48-174 {
    color: #a85454
}

.ansi38-175 {
    color: #a8547e
}

.inv38-175 {
    background: #a8547e
}

.ansi48-175 {
    background: #a8547e
}

.inv48-175 {
    color: #a8547e
}

.ansi38-176 {
    color: #a854a8
}

.inv38-176 {
    background: #a854a8
}

.ansi48-176 {
    background: #a854a8
}

.inv48-176 {
    color: #a854a8
}

.ansi38-177 {
    color: #a854d2
}

.inv38-177 {
    background: #a854d2
}

.ansi48-177 {
    background: #a854d2
}

.inv48-177 {
    color: #a854d2
}

.ansi38-208 {
    color: #d25400
}

.inv38-208 {
    background: #d25400
}

.ansi48-208 {
    background: #d25400
}

.inv48-208 {
    color: #d25400
}

.ansi38-209 {
    color: #d2542a
}

.inv38-209 {
    background: #d2542a
}

.ansi48-209 {
    background: #d2542a
}

.inv48-209 {
    color: #d2542a
}

.ansi38-210 {
    color: #d25454
}

.inv38-210 {
    background: #d25454
}

.ansi48-210 {
    background: #d25454
}

.inv48-210 {
    color: #d25454
}

.ansi38-211 {
    color: #d2547e
}

.inv38-211 {
    background: #d2547e
}

.ansi48-211 {
    background: #d2547e
}

.inv48-211 {
    color: #d2547e
}

.ansi38-212 {
    color: #d254a8
}

.inv38-212 {
    background: #d254a8
}

.ansi48-212 {
    background: #d254a8
}

.inv48-212 {
    color: #d254a8
}

.ansi38-213 {
    color: #d254d2
}

.inv38-213 {
    background: #d254d2
}

.ansi48-213 {
    background: #d254d2
}

.inv48-213 {
    color: #d254d2
}

.ansi38-34 {
    color: #007e00
}

.inv38-34 {
    background: #007e00
}

.ansi48-34 {
    background: #007e00
}

.inv48-34 {
    color: #007e00
}

.ansi38-35 {
    color: #007e2a
}

.inv38-35 {
    background: #007e2a
}

.ansi48-35 {
    background: #007e2a
}

.inv48-35 {
    color: #007e2a
}

.ansi38-36 {
    color: #007e54
}

.inv38-36 {
    background: #007e54
}

.ansi48-36 {
    background: #007e54
}

.inv48-36 {
    color: #007e54
}

.ansi38-37 {
    color: #007e7e
}

.inv38-37 {
    background: #007e7e
}

.ansi48-37 {
    background: #007e7e
}

.inv48-37 {
    color: #007e7e
}

.ansi38-38 {
    color: #007ea8
}

.inv38-38 {
    background: #007ea8
}

.ansi48-38 {
    background: #007ea8
}

.inv48-38 {
    color: #007ea8
}

.ansi38-39 {
    color: #007ed2
}

.inv38-39 {
    background: #007ed2
}

.ansi48-39 {
    background: #007ed2
}

.inv48-39 {
    color: #007ed2
}

.ansi38-70 {
    color: #2a7e00
}

.inv38-70 {
    background: #2a7e00
}

.ansi48-70 {
    background: #2a7e00
}

.inv48-70 {
    color: #2a7e00
}

.ansi38-71 {
    color: #2a7e2a
}

.inv38-71 {
    background: #2a7e2a
}

.ansi48-71 {
    background: #2a7e2a
}

.inv48-71 {
    color: #2a7e2a
}

.ansi38-72 {
    color: #2a7e54
}

.inv38-72 {
    background: #2a7e54
}

.ansi48-72 {
    background: #2a7e54
}

.inv48-72 {
    color: #2a7e54
}

.ansi38-73 {
    color: #2a7e7e
}

.inv38-73 {
    background: #2a7e7e
}

.ansi48-73 {
    background: #2a7e7e
}

.inv48-73 {
    color: #2a7e7e
}

.ansi38-74 {
    color: #2a7ea8
}

.inv38-74 {
    background: #2a7ea8
}

.ansi48-74 {
    background: #2a7ea8
}

.inv48-74 {
    color: #2a7ea8
}

.ansi38-75 {
    color: #2a7ed2
}

.inv38-75 {
    background: #2a7ed2
}

.ansi48-75 {
    background: #2a7ed2
}

.inv48-75 {
    color: #2a7ed2
}

.ansi38-106 {
    color: #547e00
}

.inv38-106 {
    background: #547e00
}

.ansi48-106 {
    background: #547e00
}

.inv48-106 {
    color: #547e00
}

.ansi38-107 {
    color: #547e2a
}

.inv38-107 {
    background: #547e2a
}

.ansi48-107 {
    background: #547e2a
}

.inv48-107 {
    color: #547e2a
}

.ansi38-108 {
    color: #547e54
}

.inv38-108 {
    background: #547e54
}

.ansi48-108 {
    background: #547e54
}

.inv48-108 {
    color: #547e54
}

.ansi38-109 {
    color: #547e7e
}

.inv38-109 {
    background: #547e7e
}

.ansi48-109 {
    background: #547e7e
}

.inv48-109 {
    color: #547e7e
}

.ansi38-110 {
    color: #547ea8
}

.inv38-110 {
    background: #547ea8
}

.ansi48-110 {
    background: #547ea8
}

.inv48-110 {
    color: #547ea8
}

.ansi38-111 {
    color: #547ed2
}

.inv38-111 {
    background: #547ed2
}

.ansi48-111 {
    background: #547ed2
}

.inv48-111 {
    color: #547ed2
}

.ansi38-142 {
    color: #7e7e00
}

.inv38-142 {
    background: #7e7e00
}

.ansi48-142 {
    background: #7e7e00
}

.inv48-142 {
    color: #7e7e00
}

.ansi38-143 {
    color: #7e7e2a
}

.inv38-143 {
    background: #7e7e2a
}

.ansi48-143 {
    background: #7e7e2a
}

.inv48-143 {
    color: #7e7e2a
}

.ansi38-144 {
    color: #7e7e54
}

.inv38-144 {
    background: #7e7e54
}

.ansi48-144 {
    background: #7e7e54
}

.inv48-144 {
    color: #7e7e54
}

.ansi38-145 {
    color: #7e7e7e
}

.inv38-145 {
    background: #7e7e7e
}

.ansi48-145 {
    background: #7e7e7e
}

.inv48-145 {
    color: #7e7e7e
}

.ansi38-146 {
    color: #7e7ea8
}

.inv38-146 {
    background: #7e7ea8
}

.ansi48-146 {
    background: #7e7ea8
}

.inv48-146 {
    color: #7e7ea8
}

.ansi38-147 {
    color: #7e7ed2
}

.inv38-147 {
    background: #7e7ed2
}

.ansi48-147 {
    background: #7e7ed2
}

.inv48-147 {
    color: #7e7ed2
}

.ansi38-178 {
    color: #a87e00
}

.inv38-178 {
    background: #a87e00
}

.ansi48-178 {
    background: #a87e00
}

.inv48-178 {
    color: #a87e00
}

.ansi38-179 {
    color: #a87e2a
}

.inv38-179 {
    background: #a87e2a
}

.ansi48-179 {
    background: #a87e2a
}

.inv48-179 {
    color: #a87e2a
}

.ansi38-180 {
    color: #a87e54
}

.inv38-180 {
    background: #a87e54
}

.ansi48-180 {
    background: #a87e54
}

.inv48-180 {
    color: #a87e54
}

.ansi38-181 {
    color: #a87e7e
}

.inv38-181 {
    background: #a87e7e
}

.ansi48-181 {
    background: #a87e7e
}

.inv48-181 {
    color: #a87e7e
}

.ansi38-182 {
    color: #a87ea8
}

.inv38-182 {
    background: #a87ea8
}

.ansi48-182 {
    background: #a87ea8
}

.inv48-182 {
    color: #a87ea8
}

.ansi38-183 {
    color: #a87ed2
}

.inv38-183 {
    background: #a87ed2
}

.ansi48-183 {
    background: #a87ed2
}

.inv48-183 {
    color: #a87ed2
}

.ansi38-214 {
    color: #d27e00
}

.inv38-214 {
    background: #d27e00
}

.ansi48-214 {
    background: #d27e00
}

.inv48-214 {
    color: #d27e00
}

.ansi38-215 {
    color: #d27e2a
}

.inv38-215 {
    background: #d27e2a
}

.ansi48-215 {
    background: #d27e2a
}

.inv48-215 {
    color: #d27e2a
}

.ansi38-216 {
    color: #d27e54
}

.inv38-216 {
    background: #d27e54
}

.ansi48-216 {
    background: #d27e54
}

.inv48-216 {
    color: #d27e54
}

.ansi38-217 {
    color: #d27e7e
}

.inv38-217 {
    background: #d27e7e
}

.ansi48-217 {
    background: #d27e7e
}

.inv48-217 {
    color: #d27e7e
}

.ansi38-218 {
    color: #d27ea8
}

.inv38-218 {
    background: #d27ea8
}

.ansi48-218 {
    background: #d27ea8
}

.inv48-218 {
    color: #d27ea8
}

.ansi38-219 {
    color: #d27ed2
}

.inv38-219 {
    background: #d27ed2
}

.ansi48-219 {
    background: #d27ed2
}

.inv48-219 {
    color: #d27ed2
}

.ansi38-40 {
    color: #00a800
}

.inv38-40 {
    background: #00a800
}

.ansi48-40 {
    background: #00a800
}

.inv48-40 {
    color: #00a800
}

.ansi38-41 {
    color: #00a82a
}

.inv38-41 {
    background: #00a82a
}

.ansi48-41 {
    background: #00a82a
}

.inv48-41 {
    color: #00a82a
}

.ansi38-42 {
    color: #00a854
}

.inv38-42 {
    background: #00a854
}

.ansi48-42 {
    background: #00a854
}

.inv48-42 {
    color: #00a854
}

.ansi38-43 {
    color: #00a87e
}

.inv38-43 {
    background: #00a87e
}

.ansi48-43 {
    background: #00a87e
}

.inv48-43 {
    color: #00a87e
}

.ansi38-44 {
    color: #00a8a8
}

.inv38-44 {
    background: #00a8a8
}

.ansi48-44 {
    background: #00a8a8
}

.inv48-44 {
    color: #00a8a8
}

.ansi38-45 {
    color: #00a8d2
}

.inv38-45 {
    background: #00a8d2
}

.ansi48-45 {
    background: #00a8d2
}

.inv48-45 {
    color: #00a8d2
}

.ansi38-76 {
    color: #2aa800
}

.inv38-76 {
    background: #2aa800
}

.ansi48-76 {
    background: #2aa800
}

.inv48-76 {
    color: #2aa800
}

.ansi38-77 {
    color: #2aa82a
}

.inv38-77 {
    background: #2aa82a
}

.ansi48-77 {
    background: #2aa82a
}

.inv48-77 {
    color: #2aa82a
}

.ansi38-78 {
    color: #2aa854
}

.inv38-78 {
    background: #2aa854
}

.ansi48-78 {
    background: #2aa854
}

.inv48-78 {
    color: #2aa854
}

.ansi38-79 {
    color: #2aa87e
}

.inv38-79 {
    background: #2aa87e
}

.ansi48-79 {
    background: #2aa87e
}

.inv48-79 {
    color: #2aa87e
}

.ansi38-80 {
    color: #2aa8a8
}

.inv38-80 {
    background: #2aa8a8
}

.ansi48-80 {
    background: #2aa8a8
}

.inv48-80 {
    color: #2aa8a8
}

.ansi38-81 {
    color: #2aa8d2
}

.inv38-81 {
    background: #2aa8d2
}

.ansi48-81 {
    background: #2aa8d2
}

.inv48-81 {
    color: #2aa8d2
}

.ansi38-112 {
    color: #54a800
}

.inv38-112 {
    background: #54a800
}

.ansi48-112 {
    background: #54a800
}

.inv48-112 {
    color: #54a800
}

.ansi38-113 {
    color: #54a82a
}

.inv38-113 {
    background: #54a82a
}

.ansi48-113 {
    background: #54a82a
}

.inv48-113 {
    color: #54a82a
}

.ansi38-114 {
    color: #54a854
}

.inv38-114 {
    background: #54a854
}

.ansi48-114 {
    background: #54a854
}

.inv48-114 {
    color: #54a854
}

.ansi38-115 {
    color: #54a87e
}

.inv38-115 {
    background: #54a87e
}

.ansi48-115 {
    background: #54a87e
}

.inv48-115 {
    color: #54a87e
}

.ansi38-116 {
    color: #54a8a8
}

.inv38-116 {
    background: #54a8a8
}

.ansi48-116 {
    background: #54a8a8
}

.inv48-116 {
    color: #54a8a8
}

.ansi38-117 {
    color: #54a8d2
}

.inv38-117 {
    background: #54a8d2
}

.ansi48-117 {
    background: #54a8d2
}

.inv48-117 {
    color: #54a8d2
}

.ansi38-148 {
    color: #7ea800
}

.inv38-148 {
    background: #7ea800
}

.ansi48-148 {
    background: #7ea800
}

.inv48-148 {
    color: #7ea800
}

.ansi38-149 {
    color: #7ea82a
}

.inv38-149 {
    background: #7ea82a
}

.ansi48-149 {
    background: #7ea82a
}

.inv48-149 {
    color: #7ea82a
}

.ansi38-150 {
    color: #7ea854
}

.inv38-150 {
    background: #7ea854
}

.ansi48-150 {
    background: #7ea854
}

.inv48-150 {
    color: #7ea854
}

.ansi38-151 {
    color: #7ea87e
}

.inv38-151 {
    background: #7ea87e
}

.ansi48-151 {
    background: #7ea87e
}

.inv48-151 {
    color: #7ea87e
}

.ansi38-152 {
    color: #7ea8a8
}

.inv38-152 {
    background: #7ea8a8
}

.ansi48-152 {
    background: #7ea8a8
}

.inv48-152 {
    color: #7ea8a8
}

.ansi38-153 {
    color: #7ea8d2
}

.inv38-153 {
    background: #7ea8d2
}

.ansi48-153 {
    background: #7ea8d2
}

.inv48-153 {
    color: #7ea8d2
}

.ansi38-184 {
    color: #a8a800
}

.inv38-184 {
    background: #a8a800
}

.ansi48-184 {
    background: #a8a800
}

.inv48-184 {
    color: #a8a800
}

.ansi38-185 {
    color: #a8a82a
}

.inv38-185 {
    background: #a8a82a
}

.ansi48-185 {
    background: #a8a82a
}

.inv48-185 {
    color: #a8a82a
}

.ansi38-186 {
    color: #a8a854
}

.inv38-186 {
    background: #a8a854
}

.ansi48-186 {
    background: #a8a854
}

.inv48-186 {
    color: #a8a854
}

.ansi38-187 {
    color: #a8a87e
}

.inv38-187 {
    background: #a8a87e
}

.ansi48-187 {
    background: #a8a87e
}

.inv48-187 {
    color: #a8a87e
}

.ansi38-188 {
    color: #a8a8a8
}

.inv38-188 {
    background: #a8a8a8
}

.ansi48-188 {
    background: #a8a8a8
}

.inv48-188 {
    color: #a8a8a8
}

.ansi38-189 {
    color: #a8a8d2
}

.inv38-189 {
    background: #a8a8d2
}

.ansi48-189 {
    background: #a8a8d2
}

.inv48-189 {
    color: #a8a8d2
}

.ansi38-220 {
    color: #d2a800
}

.inv38-220 {
    background: #d2a800
}

.ansi48-220 {
    background: #d2a800
}

.inv48-220 {
    color: #d2a800
}

.ansi38-221 {
    color: #d2a82a
}

.inv38-221 {
    background: #d2a82a
}

.ansi48-221 {
    background: #d2a82a
}

.inv48-221 {
    color: #d2a82a
}

.ansi38-222 {
    color: #d2a854
}

.inv38-222 {
    background: #d2a854
}

.ansi48-222 {
    background: #d2a854
}

.inv48-222 {
    color: #d2a854
}

.ansi38-223 {
    color: #d2a87e
}

.inv38-223 {
    background: #d2a87e
}

.ansi48-223 {
    background: #d2a87e
}

.inv48-223 {
    color: #d2a87e
}

.ansi38-224 {
    color: #d2a8a8
}

.inv38-224 {
    background: #d2a8a8
}

.ansi48-224 {
    background: #d2a8a8
}

.inv48-224 {
    color: #d2a8a8
}

.ansi38-225 {
    color: #d2a8d2
}

.inv38-225 {
    background: #d2a8d2
}

.ansi48-225 {
    background: #d2a8d2
}

.inv48-225 {
    color: #d2a8d2
}

.ansi38-46 {
    color: #00d200
}

.inv38-46 {
    background: #00d200
}

.ansi48-46 {
    background: #00d200
}

.inv48-46 {
    color: #00d200
}

.ansi38-47 {
    color: #00d22a
}

.inv38-47 {
    background: #00d22a
}

.ansi48-47 {
    background: #00d22a
}

.inv48-47 {
    color: #00d22a
}

.ansi38-48 {
    color: #00d254
}

.inv38-48 {
    background: #00d254
}

.ansi48-48 {
    background: #00d254
}

.inv48-48 {
    color: #00d254
}

.ansi38-49 {
    color: #00d27e
}

.inv38-49 {
    background: #00d27e
}

.ansi48-49 {
    background: #00d27e
}

.inv48-49 {
    color: #00d27e
}

.ansi38-50 {
    color: #00d2a8
}

.inv38-50 {
    background: #00d2a8
}

.ansi48-50 {
    background: #00d2a8
}

.inv48-50 {
    color: #00d2a8
}

.ansi38-51 {
    color: #00d2d2
}

.inv38-51 {
    background: #00d2d2
}

.ansi48-51 {
    background: #00d2d2
}

.inv48-51 {
    color: #00d2d2
}

.ansi38-82 {
    color: #2ad200
}

.inv38-82 {
    background: #2ad200
}

.ansi48-82 {
    background: #2ad200
}

.inv48-82 {
    color: #2ad200
}

.ansi38-83 {
    color: #2ad22a
}

.inv38-83 {
    background: #2ad22a
}

.ansi48-83 {
    background: #2ad22a
}

.inv48-83 {
    color: #2ad22a
}

.ansi38-84 {
    color: #2ad254
}

.inv38-84 {
    background: #2ad254
}

.ansi48-84 {
    background: #2ad254
}

.inv48-84 {
    color: #2ad254
}

.ansi38-85 {
    color: #2ad27e
}

.inv38-85 {
    background: #2ad27e
}

.ansi48-85 {
    background: #2ad27e
}

.inv48-85 {
    color: #2ad27e
}

.ansi38-86 {
    color: #2ad2a8
}

.inv38-86 {
    background: #2ad2a8
}

.ansi48-86 {
    background: #2ad2a8
}

.inv48-86 {
    color: #2ad2a8
}

.ansi38-87 {
    color: #2ad2d2
}

.inv38-87 {
    background: #2ad2d2
}

.ansi48-87 {
    background: #2ad2d2
}

.inv48-87 {
    color: #2ad2d2
}

.ansi38-118 {
    color: #54d200
}

.inv38-118 {
    background: #54d200
}

.ansi48-118 {
    background: #54d200
}

.inv48-118 {
    color: #54d200
}

.ansi38-119 {
    color: #54d22a
}

.inv38-119 {
    background: #54d22a
}

.ansi48-119 {
    background: #54d22a
}

.inv48-119 {
    color: #54d22a
}

.ansi38-120 {
    color: #54d254
}

.inv38-120 {
    background: #54d254
}

.ansi48-120 {
    background: #54d254
}

.inv48-120 {
    color: #54d254
}

.ansi38-121 {
    color: #54d27e
}

.inv38-121 {
    background: #54d27e
}

.ansi48-121 {
    background: #54d27e
}

.inv48-121 {
    color: #54d27e
}

.ansi38-122 {
    color: #54d2a8
}

.inv38-122 {
    background: #54d2a8
}

.ansi48-122 {
    background: #54d2a8
}

.inv48-122 {
    color: #54d2a8
}

.ansi38-123 {
    color: #54d2d2
}

.inv38-123 {
    background: #54d2d2
}

.ansi48-123 {
    background: #54d2d2
}

.inv48-123 {
    color: #54d2d2
}

.ansi38-154 {
    color: #7ed200
}

.inv38-154 {
    background: #7ed200
}

.ansi48-154 {
    background: #7ed200
}

.inv48-154 {
    color: #7ed200
}

.ansi38-155 {
    color: #7ed22a
}

.inv38-155 {
    background: #7ed22a
}

.ansi48-155 {
    background: #7ed22a
}

.inv48-155 {
    color: #7ed22a
}

.ansi38-156 {
    color: #7ed254
}

.inv38-156 {
    background: #7ed254
}

.ansi48-156 {
    background: #7ed254
}

.inv48-156 {
    color: #7ed254
}

.ansi38-157 {
    color: #7ed27e
}

.inv38-157 {
    background: #7ed27e
}

.ansi48-157 {
    background: #7ed27e
}

.inv48-157 {
    color: #7ed27e
}

.ansi38-158 {
    color: #7ed2a8
}

.inv38-158 {
    background: #7ed2a8
}

.ansi48-158 {
    background: #7ed2a8
}

.inv48-158 {
    color: #7ed2a8
}

.ansi38-159 {
    color: #7ed2d2
}

.inv38-159 {
    background: #7ed2d2
}

.ansi48-159 {
    background: #7ed2d2
}

.inv48-159 {
    color: #7ed2d2
}

.ansi38-190 {
    color: #a8d200
}

.inv38-190 {
    background: #a8d200
}

.ansi48-190 {
    background: #a8d200
}

.inv48-190 {
    color: #a8d200
}

.ansi38-191 {
    color: #a8d22a
}

.inv38-191 {
    background: #a8d22a
}

.ansi48-191 {
    background: #a8d22a
}

.inv48-191 {
    color: #a8d22a
}

.ansi38-192 {
    color: #a8d254
}

.inv38-192 {
    background: #a8d254
}

.ansi48-192 {
    background: #a8d254
}

.inv48-192 {
    color: #a8d254
}

.ansi38-193 {
    color: #a8d27e
}

.inv38-193 {
    background: #a8d27e
}

.ansi48-193 {
    background: #a8d27e
}

.inv48-193 {
    color: #a8d27e
}

.ansi38-194 {
    color: #a8d2a8
}

.inv38-194 {
    background: #a8d2a8
}

.ansi48-194 {
    background: #a8d2a8
}

.inv48-194 {
    color: #a8d2a8
}

.ansi38-195 {
    color: #a8d2d2
}

.inv38-195 {
    background: #a8d2d2
}

.ansi48-195 {
    background: #a8d2d2
}

.inv48-195 {
    color: #a8d2d2
}

.ansi38-226 {
    color: #d2d200
}

.inv38-226 {
    background: #d2d200
}

.ansi48-226 {
    background: #d2d200
}

.inv48-226 {
    color: #d2d200
}

.ansi38-227 {
    color: #d2d22a
}

.inv38-227 {
    background: #d2d22a
}

.ansi48-227 {
    background: #d2d22a
}

.inv48-227 {
    color: #d2d22a
}

.ansi38-228 {
    color: #d2d254
}

.inv38-228 {
    background: #d2d254
}

.ansi48-228 {
    background: #d2d254
}

.inv48-228 {
    color: #d2d254
}

.ansi38-229 {
    color: #d2d27e
}

.inv38-229 {
    background: #d2d27e
}

.ansi48-229 {
    background: #d2d27e
}

.inv48-229 {
    color: #d2d27e
}

.ansi38-230 {
    color: #d2d2a8
}

.inv38-230 {
    background: #d2d2a8
}

.ansi48-230 {
    background: #d2d2a8
}

.inv48-230 {
    color: #d2d2a8
}

.ansi38-231 {
    color: #d2d2d2
}

.inv38-231 {
    background: #d2d2d2
}

.ansi48-231 {
    background: #d2d2d2
}

.inv48-231 {
    color: #d2d2d2
}

.ansi38-232 {
    color: #080808
}

.inv38-232 {
    background: #080808
}

.ansi48-232 {
    background: #080808
}

.inv48-232 {
    color: #080808
}

.ansi38-233 {
    color: #121212
}

.inv38-233 {
    background: #121212
}

.ansi48-233 {
    background: #121212
}

.inv48-233 {
    color: #121212
}

.ansi38-234 {
    color: #1c1c1c
}

.inv38-234 {
    background: #1c1c1c
}

.ansi48-234 {
    background: #1c1c1c
}

.inv48-234 {
    color: #1c1c1c
}

.ansi38-235 {
    color: #262626
}

.inv38-235 {
    background: #262626
}

.ansi48-235 {
    background: #262626
}

.inv48-235 {
    color: #262626
}

.ansi38-236 {
    color: #303030
}

.inv38-236 {
    background: #303030
}

.ansi48-236 {
    background: #303030
}

.inv48-236 {
    color: #303030
}

.ansi38-237 {
    color: #3a3a3a
}

.inv38-237 {
    background: #3a3a3a
}

.ansi48-237 {
    background: #3a3a3a
}

.inv48-237 {
    color: #3a3a3a
}

.ansi38-238 {
    color: #444
}

.inv38-238 {
    background: #444
}

.ansi48-238 {
    background: #444
}

.inv48-238 {
    color: #444
}

.ansi38-239 {
    color: #4e4e4e
}

.inv38-239 {
    background: #4e4e4e
}

.ansi48-239 {
    background: #4e4e4e
}

.inv48-239 {
    color: #4e4e4e
}

.ansi38-240 {
    color: #585858
}

.inv38-240 {
    background: #585858
}

.ansi48-240 {
    background: #585858
}

.inv48-240 {
    color: #585858
}

.ansi38-241 {
    color: #626262
}

.inv38-241 {
    background: #626262
}

.ansi48-241 {
    background: #626262
}

.inv48-241 {
    color: #626262
}

.ansi38-242 {
    color: #6c6c6c
}

.inv38-242 {
    background: #6c6c6c
}

.ansi48-242 {
    background: #6c6c6c
}

.inv48-242 {
    color: #6c6c6c
}

.ansi38-243 {
    color: #767676
}

.inv38-243 {
    background: #767676
}

.ansi48-243 {
    background: #767676
}

.inv48-243 {
    color: #767676
}

.ansi38-244 {
    color: grey
}

.inv38-244 {
    background: grey
}

.ansi48-244 {
    background: grey
}

.inv48-244 {
    color: grey
}

.ansi38-245 {
    color: #8a8a8a
}

.inv38-245 {
    background: #8a8a8a
}

.ansi48-245 {
    background: #8a8a8a
}

.inv48-245 {
    color: #8a8a8a
}

.ansi38-246 {
    color: #949494
}

.inv38-246 {
    background: #949494
}

.ansi48-246 {
    background: #949494
}

.inv48-246 {
    color: #949494
}

.ansi38-247 {
    color: #9e9e9e
}

.inv38-247 {
    background: #9e9e9e
}

.ansi48-247 {
    background: #9e9e9e
}

.inv48-247 {
    color: #9e9e9e
}

.ansi38-248 {
    color: #a8a8a8
}

.inv38-248 {
    background: #a8a8a8
}

.ansi48-248 {
    background: #a8a8a8
}

.inv48-248 {
    color: #a8a8a8
}

.ansi38-249 {
    color: #b2b2b2
}

.inv38-249 {
    background: #b2b2b2
}

.ansi48-249 {
    background: #b2b2b2
}

.inv48-249 {
    color: #b2b2b2
}

.ansi38-250 {
    color: #bcbcbc
}

.inv38-250 {
    background: #bcbcbc
}

.ansi48-250 {
    background: #bcbcbc
}

.inv48-250 {
    color: #bcbcbc
}

.ansi38-251 {
    color: #c6c6c6
}

.inv38-251 {
    background: #c6c6c6
}

.ansi48-251 {
    background: #c6c6c6
}

.inv48-251 {
    color: #c6c6c6
}

.ansi38-252 {
    color: #d0d0d0
}

.inv38-252 {
    background: #d0d0d0
}

.ansi48-252 {
    background: #d0d0d0
}

.inv48-252 {
    color: #d0d0d0
}

.ansi38-253 {
    color: #dadada
}

.inv38-253 {
    background: #dadada
}

.ansi48-253 {
    background: #dadada
}

.inv48-253 {
    color: #dadada
}

.ansi38-254 {
    color: #e4e4e4
}

.inv38-254 {
    background: #e4e4e4
}

.ansi48-254 {
    background: #e4e4e4
}

.inv48-254 {
    color: #e4e4e4
}

.ansi38-255 {
    color: #eee
}

.inv38-255 {
    background: #eee
}

.ansi48-255 {
    background: #eee
}

.inv48-255 {
    color: #eee
}

.goog-date-picker {
    position: absolute;
    left: 0;
    float: left;
    min-width: 160px;
    margin: 1px 0 0 0;
    font-size: 14px;
    list-style: none;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid rgba(0, 0, 0, .15);
    border-radius: 4px;
    background-clip: padding-box;
    box-shadow: 0 6px 12px rgba(0, 0, 0, .175);
    top: 0;
    width: 250px;
    padding: 4px;
    z-index: 99999
}

.goog-date-picker th {
    text-align: center;
    font-size: .9em;
    padding: 5px
}

.goog-date-picker th div {
    float: left
}

.goog-date-picker th:first-child, .goog-date-picker th[role=rowheader] {
    display: none
}

.goog-date-picker td {
    text-align: center;
    vertical-align: middle;
    border-radius: 4px;
    padding: 5px
}

.goog-date-picker td:hover {
    cursor: pointer
}

.goog-date-picker button {
    padding: 5px 0;
    margin: 1px 0;
    border: 0;
    font-weight: 400;
    background: 0 0;
    box-shadow: none;
    color: #000;
    font-weight: 700
}

.goog-date-picker-menu {
    position: absolute;
    background: #fff;
    border: 1px solid rgba(0, 0, 0, .15);
    border-radius: 4px;
    -moz-user-focus: normal;
    -moz-user-select: none;
    z-index: 1;
    outline: 0;
    width: 160px !important
}

.goog-date-picker-menu ul {
    list-style: none;
    margin: 0;
    padding: 0
}

.goog-date-picker-menu ul li {
    cursor: default;
    padding: 5px 20px
}

.goog-date-picker-menu ul li:hover {
    cursor: pointer;
    background-color: #eee
}

.goog-date-picker-menu-selected {
    background: #fafa00;
    color: #000
}

.goog-date-picker-date {
    background: #fff
}

.goog-date-picker-date:hover {
    background-color: #eee
}

.goog-date-picker-wday, .goog-date-picker-week {
    padding: 1px 3px;
    border: 0;
    border-color: #e0e0e0;
    border-style: solid
}

.goog-date-picker-week {
    border-right-width: 1px
}

.goog-date-picker-wday {
    border-bottom-width: 1px
}

.goog-date-picker-head td {
    text-align: center;
    position: relative
}

.goog-date-picker-head td .goog-date-picker-previousMonth, .goog-date-picker-head td .goog-date-picker-previousYear {
    position: absolute;
    left: 5px;
    font-size: 0;
    height: 30px;
    width: 15px
}

.goog-date-picker-head td .goog-date-picker-previousMonth:after, .goog-date-picker-head td .goog-date-picker-previousYear:after {
    content: "\f104";
    font-family: FontAwesome;
    font-size: 18px;
    padding: 0 2px;
    position: absolute;
    left: 2px;
    top: 3px
}

.goog-date-picker-head td .goog-date-picker-nextMonth, .goog-date-picker-head td .goog-date-picker-nextYear {
    position: absolute;
    right: 5px;
    left: auto;
    font-size: 0;
    height: 30px;
    width: 15px
}

.goog-date-picker-head td .goog-date-picker-nextMonth:after, .goog-date-picker-head td .goog-date-picker-nextYear:after {
    content: "\f105";
    font-family: FontAwesome;
    font-size: 18px;
    padding: 0 2px;
    position: absolute;
    left: 2px;
    top: 3px
}

td.goog-date-picker-none-cont, td.goog-date-picker-today-cont {
    text-align: center
}

.goog-date-picker-month {
    white-space: nowrap
}

.goog-date-picker-year {
    white-space: nowrap
}

.goog-date-picker-monthyear {
    white-space: nowrap
}

.goog-date-picker table {
    border-collapse: collapse;
    width: 100%
}

.goog-date-picker-other-month {
    color: #888
}

td.goog-date-picker-selected {
    border-radius: 4px;
    background: #fafa00;
    color: #000
}

.goog-date-picker-today {
    font-weight: 700;
    color: #000;
    position: relative
}

.goog-date-picker-today::before {
    content: '';
    display: inline-block;
    border-left: 7px solid transparent;
    border-bottom: 7px solid #000;
    border-top-color: rgba(0, 0, 0, .2);
    position: absolute;
    bottom: 4px;
    right: 4px
}

.ac-buttons .goog-icon-remove {
    top: 10px
}

.ac-buttons .ac.dropdown-menu {
    width: 100%;
    overflow-x: hidden;
    overflow-y: auto
}

.ac-buttons .ac.dropdown-menu li {
    height: auto;
    cursor: pointer
}

.ac-buttons .ac.dropdown-menu li[data-value="__empty__"] {
    font-style: italic
}

.ac-buttons .open-list {
    cursor: pointer
}

.tag-container .tag {
    height: auto
}

body:not(.club-layout) {
    padding-top: 51px
}

.app-backend #js-session-expiration-modal .modal {
    display: block
}

.app-backend .alert.alert-info {
    background-color: #fff;
    border-color: #fff;
    color: #999;
    border: 1px dashed #ccc
}

.app-backend .alert.alert-info hr {
    border-top-color: #f2f2f2
}

.app-backend .alert.alert-info .alert-link {
    color: gray
}

.app-backend.loading {
    border: 1px solid #3ea1ff;
    color: #3ea1ff;
    border-radius: 0
}

.app-backend.app-backend-env-accept .navbar-fixed-top {
    background-color: #b6ffbd
}

.app-backend.app-backend-env-dev .navbar-fixed-top {
    background-color: #f4d9d0
}

.app-backend.app-backend-env-integration .navbar-fixed-top {
    background-color: #cfd9f2
}

.app-backend.app-backend-env-local .navbar-fixed-top {
    background-color: #fdffb6
}

.app-backend.app-backend-env-preprod .navbar-fixed-top {
    background-color: #d6cdc8
}

.app-backend.app-backend-env-prod .navbar-fixed-top {
    background-color: inherit
}

.app-backend.app-backend-env-train .navbar-fixed-top {
    background-color: #b5dce1
}

.app-backend .navbar-static-side {
    overflow: auto
}

@media (max-width: 767px) {
    .app-backend .app-backend .environment, .app-backend .navbar-brand, .app-backend .sidebar-collapse {
        display: none
    }

    .app-backend .sidebar-collapse.in {
        display: block
    }

    .app-backend .navbar-user {
        position: absolute;
        top: 0
    }
}

.app-backend #page-wrapper {
    overflow: auto;
    height: 100%;
    min-height: 350px
}

.app-backend .value {
    font-size: 1em
}

.app-backend div.content {
    padding: 15px
}

.app-backend .header {
    height: auto;
    padding: 10px 15px 0
}

.app-backend .header:after {
    content: '';
    width: 100%;
    display: table;
    position: relative
}

.app-backend .header .nav-tabs {
    border-bottom: 0;
    margin-top: 10px;
    float: none
}

.app-backend .header .nav-tabs:after, .app-backend .header .nav-tabs:before {
    content: '';
    display: table;
    clear: both
}

.app-backend .header .breadcrumb {
    margin: 0;
    display: block
}

.app-backend .header .breadcrumb li {
    margin-bottom: 5px
}

.app-backend fieldset > .container-fluid {
    padding: 0
}

.app-backend .pull-right > .dropdown-menu {
    right: auto
}

.app-backend .form-btns {
    left: 211px
}

.app-backend.app-backend-form-view .snippet-content {
    height: calc(100% - 74px);
    margin-bottom: 74px;
    overflow-y: auto
}

.c3-tooltip-container {
    background: #f0f0f0;
    border: 1px solid #ddd;
    border-radius: 3px;
    box-shadow: 0 0 4px 0 rgba(0, 0, 0, .15);
    color: #666;
    max-width: 180px;
    padding: 10px
}

.paginator__custom-base-input {
    width: 90px;
    margin-left: 10px;
    margin-right: 10px
}

.field-value.tag, .field.tag, .form-group.tag {
    padding: 0;
    border: 0;
    float: none;
    height: inherit
}

.row-md-cleaner {
    margin-left: -15px;
    margin-right: -15px
}
